/*
Met dit programma wordt het laatst geobserveerde arbeidsmarktstatuut geconstrueerd
Hiervoor worden bestanden RSZ en RSZPPO gecombineerd voor de periode 1997 tot 2006
*/
/*Zet gebruikersopties*/
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = LabmStatCombin;
%let AantFiles  = 12;
%let StartYear  = 1997;

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak bibliotheek en filenamen aan*/
    DATA _NULL_;
        /*Maak library en filenaam voor resultaatgegevens: merk op: hier 1 naam*/
        subnaam1 = "&ResFile" || "_&StartYear";            
        CALL SYMPUT(%UNQUOTE(%STR(%'SubRFile%')),TRIM(LEFT(subnaam1)));               
    RUN;
    
    /*Start loop over aantal files*/
    %DO I = &StartYear %to %EVAL(&StartYear + &AantFiles -1);

        PROC SORT DATA=&LIB2..mim2008_labmstatrsz_&I;
            BY /*GECODEERD_*/INSZ;
        RUN;
        PROC SORT DATA=&LIB2..mim2008_labmstatrszppo_&I;
            BY /*GECODEERD_*/INSZ;
        RUN;

    %END;

    DATA &LIB2..mim2008_&SubRFile;

        MERGE
        %DO I = &StartYear %to %EVAL(&StartYear + &AantFiles -1);
            &LIB2..mim2008_labmstatrsz_&I &LIB2..mim2008_labmstatrszppo_&I
        %END;
        ;
        BY /*gecodeerd_*/insz;
        
        /*Create LABMSTAT_PRIV*/
        LABMSTAT_PRIV = 0;
        %DO I = %EVAL(&StartYear + &AantFiles -1) %TO &StartYear %BY -1;
            IF RSZ_LABMSTAT_PRIV_&I NE 0 AND RSZ_LABMSTAT_PRIV_&I NE . AND LABMSTAT_PRIV EQ 0 THEN    LABMSTAT_PRIV = RSZ_LABMSTAT_PRIV_&I;
        %END;

        /*Create LABMSTAT_PUB*/
        LABMSTAT_PUB = 0;
        %DO I = %EVAL(&StartYear + &AantFiles -1) %TO &StartYear %BY -1;
            IF RSZ_LABMSTAT_PUB_&I NE 0 AND RSZ_LABMSTAT_PUB_&I NE . AND LABMSTAT_PUB EQ 0 THEN       LABMSTAT_PUB = RSZ_LABMSTAT_PUB_&I;
            IF RSZPPO_LABMSTAT_PUB_&I NE 0 AND RSZPPO_LABMSTAT_PUB_&I NE . AND LABMSTAT_PUB EQ 0 THEN LABMSTAT_PUB = RSZPPO_LABMSTAT_PUB_&I;
        %END;
        
        /*Create part-time and full time*/
        Days_Full = 0;
        Days_Part = 0;
        %DO I = &StartYear %TO %EVAL(&StartYear + &AantFiles -1);
            IF RSZ_Full_&I NE .     THEN Days_Full = Days_Full + RSZ_Full_&I;
            IF RSZ_Part_&I NE .     THEN Days_Part = Days_Part + RSZ_Part_&I;
            IF RSZPPO_Full_&I NE .  THEN Days_Full = Days_Full + RSZPPO_Full_&I;
            IF RSZPPO_Part_&I NE .  THEN Days_Part = Days_Part + RSZPPO_Part_&I;
        %END;
        Work_FP = 0;
        IF Days_Full GT Days_Part THEN Work_FP = 1;

        LABEL LABMSTAT_PRIV = "Meest voorkomende arbeidsmarktstatus op de private arbeidsmarkt in de periode 1997 tot en met eindjaar";
        LABEL LABMSTAT_PUB  = "Meest voorkomende arbeidsmarktstatus op de publieke arbeidsmarkt in de periode 1997 tot en met eindjaar";
        LABEL Work_FP       = "Voornamelijk actief als voltijds werker of als deeltijds werker";

        KEEP 
        /*GECODEERD_*/INSZ 
        LABMSTAT_PRIV 
        LABMSTAT_PUB 
        Work_FP
        ;       
    RUN;

%MEND ForEach;
%ForEach;

