/*
Met dit programma wordt het arbeidsmarktstatuut op jaarbasis geconstrueerd met RSZ gegevens
*/

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach(EEJJK);

    /*Zet gebruikersopties*/
    %let EEJJ       = %SUBSTR(&EEJJK,1,4);
    %let Year       = %SUBSTR(&EEJJK,1,4);
    %let JJK        = %SUBSTR(&EEJJK,3,3);
    %let JJ         = %SUBSTR(&EEJJK,3,2);
    %let LIB1       = D_RSZ&JJ.;                    /*bibliotheek waar RSZ-gegevens staan*/
    %let SubFile1   = rsz_&JJ.1;
    %let SubFile2   = rsz_&JJ.2;
    %let SubFile3   = rsz_&JJ.3;
    %let SubFile4   = rsz_&JJ.4;
    %let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
    %let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
    %let ResFile    = mim2008_LabmStatRSZ;
    %let AantFiles  = 4;

    /*Merk op: Chris Brijs zegt wel dat de selectie van de lijnen hier niet volgens de regels van de kunst verloopt
    Om correct te zijn zouden we eerst een telling van alle lijnen per job moeten doen en dan pas het statuut van de
    belangrijkste job over houden, terwijl we nu het statuut van de lijn met de hoogste waarde van SAL100 over houden*/
    
    /*Start loop over aantal files*/
    %DO I = 1 %to &AantFiles;
             
        /*Verwerk gegevens van een gegeven kwartaal*/
        DATA RSZBasis&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;

            
            %if &EEJJ. lt 2003 %then %do;
                if fictif = 'R';
            %end;

            /*Create RSZ_LABMSTAT_PRIV*/
            RSZ_LABMSTAT_PRIV_&Year = 0;
            IF (SECEMP EQ '1') THEN DO;
                IF CLATRA EQ 1 THEN RSZ_LABMSTAT_PRIV_&Year = 1;
                IF CLATRA EQ 2 THEN RSZ_LABMSTAT_PRIV_&Year = 2;
                IF CLATRA EQ 4 THEN RSZ_LABMSTAT_PRIV_&Year = 5;
            END;
            Label RSZ_LABMSTAT_PRIV_&Year = "Labour market status of a wage earner on the private labour market in &Year";

            /*Create RSZ_LABMSTAT_PUB*/
            RSZ_LABMSTAT_PUB_&Year = 0;
            IF (SECEMP EQ '2') THEN DO;
                IF CLATRA EQ 1 THEN RSZ_LABMSTAT_PUB_&Year = 1;
                IF CLATRA EQ 2 THEN RSZ_LABMSTAT_PUB_&Year = 2;
                IF CLATRA EQ 3 THEN RSZ_LABMSTAT_PUB_&Year = 4;
                IF CLATRA EQ 4 THEN RSZ_LABMSTAT_PUB_&Year = 5;
            END;
            IF (SECEMP EQ '2' AND RSZ_LABMSTAT_PUB_&Year EQ 0) THEN DO;
                IF CODTRA IN (10, 11, 12, 13, 14, 15, 16, 22, 24, 25, 27, 35, 41, 45)            THEN RSZ_LABMSTAT_PUB_&Year = 1;
                IF CODTRA IN (439, 484, 485, 487, 492, 493, 494, 495, 673, 840, 876, 877, 879)   THEN RSZ_LABMSTAT_PUB_&Year = 2;
                IF CODTRA IN (671, 675)                                                          THEN RSZ_LABMSTAT_PUB_&Year = 4;
            END;
            Label RSZ_LABMSTAT_PUB_&Year = "Labour market status of a wage earner on the public labour market in &Year";

            /*Merk op: R_exclus niet gebruikt omdat variabele niet in kleine bestanden zat*/
            KEEP GECODEERD_INSZ RSZ_LABMSTAT_PRIV_&Year RSZ_LABMSTAT_PUB_&Year SAL100 jrsrem_f jrsrem_p;
        RUN;

    %END;

    DATA Combin;
        SET
            %DO I = 1 %to &AantFiles;
                RSZBasis&I
            %END;
        ;
    RUN;
    
    PROC SORT DATA=Combin;
        BY gecodeerd_insz SAL100;
    RUN;
    
    DATA &LIB2..&ResFile._&Year.;

        SET Combin;
        BY gecodeerd_insz;
        RETAIN RSZ_Full_&Year RSZ_Part_&Year 0;

        IF FIRST.gecodeerd_insz THEN DO;
            RSZ_Full_&Year = 0;
            RSZ_Part_&Year = 0;
            IF jrsrem_f NE . THEN RSZ_Full_&Year = jrsrem_f;
            IF jrsrem_p NE . THEN RSZ_Part_&Year = jrsrem_p;
        END;
        ELSE DO;
            IF jrsrem_f NE . THEN RSZ_Full_&Year = RSZ_Full_&Year + jrsrem_f;
            IF jrsrem_p NE . THEN RSZ_Part_&Year = RSZ_Part_&Year + jrsrem_p;
        END;
        
        IF LAST.gecodeerd_insz THEN OUTPUT;
        KEEP GECODEERD_INSZ RSZ_LABMSTAT_PRIV_&Year RSZ_LABMSTAT_PUB_&Year RSZ_Full_&Year RSZ_Part_&Year;
    RUN;

	data &LIB2..&ResFile._&Year.;
		set &LIB2..&ResFile._&Year. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach(19974);
%ForEach(19984);
%ForEach(19994);
%ForEach(20004);
%ForEach(20014);
%ForEach(20024);
%ForEach(20034);
%ForEach(20044);
%ForEach(20054);
%ForEach(20064);
%ForEach(20074);
%ForEach(20084);

