/*
Met dit programma wordt het arbeidsmarktstatuut op jaarbasis geconstrueerd met RSZPPO gegevens
*/

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach(EEJJK);

    /*Zet gebruikersopties*/
    %let EEJJ       = %SUBSTR(&EEJJK,1,4);
    %let Year       = %SUBSTR(&EEJJK,1,4);
    %let JJK        = %SUBSTR(&EEJJK,3,3);
    %let JJ         = %SUBSTR(&EEJJK,3,2);
    %let LIB1       = D_PPO&JJ.;                    /*bibliotheek waar RSZPPO-gegevens staan*/
    %let SubFile1   = ppo_&JJ.1;
    %let SubFile2   = ppo_&JJ.2;
    %let SubFile3   = ppo_&JJ.3;
    %let SubFile4   = ppo_&JJ.4;
    %let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
    %let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
    %let ResFile    = mim2008_LabmStatRSZPPO;
    %let AantFiles  = 4;

    /*Start loop over aantal files*/
    %DO I = 1 %to &AantFiles;
             
        %IF %EVAL(&Year.) GE 2005 %THEN %DO;

            /*Verwerk gegevens van een gegeven kwartaal*/
            DATA RSZPPOBasis&I;

                MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                        &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
                ;
                BY gecodeerd_insz;
                IF ina=1 and inb=1;

                /*Create RSZPPO_LABMSTAT_PUB*/
                RSZPPO_LABMSTAT_PUB_&Year = 0;
                IF CLATRAAPL EQ 1 THEN RSZPPO_LABMSTAT_PUB_&Year = 1;
                IF CLATRAAPL EQ 2 THEN RSZPPO_LABMSTAT_PUB_&Year = 2;
                IF CLATRAAPL EQ 3 THEN RSZPPO_LABMSTAT_PUB_&Year = 4;
                IF CLATRAAPL EQ 4 THEN RSZPPO_LABMSTAT_PUB_&Year = 5;
                IF (RSZPPO_LABMSTAT_PUB_&Year EQ 0 OR RSZPPO_LABMSTAT_PUB_&Year EQ 5) THEN DO;
                    IF CODTRA IN
                       (102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
                        114, 115, 116, 117, 118, 119, 120, 121, 122, 126, 127, 128, 
                        129, 132, 133, 134, 135, 136, 138, 140, 142, 143, 144, 145, 
                        146, 147, 148, 149, 150, 152, 153, 154, 155, 156, 157, 158, 
                        159, 162, 163, 164, 165, 166, 167, 168, 181, 182, 183, 184, 
                        191, 192, 193, 194, 195, 196, 197, 198)                     THEN RSZPPO_LABMSTAT_PUB_&Year = 1;
                    IF CODTRA IN
                       (202, 203, 204, 205, 206, 207, 208, 209, 210, 212, 213, 214,
                        215, 217, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 
                        229, 232, 233, 234, 235, 236, 237, 238, 240, 242, 243, 244, 
                        245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 
                        257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 270, 
                        271, 273, 274, 275, 276, 277, 278, 279, 281, 282, 283, 284, 
                        285, 286, 287, 288, 291, 292, 293, 294, 295, 296, 297, 298,
                        761, 762, 763)                                              THEN RSZPPO_LABMSTAT_PUB_&Year = 2;
                    IF CODTRA IN
                       (601, 602, 605, 606, 607, 608, 609, 610, 611, 615, 616, 617, 
                        618, 773, 774, 775, 776, 777, 778, 790, 795)                THEN RSZPPO_LABMSTAT_PUB_&Year = 3;
                    IF CODTRA IN
                       (620, 621, 622, 623, 625, 626, 630, 631, 632, 633, 635, 636, 
                        649, 650, 651, 652, 659, 660, 671, 672, 673, 674, 675, 681, 
                        682, 683, 684, 685, 700, 710, 720, 731, 732, 733, 734, 735, 
                        736, 737, 738, 740, 771, 772, 781, 782, 783, 784, 785, 786, 
                        787, 788)                                                   THEN RSZPPO_LABMSTAT_PUB_&Year = 4;
                END;

                Label RSZPPO_LABMSTAT_PUB_&Year = "Labour market status of a wage earner on the public labour market in &Year";

                InkConcept = SAL100;
                DAGEN_W = days_pc1/100;
                UREN_W = hrs_pc1/100;
                
                KEEP GECODEERD_INSZ RSZPPO_LABMSTAT_PUB_&Year InkConcept /*WCATCD*/ DAGEN_W UREN_W;
            RUN;
    
        %END;
        %ELSE %DO;            

            /*Verwerk gegevens van een gegeven kwartaal*/
            DATA RSZPPOBasis&I;

                MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                        &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
                ;
                BY gecodeerd_insz;
                IF ina=1 and inb=1;

                /*Create RSZPPO_LABMSTAT_PUB*/
                RSZPPO_LABMSTAT_PUB_&Year = 0;
                IF WCATCD IN
                   (102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
                    114, 115, 116, 117, 118, 119, 120, 121, 122, 126, 127, 128, 
                    129, 132, 133, 134, 135, 136, 138, 140, 142, 143, 144, 145, 
                    146, 147, 148, 149, 150, 152, 153, 154, 155, 156, 157, 158, 
                    159, 162, 163, 164, 165, 166, 167, 168, 181, 182, 183, 184, 
                    191, 192, 193, 194, 195, 196, 197, 198)                     THEN RSZPPO_LABMSTAT_PUB_&Year = 1;
                IF WCATCD IN
                   (202, 203, 204, 205, 206, 207, 208, 209, 210, 212, 213, 214,
                    215, 217, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 
                    229, 232, 233, 234, 235, 236, 237, 238, 240, 242, 243, 244, 
                    245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 
                    257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 270, 
                    271, 273, 274, 275, 276, 277, 278, 279, 281, 282, 283, 284, 
                    285, 286, 287, 288, 291, 292, 293, 294, 295, 296, 297, 298,
                    761, 762, 763)                                              THEN RSZPPO_LABMSTAT_PUB_&Year = 2;
                IF WCATCD IN
                   (601, 602, 605, 606, 607, 608, 609, 610, 611, 615, 616, 617, 
                    618, 773, 774, 775, 776, 777, 778, 790, 795)                THEN RSZPPO_LABMSTAT_PUB_&Year = 3;
                IF WCATCD IN
                   (620, 621, 622, 623, 625, 626, 630, 631, 632, 633, 635, 636, 
                    649, 650, 651, 652, 659, 660, 671, 672, 673, 674, 675, 681, 
                    682, 683, 684, 685, 700, 710, 720, 731, 732, 733, 734, 735, 
                    736, 737, 738, 740, 771, 772, 781, 782, 783, 784, 785, 786, 
                    787, 788)                                                   THEN RSZPPO_LABMSTAT_PUB_&Year = 4;

                Label RSZPPO_LABMSTAT_PUB_&Year = "Labour market status of a wage earner on the public labour market in &Year";

                InkConcept = Lmasamt;
                DAGEN_W = P_dg100a;
                UREN_W = P_ur100a;
                
                KEEP GECODEERD_INSZ RSZPPO_LABMSTAT_PUB_&Year InkConcept WCATCD DAGEN_W UREN_W;
            RUN;
    
        %END;

    %END;

    DATA Combin;
        SET
            %DO I = 1 %to &AantFiles;
                RSZPPOBasis&I
            %END;
        ;
    RUN;
    
    PROC SORT DATA=Combin;
        BY gecodeerd_insz InkConcept;
    RUN;
    
    DATA &LIB2..&ResFile._&Year.;

        SET Combin;
        BY gecodeerd_insz;

        RETAIN RSZPPO_Full_&Year RSZPPO_Part_&Year 0;

        IF FIRST.gecodeerd_insz THEN DO;
            RSZPPO_Full_&Year = 0;
            RSZPPO_Part_&Year = 0;
            IF DAGEN_W*7.6 GE UREN_W AND DAGEN_W NE . THEN RSZPPO_Full_&Year = DAGEN_W; 
            IF DAGEN_W*7.6 LT UREN_W AND DAGEN_W NE . THEN RSZPPO_Part_&Year = DAGEN_W; 
        END;
        ELSE DO;
            IF DAGEN_W*7.6 GE UREN_W AND DAGEN_W NE . THEN RSZPPO_Full_&Year = RSZPPO_Full_&Year + DAGEN_W; 
            IF DAGEN_W*7.6 LT UREN_W AND DAGEN_W NE . THEN RSZPPO_Part_&Year = RSZPPO_Part_&Year + DAGEN_W; 
        END;
        
        IF LAST.gecodeerd_insz THEN OUTPUT;
        KEEP GECODEERD_INSZ RSZPPO_LABMSTAT_PUB_&Year RSZPPO_Full_&Year RSZPPO_Part_&Year;
    RUN;

	data &LIB2..&ResFile._&Year.;
		set &LIB2..&ResFile._&Year. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach(19974);
%ForEach(19984);
%ForEach(19994);
%ForEach(20004);
%ForEach(20014);
%ForEach(20024);
%ForEach(20034);
%ForEach(20044);
%ForEach(20054);
%ForEach(20064);
%ForEach(20074);
%ForEach(20084);


