/*
Met dit programma worden 4 kwartaalbestanden met gegevens van de DG PMH aangemaakt
*/
/*Zet gebruikersopties*/
%let LIB1       = D_FOSZ08;                    /*bibliotheek waar PMH-gegevens staan*/
%let SubFile1   = med;
%let SubFile2   = pay;/*droit;*/
%let SubFile3   = rht; /*pay;*/
%let SubFile4   = ptn;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = DGPMH_Data;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;

        DATA &LIB2..mim2008_fodsz_&SubFile1.&JJ.&i._New;

            MERGE   &LIB1..&SubFile1._&JJ.&i. (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7         (In=InB keep = insz rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
            
            /*Make variables*/
            /*Variabelen bestand erkenning handicap*/
            type_rec_&JJ.&i.                    = type_rec;
            code_leg_&JJ.&i.                    = code_leg;
            %DateManip(date_start_recon,date_start_recon_&JJ.&i.);
            %DateManip(date_end_recon,date_end_recon_&JJ.&i.);
            memb_inf_50perc_&JJ.&i.             = memb_inf_50perc;
            cecite_comp_&JJ.&i.                 = cecite_comp;
            amp_memb_sup_&JJ.&i.                = amp_memb_sup;
            paral_memb_sup_&JJ.&i.              = paral_memb_sup;
            incapacite_&JJ.&i.                  = incapacite;
            pilier_un_&JJ.&i.                   = pilier_un;
            pilier_deux_&JJ.&i.                 = pilier_deux;
            pilier_trois_&JJ.&i.                = pilier_trois;
            arr_&JJ.&i.                         = arr;
            critere_un_&JJ.&i.                  = critere_un;
            critere_deux_&JJ.&i.                = critere_deux;
            critere_trois_&JJ.&i.               = critere_trois;
            critere_quatre_&JJ.&i.              = critere_quatre;
            critere_cinq_&JJ.&i.                = critere_cinq;
            critere_six_&JJ.&i.                 = critere_six;
            %DateManip(date_deces,date_deces_&JJ.&i.);

            /*Label variables*/
            LABEL GECODEERD_INSZ                = "Geanonimiseerd identificatienummer van het individu";
            /*Labels bestand erkenning handicap*/
            LABEL type_rec_&JJ.&i.              = "Type Record";
            LABEL code_leg_&JJ.&i.              = "Code wetgeving";
            LABEL date_start_recon_&JJ.&i.      = "Begindatum erkenning (=beslissing medische commissie)";
            LABEL date_end_recon_&JJ.&i.        = "Einddatum erkenning (=beslissing medische commissie)";
            LABEL memb_inf_50perc_&JJ.&i.       = "50% onderste ledematen";
            LABEL cecite_comp_&JJ.&i.           = "Volledige blindheid";
            LABEL amp_memb_sup_&JJ.&i.          = "Amputatie van bovenste ledematen";
            LABEL paral_memb_sup_&JJ.&i.        = "Verlamming van de bovenste ledematen";
            LABEL incapacite_&JJ.&i.            = "ongeschiktheid";
            LABEL pilier_un_&JJ.&i.             = "pijler 1";
            LABEL pilier_deux_&JJ.&i.           = "pijler 2";
            LABEL pilier_trois_&JJ.&i.          = "pijler 3";
            LABEL arr_&JJ.&i.                   = "IVT";
            LABEL critere_un_&JJ.&i.            = "criterium 1";
            LABEL critere_deux_&JJ.&i.          = "criterium 2";
            LABEL critere_trois_&JJ.&i.         = "criterium 3";
            LABEL critere_quatre_&JJ.&i.        = "criterium 4";
            LABEL critere_cinq_&JJ.&i.          = "criterium 5";
            LABEL critere_six_&JJ.&i.           = "criterium 6";
            LABEL date_deces_&JJ.&i.            = "Overlijdensdatum";

            KEEP
            GECODEERD_INSZ                
            /*Variabelen bestand erkenning handicap*/
            type_rec_&JJ.&i.              
            code_leg_&JJ.&i.              
            date_start_recon_&JJ.&i.      
            date_end_recon_&JJ.&i.        
            memb_inf_50perc_&JJ.&i.       
            cecite_comp_&JJ.&i.           
            amp_memb_sup_&JJ.&i.          
            paral_memb_sup_&JJ.&i.        
            incapacite_&JJ.&i.            
            pilier_un_&JJ.&i.             
            pilier_deux_&JJ.&i.           
            pilier_trois_&JJ.&i.          
            arr_&JJ.&i.                   
            critere_un_&JJ.&i.            
            critere_deux_&JJ.&i.          
            critere_trois_&JJ.&i.         
            critere_quatre_&JJ.&i.        
            critere_cinq_&JJ.&i.          
            critere_six_&JJ.&i.           
            date_deces_&JJ.&i.            
            ;

        RUN;            

        DATA &LIB2..mim2008_fodsz_&SubFile1.&JJ.&i._New;
			set &LIB2..mim2008_fodsz_&SubFile1.&JJ.&i._New (rename = (gecodeerd_insz = insz));
		RUN;

    %END;

    /*Andere bestanden zijn jaarbestanden*/

    DATA &LIB2..mim2008_fodsz_&SubFile2.&EEJJ._New;

        MERGE   &LIB1..&SubFile2._&EEJJ. (In=InA rename = (insz = gecodeerd_insz))
                &LIB2..&SubFile7         (In=InB rename = (insz = gecodeerd_insz))
        ;
        BY gecodeerd_insz;
        IF ina=1 and inb=1;
        
        /*Variabelen betalingsbestand*/      
        %NomValManip(montant,montant_&EEJJ.,1000);
        %NomValManip(mont_emis,mont_emis_&EEJJ.,1000);
        class_stat_&EEJJ.                  = class_stat;
/*        %DateManip(per_start_pay,per_start_pay_&EEJJ.);*/
/*        %DateManip(per_end_pay,per_end_pay_&EEJJ.);*/

		per_start_pay_&EEJJ. = per_start_pay;
		per_end_pay_&EEJJ. = per_end_pay;

        /*Label variables*/
        LABEL GECODEERD_INSZ                = "Geanonimiseerd identificatienummer van het individu";
        /*Labels betalingsbestand*/
        LABEL montant_&EEJJ.               = "Maandbedrag (= bedrag dat in principe iedere maand van de betalingsperiode zou moeten betaald zou moeten worden)";
        LABEL mont_emis_&EEJJ.             = "Totaal betaald bedrag gedurende de periode";
        LABEL class_stat_&EEJJ.            = "Statistische codificatie";
        LABEL per_start_pay_&EEJJ.         = "Begindatum betaling";
        LABEL per_end_pay_&EEJJ.           = "Einddatum betaling";

        KEEP
        GECODEERD_INSZ                
        /*Variabelen betalingsbestand*/
        montant_&EEJJ.               
        mont_emis_&EEJJ.             
        class_stat_&EEJJ.            
        per_start_pay_&EEJJ.         
        per_end_pay_&EEJJ.           
        ;

    RUN;            

    DATA &LIB2..mim2008_fodsz_&SubFile2.&EEJJ._New;
			set &LIB2..mim2008_fodsz_&SubFile2.&EEJJ._New (rename = (gecodeerd_insz = insz));
	RUN;


    DATA &LIB2..mim2008_fodsz_&SubFile3.&EEJJ._New;

        MERGE   &LIB1..&SubFile3._&EEJJ. (In=InA rename = (insz = gecodeerd_insz))
                &LIB2..&SubFile7         (In=InB rename = (insz = gecodeerd_insz))
        ;
        BY gecodeerd_insz;
        IF ina=1 and inb=1;
        
        /*Make variables*/
        /*Variabelen rechtenbestand*/       
        %NomValManip(mnt_mens_sim,mnt_mens_sim_&EEJJ.,1000);
        %NomValManip(mnt_mens_AI_sim,mnt_mens_AI_sim_&EEJJ.,1000);
        periode_&EEJJ.                     = periode;
        %DateManip(date_start,date_start_&EEJJ.);
        %DateManip(date_end,date_end_&EEJJ.);
        %DateManip(date_decision,date_decision_&EEJJ.);
        %DateManip(date_decision_corr,date_decision_corr_&EEJJ.);

        /*Label variables*/
        LABEL GECODEERD_INSZ                = "Geanonimiseerd identificatienummer van het individu";
        /*Labels rechtenbestand*/
        LABEL mnt_mens_sim_&EEJJ.          = "Gesimuleerd maandbedrag IT en IVT samen van toepassing gedurende de referentieperiode (=bedrag zonder indexering etc)";
        LABEL mnt_mens_AI_sim_&EEJJ.       = "Gesimuleerd maandbedrag IT van toepassing gedurende de referentieperiode (=bedrag zonder indexering etc)";
        LABEL periode_&EEJJ.               = "Referentiemaand (inhoud gegeven en link met begindatum recht nog onduidelijk)";
        LABEL date_start_&EEJJ.            = "Begindatum recht";
        LABEL date_end_&EEJJ.              = "Einddatum recht";
        LABEL date_decision_&EEJJ.         = "Datum waarop geldigheid van het recht beslist werd";
        LABEL date_decision_corr_&EEJJ.    = "Datum waarop beslist werd om een recht ten onrechte toe te kennen en die recht gezet wordt op de beslissingsdatum in V9";

        KEEP
        GECODEERD_INSZ                
        /*Variabelen rechtenbestand*/
        mnt_mens_sim_&EEJJ.          
        mnt_mens_AI_sim_&EEJJ.       
        periode_&EEJJ.               
        date_start_&EEJJ.            
        date_end_&EEJJ.              
        date_decision_&EEJJ.         
        date_decision_corr_&EEJJ.    
        ;

    RUN;            

    DATA &LIB2..mim2008_fodsz_&SubFile3.&EEJJ._New;
		set	&LIB2..mim2008_fodsz_&SubFile3.&EEJJ._New (rename = (gecodeerd_insz = insz));
	RUN;


	/***/
	proc sort data = &LIB1..&SubFile4._&EEJJ. out = &SubFile4._&EEJJ.; by rrn; run;
	/***/

    DATA &LIB2..mim2008_fodsz_&SubFile4.&EEJJ._New;

        MERGE   /*&LIB1..*/&SubFile4._&EEJJ. (In=InA rename = (rrn/*insz*/ = insz 
															   rrn_part /*insz_partner*/ = insz_partner))
                &LIB2..&SubFile7         (In=InB )
        ;
        BY insz;
        IF ina=1 and inb=1;
        
        /*Make variables*/
        /*Variabelen partnerbestand*/       
        /*gecodeerd_insz_partner_&EEJJ.      = gecodeerd_insz_partner;*/
        %DateManip(date_start,date_start_&EEJJ.);
        %DateManip(date_end,date_end_&EEJJ.);

        /*Label variables*/
        LABEL /*GECODEERD_*/INSZ                = "Geanonimiseerd identificatienummer van het individu";
        /*Labels partnerbestand*/
        LABEL INSZ_PARTNER /*gecodeerd_insz_partner_&EEJJ.*/= "Het INSZ nummer van het individu";
        LABEL date_start_&EEJJ.            = "Begindatum partnerschap";
        LABEL date_end_&EEJJ.              = "Einddatum partnerschap";

        KEEP
        /*GECODEERD_*/INSZ                
        /*Variabelen partnerbestand*/
        insz_partner /*gecodeerd_insz_partner_&EEJJ.*/
        date_start_&EEJJ.            
        date_end_&EEJJ.
        ;

    RUN;            

/*    DATA &LIB2..mim2008_fodsz_&SubFile4.&EEJJ._New;
		set &LIB2..mim2008_fodsz_&SubFile4.&EEJJ._New (rename = (gecodeerd_insz = insz));
	RUN;*/

%MEND ForEach;
%ForEach;
