/*
Met dit programma worden een aantal gegevens van het FAO samengevoegd in n bestand
*/
/*Geef logfile naam en maak file leeg voor start*/
/*Zet gebruikersopties*/
%let LIB1       = D_fao08;                    /*bibliotheek waar FAO-gegevens staan*/
%let SubFile1   = fao_at_081;
%let SubFile2   = fao_at_082;
%let SubFile3   = fao_at_083;
%let SubFile4   = fao_at_084;
%let SubFile5   = fao_perit_2008;
%let SubFile6   = fao_pm_2008;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_FAO;
%let EEJJK      = 20084;
%let AantFiles  = 6;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;


    /*selecteer gegevens*/
    DATA MIMOSIS&EEJJ._fao_perit_&JJ.;

        SET &LIB1..&SubFile5;

        /*Give variables unique name*/
        TAUXIT_&EEJJ = TAUXIT;
        %DateManip(DDEBUT,DDEBUT_&EEJJ.);
        %DateManip(DFIN,DFIN_&EEJJ.);

        /*Label*/
        LABEL TAUXIT_&EEJJ = "Graad van tijdelijke arbeidsongeschiktheid (geregistreerd in &EEJJ)";
        LABEL DDEBUT_&EEJJ = "Begin van de periode van ongeschiktheid (geregistreerd in &EEJJ)";
        LABEL DFIN_&EEJJ   = "Einde van de periode van ongeschiktheid (geregistreerd in &EEJJ)";

        /*Keep variables*/
        KEEP
        nraccf
        TAUXIT_&EEJJ
        DDEBUT_&EEJJ
        DFIN_&EEJJ
        ;

    RUN;
    PROC SORT DATA=MIMOSIS&EEJJ._fao_perit_&JJ.;
        BY nraccf;
    RUN;
    
    DATA MIMOSIS&EEJJ._fao_pm_&JJ.;

        SET  &LIB1..&SubFile6;

        /*Give variables unique name*/
        DUREEITT_&EEJJ = DUREEITT;                                                                                                                                                                                                                
        DUREEITP_&EEJJ = DUREEITP;                                                                                                                                                                                                                  
        %NomValManip(MONTPERTSAL,MONTPERTSAL_&EEJJ.,10);
        %NomValManip(SALBASE,SALBASE_&EEJJ.,10);
        %NomValManip(MONTITT,MONTITT_&EEJJ.,10);
        %NomValManip(MONTITP,MONTITP_&EEJJ.,10);

        /*Label*/
        LABEL DUREEITT_&EEJJ    = "Aantal dagen tijdelijke arbeidsongeschiktheid: volledige afwezigheid (geregistreerd in &EEJJ)";
        LABEL DUREEITP_&EEJJ    = "Aantal dagen tijdelijke arbeidsongeschiktheid: gedeeltelijke afwezigheid (geregistreerd in &EEJJ)";
        LABEL MONTPERTSAL_&EEJJ = "Bedrag van het verloren loon (geregistreerd in &EEJJ)";
        LABEL SALBASE_&EEJJ     = "Voorgesteld loon dat dient als basis voor de berekening van de uitkering (geregistreerd in &EEJJ)";
        LABEL MONTITP_&EEJJ     = "Bedrag voor tijdelijke arbeidsongeschiktheid: gedeeltelijke afwezigheid (geregistreerd in &EEJJ)";
        LABEL MONTITT_&EEJJ     = "Bedrag voor tijdelijke arbeidsongeschiktheid: volledige afwezigheid (geregistreerd in &EEJJ)";

        /*Keep variables*/
        KEEP
        nraccf
        DUREEITT_&EEJJ                                                                                                                                                                                                             
        DUREEITP_&EEJJ                                                                                                                                                                                                                
        MONTPERTSAL_&EEJJ                                                                                                                                                                                                                             
        SALBASE_&EEJJ                                                                                                                                                                                                                               
        MONTITT_&EEJJ                                                                                                                                                                                                                             
        MONTITP_&EEJJ
        ;

    RUN;
    PROC SORT DATA=MIMOSIS&EEJJ._fao_pm_&JJ.;
        BY nraccf;
    RUN;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    DATA MIMOSIS&EEJJ._fao_ongeval_&JJ.;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;
    PROC SORT DATA=MIMOSIS&EEJJ._fao_ongeval_&JJ.;
        BY nraccf;
    RUN;
    DATA MIMOSIS&EEJJ._fao_ongeval_&JJ.;
        SET MIMOSIS&EEJJ._fao_ongeval_&JJ.;
        BY nraccf;
        IF last.nraccf THEN OUTPUT;
    RUN;        
    
    DATA COMBIN;
        MERGE
        MIMOSIS&EEJJ._fao_perit_&JJ.(in=lpb)
        MIMOSIS&EEJJ._fao_pm_&JJ.(in=inop)
        MIMOSIS&EEJJ._fao_ongeval_&JJ.(in=inrp)
        ;
        BY nraccf;
        if inrp=1;
        inlpb = 0;
        if lpb eq 1 then inlpb = lpb;
        inopvar = 0;
        if inop eq 1 then inopvar = inop;
        inrpvar = 0;
        if inrp eq 1 then inrpvar = inrp;
        
        /*Give variables unique name*/
        CJITPREV_&EEJJ.    = CJITPREV;
        CATPROFVICT_&EEJJ. = CATPROFVICT;
        CTARVICT_&EEJJ.    = CTARVICT;
        TYPETRAV_&EEJJ.    = TYPETRAV;
        TAUXIPRES_&EEJJ.   = TAUXIPRES;
        TAUXATRES_&EEJJ.   = TAUXATRES;
        %DateManip(datong,datong_&EEJJ.);

        /*Label*/
        LABEL CJITPREV_&EEJJ.    = "Graad van tijdelijke arbeidsongeschiktheid (geregistreerd in &EEJJ)";
        LABEL CATPROFVICT_&EEJJ. = "Beroepscategorie waartoe het individu op het moment van het ongeval behoort (geregistreerd in &EEJJ)";
        LABEL CTARVICT_&EEJJ.    = "Tariefcode gebruikt om de verzekeringspremie te bepalen (geregistreerd in &EEJJ)";
        LABEL TYPETRAV_&EEJJ.    = "Aanduiding van het beroep uitgeoefend op het moment van het ongeval (geregistreerd in &EEJJ)";
        LABEL TAUXIPRES_&EEJJ.   = "Graad van permanente arbeidsongeschiktheid (geregistreerd in &EEJJ)";
        LABEL TAUXATRES_&EEJJ.   = "Graad voor hulp van derden (geregistreerd in &EEJJ)";
        LABEL DATONG_&EEJJ.      = "Datum ongeval (geregistreerd in &EEJJ)";

    RUN;

    PROC FREQ DATA=COMBIN;
        tables 
        inlpb
        inopvar 
        inrpvar 
        ;
    RUN;

    DATA &LIB2..&ResFile;

        SET COMBIN;

        /*Keep variables*/
        KEEP
        gecodeerd_insz
        TAUXIPRES_&EEJJ.
        TAUXATRES_&EEJJ.
        TAUXIT_&EEJJ
        DDEBUT_&EEJJ
        DFIN_&EEJJ
        DUREEITT_&EEJJ                                                                                                                                                                                                             
        DUREEITP_&EEJJ                                                                                                                                                                                                                
        MONTPERTSAL_&EEJJ                                                                                                                                                                                                                             
        SALBASE_&EEJJ                                                                                                                                                                                                                               
        MONTITT_&EEJJ                                                                                                                                                                                                                             
        MONTITP_&EEJJ
        CATPROFVICT_&EEJJ.
        ;

    RUN;      
 
	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;
 
	proc sort data = &LIB2..&ResFile.; by insz; run;

%MEND ForEach;
%ForEach;
        


