/*
Met dit programma voeren we manipulaties uit op de FBZ data
Voor alle lijnen per individu en per soort uitkering worden gegevens voor bedragen opgeteld en de karakteristieken van de lijn met het hoogste bedrag
worden weggeschreven.
De vroegste begindatum en de laatste einddatum van de erkenningsperiode en de betalingsperiode worden weerhouden
*/
/*Zet gebruikersopties*/
%let LIB1       = D_fbz08;                    /*bibliotheek waar FBZ-gegevens staan*/
%let SubFile1   = fbz_081;
%let SubFile2   = fbz_082;
%let SubFile3   = fbz_083;
%let SubFile4   = fbz_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_FBZ;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    DATA FBZBasis;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;

    /*Sort by variables that can be squeezed*/
    PROC SORT DATA=FBZBasis;
        BY gecodeerd_insz soort_uitkering bedrag;
    RUN;

    /*Count number of times individuals appear with more than one line in basic file*/        
    PROC FREQ DATA=FBZBasis NOPRINT;
        TABLES  gecodeerd_insz / OUT=OutFreq;
    RUN;    
    PROC FREQ DATA=OutFreq(RENAME=(COUNT=NumTimes));
        TABLES  NumTimes / OUT=OutFreq1;
    RUN;    

    /*Manipulate data to squeeze lines*/
    DATA ManipDate;
        SET FBZBasis;
        BY gecodeerd_insz soort_uitkering bedrag;

        RETAIN SumBedrag BegDatum_Erk EndDatum_Erk BegDatum_Bet EndDatum_Bet 0;
        /*Start summing values*/
        IF FIRST.gecodeerd_insz OR FIRST.soort_uitkering THEN DO;
            BegDatum_Erk = beg_ongeschiktheid_datum;
            EndDatum_Erk = stopzettings_datum;
            BegDatum_Bet = Beg_periode_datum;
            EndDatum_Bet = end_periode_datum;
            SumBedrag    = bedrag         ;
        END;    
        ELSE DO;
            IF beg_ongeschiktheid_datum LT BegDatum_Erk AND beg_ongeschiktheid_datum NE . THEN BegDatum_Erk = beg_ongeschiktheid_datum;
            IF stopzettings_datum       LT EndDatum_Erk AND stopzettings_datum       NE . THEN EndDatum_Erk = stopzettings_datum;
            IF Beg_periode_datum        LT BegDatum_Bet AND Beg_periode_datum        NE . THEN BegDatum_Bet = Beg_periode_datum;
            IF end_periode_datum        LT EndDatum_Bet AND end_periode_datum        NE . THEN EndDatum_Bet = end_periode_datum;
            SumBedrag                                                                                       = SumBedrag + bedrag;
        END;
        IF LAST.gecodeerd_insz OR LAST.soort_uitkering THEN OUTPUT;
    RUN;

    /*Count number of times individuals appear with more than one line in the squeezed file*/        
    PROC FREQ DATA=ManipDate NOPRINT;
        TABLES  gecodeerd_insz / OUT=OutFreq;
    RUN; 
    PROC FREQ DATA=OutFreq(RENAME=(COUNT=NumTimes));
        TABLES  NumTimes / OUT=OutFreq1;
    RUN;    

    /*Write final output file*/
    DATA &LIB2..&ResFile;

        SET ManipDate;

        LABEL GECODEERD_INSZ    = "Geanonimiseerd identificatienummer van het individu";
        
        /*Rename variables*/
        %DateManip(BegDatum_Erk,FBZ_BEGDERK_&Year.);
        %DateManip(EndDatum_Erk,FBZ_ENDDERK_&Year.);
        %DateManip(BegDatum_Bet,FBZ_BEGDBET_&Year.);
        %DateManip(EndDatum_Bet,FBZ_ENDDBET_&Year.);
        %NomValManip(SumBedrag,FBZ_BEDRAG_&Year.,10);
        FBZ_SRTUIT_&Year.   = soort_uitkering;
        FBZ_BESLIS_&Year.   = aard_beslissing_code;
        FBZ_SRTPER_&Year.   = soort_periode;
        FBZ_PERCENT_&Year.  = percentage_c;
        FBZ_INDEX_&Year.    = index_uitkering;
        %NomValManip(basisloon,FBZ_BASLOON_&Year.,10);

        /*Label variables*/
        LABEL FBZ_BEGDERK_&Year.  = "Begindatum erkenning beroepsziekte (&Year.)"; 
        LABEL FBZ_ENDDERK_&Year.  = "Einddatum erkenning beroepsziekte (&Year.)"; 
        LABEL FBZ_BEGDBET_&Year.  = "Begindatum betaling beroepsziekte (&Year.)"; 
        LABEL FBZ_ENDDBET_&Year.  = "Einddatum betaling beroepsziekte (&Year.)"; 
        LABEL FBZ_BEDRAG_&Year.   = "Betaald bedrag beroepsziekte (&Year.)"; 
        LABEL FBZ_SRTUIT_&Year.   = "Soort uitkering beroepsziekte (&Year.)"; 
        LABEL FBZ_BESLIS_&Year.   = "Aard van beslissing in verband met beroepsziekte (&Year.)"; 
        LABEL FBZ_SRTPER_&Year.   = "Soort periode beroepsziekte (&Year.)"; 
        LABEL FBZ_PERCENT_&Year.  = "Percentage arbeidsongeschiktheid als gevolg van beroepsziekte (&Year.)"; 
        LABEL FBZ_INDEX_&Year.    = "Aanduiding van indexering uitkering beroepsziekte (&Year.)"; 
        LABEL FBZ_BASLOON_&Year.  = "Basisloon gebruikt voor bepaling beroepsziekte (&Year.)"; 

        KEEP
        GECODEERD_INSZ    
        FBZ_PERCENT_&Year. 
        FBZ_SRTUIT_&Year.  
        FBZ_BASLOON_&Year. 
        FBZ_SRTPER_&Year.  
        FBZ_BEGDBET_&Year. 
        FBZ_ENDDBET_&Year. 
        FBZ_BEDRAG_&Year.  
        ;
        
    RUN;

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach;
