/*
Met dit programma voeren we manipulaties uit op de NIC data
Voor alle lijnen met gelijke info voor karakteristieken worden gegevens voor aantal dagen en bedragen opgeteld en
wordt de vroegste begindatum en de laatste einddatum weerhouden
*/
/*Zet gebruikersopties*/
%let LIB1       = D_nic08;                    /*bibliotheek waar NIC-gegevens staan*/
%let SubFile1   = nic_081;
%let SubFile2   = nic_082;
%let SubFile3   = nic_083;
%let SubFile4   = nic_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_NIC;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    /*Start processing data of a given quarter*/
    DATA NICBasis;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;
    /*Sort by variables that can be squeezed*/
    PROC SORT DATA=NICBasis;
        BY gecodeerd_insz stelsel srt_dagen srt_uitkering aard_uitkering samenst_gezin;
    RUN;

    /*Count number of times individuals appear with more than one line in basic file*/        
    PROC FREQ DATA=NICBasis NOPRINT;
        TABLES  gecodeerd_insz / OUT=OutFreq;
    RUN;    
    PROC FREQ DATA=OutFreq(RENAME=(COUNT=NumTimes));
        TABLES  NumTimes / OUT=OutFreq1;
    RUN;    

    /*Manipulate data to squeeze lines*/
    DATA ManipDate;
        SET NICBasis;
        BY gecodeerd_insz stelsel srt_dagen srt_uitkering aard_uitkering samenst_gezin;

        RETAIN AantDagen SumBedrag BegDatum EndDatum 0;
        /*Start summing values*/
        IF FIRST.gecodeerd_insz OR FIRST.stelsel OR FIRST.srt_dagen OR FIRST.srt_uitkering OR FIRST.aard_uitkering OR FIRST.samenst_gezin THEN DO;
            BegDatum     = begindatum;
            EndDatum     = einddatum;
            AantDagen    = input(aantal_dagen_ao, 8.);
            SumBedrag    = bedrag         ;
        END;    
        ELSE DO;
            IF begindatum LT BegDatum AND begindatum NE . THEN BegDatum = begindatum;
            IF einddatum  GT EndDatum AND einddatum  NE . THEN EndDatum = einddatum;
            AantDagen    = AantDagen + input(aantal_dagen_ao, 8.);
            SumBedrag    = SumBedrag + bedrag         ;
        END;
        IF LAST.gecodeerd_insz OR LAST.stelsel OR LAST.srt_dagen OR LAST.srt_uitkering OR LAST.aard_uitkering OR LAST.samenst_gezin THEN OUTPUT;
    RUN;

    /*Count number of times individuals appear with more than one line in the squeezed file*/        
    PROC FREQ DATA=ManipDate NOPRINT;
        TABLES  gecodeerd_insz / OUT=OutFreq;
    RUN; 
    PROC FREQ DATA=OutFreq(RENAME=(COUNT=NumTimes));
        TABLES  NumTimes / OUT=OutFreq1;
    RUN;    

    /*Write final output file*/
    DATA &LIB2..&ResFile;

        SET ManipDate;

        LABEL GECODEERD_INSZ    = "Geanonimiseerd identificatienummer van het individu";
        
        /*Rename variables*/
        %DateManip(BegDatum,NIC_BEGDATUM_&Year.);
        %DateManip(EndDatum,NIC_ENDDATUM_&Year.);
        NIC_DAGENAO_&Year.  =  AantDagen;      
        %NomValManip(SumBedrag,NIC_BEDRAG_&Year.,10);
        NIC_STELSEL_&Year.  =  stelsel;        
        NIC_SRTDAGEN_&Year. =  srt_dagen;      
        NIC_SRTUITK_&Year.  =  srt_uitkering;  
        NIC_AARDUITK_&Year. =  aard_uitkering; 
        NIC_TYPEGEZI_&Year. =  samenst_gezin;  
        /*Label variables*/
        LABEL NIC_BEGDATUM_&Year. = "Begindatum ziekte (&Year.)"; 
        LABEL NIC_ENDDATUM_&Year. = "Einddatum ziekte (&Year.)";
        LABEL NIC_DAGENAO_&Year.  = "Aantal dagen arbeidsongeschiktheid (&Year.)";
        LABEL NIC_BEDRAG_&Year.   = "Betaald bedrag aan uitkeringen (&Year.)";
        LABEL NIC_STELSEL_&Year.  = "Stelsel waarin het recht geklasseerd wordt (&Year.)";
        LABEL NIC_SRTDAGEN_&Year. = "Soort dagen (PAO, zwangerschap, ...) (&Year.)";
        LABEL NIC_SRTUITK_&Year.  = "Soort uitkering (&Year.)";
        LABEL NIC_AARDUITK_&Year. = "Aard uitkering (&Year.)";
        LABEL NIC_TYPEGEZI_&Year. = "Samenstelling gezin (&Year.)";

        KEEP
        GECODEERD_INSZ    
        NIC_SRTDAGEN_&Year. 
        NIC_STELSEL_&Year.  
        NIC_DAGENAO_&Year.  
        NIC_BEGDATUM_&Year. 
        NIC_ENDDATUM_&Year. 
        NIC_BEDRAG_&Year.   
        ;
        
    RUN;

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach;
