/*
Met dit programma voeren we manipulaties uit op de PODMI data
Voor alle lijnen met gelijke info voor een aantal karakteristieken worden bedragen opgeteld en
wordt de vroegste begindatum en de laatste einddatum weerhouden
*/
/*Zet gebruikersopties*/
%let LIB1       = D_mi08;                    /*bibliotheek waar POD MI-gegevens staan*/
%let SubFile1   = podmi_081;
%let SubFile2   = podmi_082;
%let SubFile3   = podmi_083;
%let SubFile4   = podmi_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_PODMI;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    /*Start processing data of a given quarter*/
    DATA PODMIBasis;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;

    /*Sort by variables that can be squeezed*/
    /*Merk op: we laten typamt_id vallen om gegevens voldoende samen te drukken
      met typamt_id kan je het onderscheid maken tussen een gewone betaling en een regularisatie van een
      vroegere betaling*/
    PROC SORT DATA=PODMIBasis;
        BY gecodeerd_insz cat_id cat_cnt_id sts_id budart_id legislation thp_id;
    RUN;

    /*Count number of times individuals appear with more than one line in basic file*/        
    PROC FREQ DATA=PODMIBasis NOPRINT;
        TABLES  gecodeerd_insz / OUT=OutFreq;
    RUN;
    PROC FREQ DATA=OutFreq(RENAME=(COUNT=NumTimes));
        TABLES  NumTimes / OUT=OutFreq1;
    RUN;    

    /*Manipulate data to squeeze lines*/
    DATA ManipDate;
        SET PODMIBasis;
        BY gecodeerd_insz cat_id cat_cnt_id sts_id budart_id legislation thp_id;

        RETAIN SumBedrag BegDatum EndDatum 0;
        /*Start summing values*/
        IF FIRST.gecodeerd_insz OR FIRST.cat_id OR FIRST.cat_cnt_id OR FIRST.sts_id OR FIRST.budart_id OR FIRST.legislation OR FIRST.thp_id THEN DO;
            BegDatum     = dpay1stday;
            EndDatum     = dpaylstday;
            SumBedrag    = epaydtlstt;
        END;    
        ELSE DO;
            IF dpay1stday LT BegDatum AND dpay1stday NE . THEN BegDatum = dpay1stday;
            IF dpaylstday GT EndDatum AND dpaylstday NE . THEN EndDatum = dpaylstday;
            SumBedrag    = SumBedrag + epaydtlstt;
        END;
        IF LAST.gecodeerd_insz OR LAST.cat_id OR LAST.cat_cnt_id OR LAST.sts_id OR LAST.budart_id OR LAST.legislation OR LAST.thp_id THEN OUTPUT;
    RUN;

    /*Count number of times individuals appear with more than one line in the squeezed file*/        
    PROC FREQ DATA=ManipDate NOPRINT;
        TABLES  gecodeerd_insz / OUT=OutFreq;
    RUN; 
    PROC FREQ DATA=OutFreq(RENAME=(COUNT=NumTimes));
        TABLES  NumTimes / OUT=OutFreq1;
    RUN;    

    /*Write final output file*/
    DATA &LIB2..&ResFile;

        SET ManipDate;

        LABEL GECODEERD_INSZ    = "Geanonimiseerd identificatienummer van het individu";

        /*Rename variables*/
        %DateManip(BegDatum,PODMI_BEGDATUM_&Year.);
        %DateManip(EndDatum,PODMI_ENDDATUM_&Year.);
        %NomValManip(SumBedrag,PODMI_BEDRAG_&Year.,10);
        PODMI_CATID_&Year.      = cat_id;       
        PODMI_CATCNTID_&Year.   = cat_cnt_id;       
        PODMI_STSID_&Year.      = sts_id;       
        PODMI_BUDART_&Year.     = budart_id;       
        PODMI_LEGIS_&Year.      = legislation;       
        PODMI_THP_&Year.        = thp_id;       
        /*Label variables*/
        LABEL PODMI_BEGDATUM_&Year.   = "Begindatum betaling recht POD MI (&Year.)";      
        LABEL PODMI_ENDDATUM_&Year.   = "Einddatum betaling recht POD MI (&Year.)";       
        LABEL PODMI_BEDRAG_&Year.     = "Bedrag betaling recht POD MI (&Year.)";        
        LABEL PODMI_CATID_&Year.      = "Gezinscategorie voor bepaling recht POD MI (&Year.)";        
        LABEL PODMI_CATCNTID_&Year.   = "Gezinscategorie tot dewelke het individu gerekend wordt voor telling recht POD MI (&Year.)"; 
        LABEL PODMI_STSID_&Year.      = "Statuut van begunstigde van de financile steun equivalent aan het leefloon (&Year.)"; 
        LABEL PODMI_BUDART_&Year.     = "Percentage en omschrijving van de terugbetaling door de Staat aan de OCMWs (begrotingsartikel) (&Year.)"; 
        LABEL PODMI_LEGIS_&Year.      = "Wetgeving van toepassing voor bepaling recht (&Year.)"; 
        LABEL PODMI_THP_&Year.        = "Soort maatschappelijke hulpverlening toegekend krachtens de wet van 2 april 1965 (&Year.)"; 
        
        KEEP
        GECODEERD_INSZ    
        PODMI_BEDRAG_&Year.    
        PODMI_BUDART_&Year.    
        PODMI_LEGIS_&Year.       
        PODMI_CATID_&Year.   
        PODMI_CATCNTID_&Year.   
        PODMI_STSID_&Year.   
        PODMI_THP_&Year.     
        PODMI_BEGDATUM_&Year. 
        PODMI_ENDDATUM_&Year. 
        ;
        
    RUN;

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;


%MEND ForEach;
%ForEach;
