/*
Met dit programma voeren we manipulaties uit op persoonsgegevens uit het DWH AM&SB met het oog 
op de aanmaak van een input dataset voor MIMOSIS.
    1. Random selectie-indicator wordt toegevoegd vanuit andere file
    2. Ontbrekende gezinshoofden worden ingevuld
    3. Huishoudnummer wordt aangemaakt
    4. Geboortedatum wordt omgezet om enkel maand en jaargegeven over te houden
    5. Een aantal variabelen worden toegevoegd zonder verdere manipulatie
    6. Individuele en steekproefgewichten worden toegevoegd
    7. een aantal tests worden uitgevoerd
*/
/*Zet bibliotheek en output-filenaam*/
%let LIB1       = D_insz08;             /*bibliotheek waar persoonsgegevens staan*/
%let SUBFILE1   = nis_084;              /*bestand met persoonsgegevens*/
%let SUBFILE3   = minirn_084;           /*bestand met gegevens miniRN*/
%let LIB2       = MIMOSIS;              /*bibliotheek met mimosis-gegevens*/
%let SUBFILE2   = mim2008_sample;   /*bestand met te gebruiken steekproef-nummers*/
%let RESFILE    = mim2008_PopChars_RR;          /*bestandsnaam van de file met gemanipuleerde gegevens*/
%let EEJJK      = 20084;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Maak variabele aan die aangeeft of het individu deel uitmaakte van de random steekproeftrekking en
manipuleer gezinshoofd en bijhorende relatiecode*/
DATA HH_Head;
    MERGE   &LIB1..&SUBFILE1 (In=InA                                        RENAME = (insz = gecodeerd_insz insz_ref = gecodeerd_insz_ref))
            &LIB2..&SUBFILE2 (In=InB                                        RENAME = (insz = gecodeerd_insz))
            &LIB1..&SUBFILE3 (In=InC KEEP = insz d_geboor geslacht codnis   RENAME = (insz = gecodeerd_insz d_geboor = gbdatum geslacht = gender codnis = wplaats))
            ;
    BY gecodeerd_insz;
    IF inb=1 and (ina=1 OR inc=1);
    /*random selectie*/
    NAREGNIS_RND_SLCT = 0;
    /*Merk op: er zit een individu in de random selectie-file dat niet in de persoonsgegevens zit: Hoe kan dat*/
    /*referentiepersoon*/
    NAREGNIS_REFPERS = gecodeerd_insz_ref;
    NAREGNIS_RELATION = RELATIE;
    /*indien gezinshoofd ongekend is, is het individu zelf het gezinshoofd en wordt verder verondersteld
    dat het om een alleenstaand indivdu gaat*/
    IF gecodeerd_insz_ref EQ "" THEN DO;
        NAREGNIS_REFPERS = gecodeerd_insz;
        NAREGNIS_RELATION = 1;
    END;    
    /*indien gezinshoofd gekend is, is relatiecode altijd gelijk aan 1*/
    IF gecodeerd_insz_ref EQ gecodeerd_insz THEN NAREGNIS_RELATION = 1;
    /*Duid ook aan of iemand gezinshoofd is in numerieke variabele*/
    NAREGNIS_HEADOFHH = 0;
    IF NAREGNIS_RELATION EQ 1 THEN NAREGNIS_HEADOFHH = 1;
    /*Vul ontbrekende gegevens in op basis van MiniRN*/
    IF InB EQ 0 THEN DO;
        d_geboor = gbdatum;
        geslacht = gender;
        codnis   = wplaats;
    END;        
    DROP gbdatum gender wplaats;
RUN;
/*Maak unieke huishoudidentificator aan*/
PROC SORT DATA=HH_Head;
    BY NAREGNIS_REFPERS;
RUN;
DATA HH_Num;
    SET HH_Head(KEEP=NAREGNIS_REFPERS);
    BY NAREGNIS_REFPERS;
    IF LAST.NAREGNIS_REFPERS THEN OUTPUT;
RUN;
DATA HH_Num;
    SET HH_Num;
    BY NAREGNIS_REFPERS;
    NAREGNIS_HH_ID = _N_;
RUN;
/*Voeg huishoudidentificator toe aan basisdataset en tel aantal huishoudens*/
DATA HH_Head;
    MERGE HH_Head HH_Num;
    BY NAREGNIS_REFPERS;
RUN;
/*Maak geboortemaand en jaar aan en voeg DROPANAL variabele toe*/
DATA HH_Head;
    SET HH_Head;
    DROPANAL = 0;   
    LENGTH NAREGNIS_DATBIRTH $7.;
    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;
    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(d_geboor),4.);
    IF YEAR(d_geboor) EQ . THEN DO;
        DROPANAL    = 1;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(d_geboor) LT 1     OR  MONTH(d_geboor) EQ .    THEN MAAND = "  ";
    IF MONTH(d_geboor) GE 1     AND MONTH(d_geboor) LT 10   THEN MAAND = "0" || PUT(MONTH(d_geboor),1.);
    IF MONTH(d_geboor) GE 10    AND MONTH(d_geboor) LT 13   THEN MAAND = PUT(MONTH(d_geboor),2.);
    IF MONTH(d_geboor) GE 13                                THEN MAAND = "  ";
    NAREGNIS_DATBIRTH = MAAND || "-" || JAAR;
    /*Merk op: Kunnen ontbrekende waarden voor geboortedatum ingevuld worden op basis van andere bronnen? Zo ja, welke?
    Is nu gebeurd op basis van miniRn*/
RUN;
/*Voeg variabelen toe die niet worden aangepast*/
DATA HH_Head;
    SET HH_Head;
    NAREGNIS_SEX        = GESLACHT;
    NAREGNIS_COMMUNIT   = CODNIS;
    NAREGNIS_TYPEHH     = type_huishouden;
    NAREGNIS_COLL       = 0;
    IF NAREGNIS_RELATION EQ 20 THEN NAREGNIS_COLL = 1;
    NAREGNIS_LIPRO = LIPRO;
    /*Merk op: Kunnen ontbrekende waarden voor relatiecode, geslacht en gemeente ingevuld worden op basis van andere bronnen? Zo ja, welke?
    Is nu gebeurd op basis van miniRn voor geslacht en gemeente*/
RUN;
/*Voeg labels toe aan nieuw aangemaakte variabelen*/
DATA HH_Head;
    SET HH_Head; 
    LABEL GECODEERD_INSZ      = "Geanonimiseerd identificatienummer van het individu";
    LABEL NAREGNIS_HH_ID      = "Geanonimiseerd identificatienummer van het gezin waartoe het individu behoort";
    LABEL NAREGNIS_HEADOFHH   = "Aanduiding of het individu op 1 januari &Year gezinshoofd is van het gezin waartoe het individu behoort";
    LABEL NAREGNIS_DATBIRTH   = "Geboortedatum van het individu in jaar en maand";
    LABEL DROPANAL            = "Een waarde 1 in deze variabele geeft aan dat het individu best niet opgenomen wordt in de analyse";
    LABEL NAREGNIS_REFPERS    = "Geanonimiseerd identificatienummer van de referentiepersoon van het gezin waartoe het individu behoort";
    LABEL NAREGNIS_RELATION   = "Verband tussen het individu en het huishoudhoofd op 1 januari &Year";
    LABEL NAREGNIS_SEX        = "Geslacht van het individu op 1 januari &Year";
    LABEL NAREGNIS_COMMUNIT   = "NIS gemeentecode van de woonplaats waar het individu op 1 januari &Year woonde";
    LABEL NAREGNIS_TYPEHH     = "Typologie van het gezin waartoe het individu behoort op 1 januari &Year";
    LABEL NAREGNIS_COLL       = "Aanduiding of het gezin waartoe het individu op 1 januari &Year behoort een collectief gezin is";
    LABEL NAREGNIS_LIPRO      = "Typologie van het individu op basis van eigenschappen van het gezin waartoe het individu behoort op 1 januari &Year";
    LABEL NAREGNIS_RND_SLCT   = "Aanduiding of het individu geselecteerd werd bij het trekken van de steekproef (= ja of nee)";
    /*Merk op: gewenste variabelen die later eventueel nog toevoegd kunnen worden op basis van bijkomende info*/
    NAREGNIS_CIVIL            = 0;
    LABEL NAREGNIS_CIVIL      = "Burgerlijke staat van het individu op 1 januari &Year";
    NAREGNIS_REGIO            = 0;
    LABEL NAREGNIS_REGIO      = "Aanduiding van de regio waarin het individu woont op 1 januari &Year (op basis van de gemeentecode die opgegeven wordt als verblijfsgemeente van het gezin)";
    NAREGNIS_DIM_MUN          = 0;
    LABEL NAREGNIS_DIM_MUN    = "Omvang van de gemeente waarin het individu woont op 1 januari &Year (op basis van de gemeentecode die opgegeven wordt als verblijfsgemeente van het gezin) ";
    /*aanmaak gewichten voorlopig geschrapt*/
    MIMOSIS_WEIGHT = 30;
    HH_Weights = 20;
    LABEL MIMOSIS_WEIGHT      = "Steekproefgewicht dat corrigeert op individueel niveau voor non random sampling van sampling units";
    LABEL HH_Weights          = "Gewicht van het privaat sociologisch gezin tot hetwelk het individu behoort nodig om resltaten op huishoudniveau op te hogen tot het niveau van de totale gezinspopulatie";
RUN;

/*Merk op:
Binnen n gezin kunnen meerdere gezinshoofden voorkomen op basis van de relatiecode
Binnen n gezin kan een gezinshoofd meerdere partners hebben
Indien dit het geval zou zijn worden deze gevallen aangepast in de FAMREL module van MIMOSIS*/
DATA &LIB2..&ResFile;
    SET HH_Head; 
    KEEP
    GECODEERD_INSZ      
    NAREGNIS_REFPERS    
    NAREGNIS_HH_ID      
    NAREGNIS_RND_SLCT   
    NAREGNIS_RELATION   
    NAREGNIS_HEADOFHH   
    NAREGNIS_DATBIRTH   
    NAREGNIS_SEX        
    NAREGNIS_COMMUNIT   
    NAREGNIS_TYPEHH     
    NAREGNIS_COLL       
    NAREGNIS_LIPRO      
    NAREGNIS_CIVIL      
    ;
RUN;    

data &LIB2..&ResFile.;
	set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz
								    NAREGNIS_REFPERS = insz_ref));
run;

proc sort data = &LIB2..&ResFile.; by insz; run;
