/*
Met dit programma voeren we manipulaties uit op RIZIV data
Gegevens uit het betalingsbestand worden gescheiden naar stelsel en enkel de meest voorkomende betalinscode wordt weerhouden
andere nominale gegevens zoals betalingsbedrag en vergoede dagen worden wel opgeteld over de andere lijnen
Van de gegevens uit het basisbestand wordt enkel de lijn met de meest recente ziektedatum weerhouden.
*/
/*Zet gebruikersopties*/
%let LIB1       = D_riz08;                    /*bibliotheek waar RIZIV-gegevens staan*/
%let SubFile1   = riz_081;
%let SubFile2   = riz_082;
%let SubFile3   = riz_083;
%let SubFile4   = riz_084;
%let SubBet1    = riz_betalingen_081;
%let SubBet2    = riz_betalingen_082;
%let SubBet3    = riz_betalingen_083;
%let SubBet4    = riz_betalingen_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RIZIV;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        PROC SORT DATA = &LIB1..&&SubBet&I OUT = &&SubBet&I; 
            BY insz; 
        RUN;
        DATA Quart&I;
            MERGE   &&SubBet&I          (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7    (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    DATA RIZIVBet;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;

    /*personen in invaliditeit*/
    DATA RIZIVSub;
        SET RIZIVBet(WHERE=(Stelsel="1" or Stelsel="2"));;
    RUN;    
    PROC SORT DATA=RIZIVSub;
        BY gecodeerd_insz betalingscode;
    RUN;
    DATA RIZIVSub;
        SET RIZIVSub;
        BY gecodeerd_insz betalingscode;
        RETAIN aantcodes sumpdag sumpbedrag 0;
        IF first.betalingscode THEN DO;
            aantcodes  = 1              ;
            sumpdag    = vergoede_dagen ;
            sumpbedrag = bedrag         ;
        END;    
        ELSE DO;
            aantcodes  + 1              ;
            sumpdag    + vergoede_dagen ;
            sumpbedrag + bedrag         ;    
        END;
        IF last.betalingscode THEN OUTPUT;
    RUN;
    PROC SORT DATA=RIZIVSub;
        BY gecodeerd_insz aantcodes;
    RUN;
    DATA RIZIVSub;
        SET RIZIVSub;
        BY gecodeerd_insz;
        RETAIN sumpdagNew sumpbedragNew 0;
        IF first.gecodeerd_insz THEN DO;
            sumpdagNew    = sumpdag    ;
            sumpbedragNew = sumpbedrag ;
        END;    
        ELSE DO;
            sumpdagNew    + sumpdag    ;
            sumpbedragNew + sumpbedrag ;    
        END;
        IF last.gecodeerd_insz THEN OUTPUT;
    RUN;
    DATA RIZIV_TOT_INVAL;

        SET RIZIVSub;

        LENGTH RIZIVINA_STELSEL_INVAL_&Year.  $ 7         ;
        LENGTH RIZIVINA_BETALING_INVAL_&Year. $ 7         ;    

        RIZIVINA_STELSEL_INVAL_&Year.   = stelsel          ;
        RIZIVINA_BETALING_INVAL_&Year.  = betalingscode    ;
        RIZIVINA_VERGOEDE_INVAL_&Year.  = sumpdagNew       ;
        %NomValManip(sumpbedragNew,RIZIVINA_BEDRAG_INVAL_&Year.,10);
        %DateManip(Aanvangsdatum_betalingsperiode,RIZIVINA_AANVANGS_INVAL_&Year.);
        %DateManip(Einddatum_betalingsperiode,RIZIVINA_EINDBETA_INVAL_&Year.);

        LABEL RIZIVINA_STELSEL_INVAL_&Year.   = "Code die type verzekering weergeeft (persoon in invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_BETALING_INVAL_&Year.  = "Betalingscode (persoon in invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_VERGOEDE_INVAL_&Year.  = "Vergoede dagen (persoon in invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_BEDRAG_INVAL_&Year.    = "Uitgekeerd bedrag (persoon in invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_AANVANGS_INVAL_&Year.  = "Aanvangsdatum van de betalingsperiode (persoon in invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_EINDBETA_INVAL_&Year.  = "Einddatum van de betalingsperiode (persoon in invaliditeit) (&Year.)"; 
        
        KEEP 
        gecodeerd_insz 
        RIZIVINA_BETALING_INVAL_&Year.  
        RIZIVINA_STELSEL_INVAL_&Year.  
        RIZIVINA_AANVANGS_INVAL_&Year.  
        RIZIVINA_EINDBETA_INVAL_&Year.
        RIZIVINA_BEDRAG_INVAL_&Year.  
        RIZIVINA_VERGOEDE_INVAL_&Year.  
        ;
    RUN;
    PROC SORT DATA=RIZIV_TOT_INVAL;
        BY gecodeerd_insz;
    RUN;   

    /*personen in zwangerschapsverlof gedurende periode van invaliditeit*/
    DATA RIZIVSub;
        SET RIZIVBet(WHERE=(Stelsel="3" or Stelsel="4"));;
    RUN;    
    PROC SORT DATA=RIZIVSub;
        BY gecodeerd_insz betalingscode;
    RUN;
    DATA RIZIVSub;
        SET RIZIVSub;
        BY gecodeerd_insz betalingscode;
        RETAIN aantcodes sumpdag sumpbedrag 0;
        IF first.betalingscode THEN DO;
            aantcodes  = 1              ;
            sumpdag    = vergoede_dagen ;
            sumpbedrag = bedrag         ;
        END;    
        ELSE DO;
            aantcodes  + 1              ;
            sumpdag    + vergoede_dagen ;
            sumpbedrag + bedrag         ;    
        END;
        IF last.betalingscode THEN OUTPUT;
    RUN;
    PROC SORT DATA=RIZIVSub;
        BY gecodeerd_insz aantcodes;
    RUN;
    DATA RIZIVSub;
        SET RIZIVSub;
        BY gecodeerd_insz;
        RETAIN sumpdagNew sumpbedragNew 0;
        IF first.gecodeerd_insz THEN DO;
            sumpdagNew    = sumpdag    ;
            sumpbedragNew = sumpbedrag ;
        END;    
        ELSE DO;
            sumpdagNew    + sumpdag    ;
            sumpbedragNew + sumpbedrag ;    
        END;
        IF last.gecodeerd_insz THEN OUTPUT;
    RUN;
    DATA RIZIV_TOT_MAT;
        SET RIZIVSub;

        LENGTH RIZIVINA_STELSEL_MAT_&Year.  $ 7         ;
        LENGTH RIZIVINA_BETALING_MAT_&Year. $ 7         ;    

        RIZIVINA_STELSEL_MAT_&Year.  = stelsel          ;
        RIZIVINA_BETALING_MAT_&Year. = betalingscode    ;
        RIZIVINA_VERGOEDE_MAT_&Year. = sumpdagNew       ;
        %NomValManip(sumpbedragNew,RIZIVINA_BEDRAG_MAT_&Year.,10);
        %DateManip(Aanvangsdatum_betalingsperiode,RIZIVINA_AANVANGS_MAT_&Year.);
        %DateManip(Einddatum_betalingsperiode,RIZIVINA_EINDBETA_MAT_&Year.);

        LABEL RIZIVINA_STELSEL_MAT_&Year.   = "Code die type verzekering weergeeft (zwangerschapsverlof gedurende invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_BETALING_MAT_&Year.  = "Betalingscode (zwangerschapsverlof gedurende invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_VERGOEDE_MAT_&Year.  = "Vergoede dagen (zwangerschapsverlof gedurende invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_BEDRAG_MAT_&Year.    = "Uitgekeerd bedrag (zwangerschapsverlof gedurende invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_AANVANGS_MAT_&Year.  = "Aanvangsdatum van de betalingsperiode (zwangerschapsverlof gedurende invaliditeit) (&Year.)"; 
        LABEL RIZIVINA_EINDBETA_MAT_&Year.  = "Einddatum van de betalingsperiode (zwangerschapsverlof gedurende invaliditeit) (&Year.)"; 
 

        KEEP 
        gecodeerd_insz 
        RIZIVINA_BETALING_MAT_&Year.  
        RIZIVINA_STELSEL_MAT_&Year.  
        RIZIVINA_AANVANGS_MAT_&Year.  
        RIZIVINA_EINDBETA_MAT_&Year.
        RIZIVINA_BEDRAG_MAT_&Year.   
        RIZIVINA_VERGOEDE_MAT_&Year.  
        ;
    RUN;
    PROC SORT DATA=RIZIV_TOT_MAT;
        BY gecodeerd_insz;
    RUN; 

    /*Reduceer basisgegevens RIZIV tot n lijn per individu*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I  (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7    (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    DATA RIZIVBasis;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;
    PROC SORT DATA=RIZIVBasis;
        BY GECODEERD_INSZ b_ziekte;
    RUN;
    DATA RIZIVBasis;
        SET RIZIVBasis (drop = jaar);
        BY  GECODEERD_INSZ;

        LENGTH CUMUL_&Year.  $ 7         ;
 
        CUMUL_&Year.    = cumul;
        %DateManip(b_ziekte,B_ZIEKTE_&Year.);
        AANWIJZ_&Year.  = aanwijz;

        LABEL CUMUL_&Year.    = "Code die aangeeft of persoon die uitkering ontvangt wegens invaliditeit ook een uitkering ontvangt naar aanleiding van arbeidsongeval, beroepsziekte of ongeval (&Year.)";                        
        LABEL B_ZIEKTE_&Year. = "Begindatum primaire arbeidsongeschiktheid (&Year.)";                                                                                                                                             
        LABEL AANWIJZ_&Year.  = "Gegevens met betrekking tot de gezinslast en de arbeidsmarktpositie van het individu op het moment van de aanvraag tot erkenning invaliditeit (&Year.)";                                         

        KEEP 
        gecodeerd_insz 
        B_ZIEKTE_&Year. 
        CUMUL_&Year. 
        AANWIJZ_&Year.
        ;
        
        /*Veronderstelling is dat bij herzieningen de meest recente ziekte-datum de meest betrouwbare is
        en/of dat ingevulde waarde gekozen wordt in gevallen waar voor sommige lijnen data zouden ontbreken*/
        IF LAST.gecodeerd_insz THEN OUTPUT;
    RUN;

    /*Voeg onderdelen samen in n file*/
    DATA &LIB2..&ResFile;
        MERGE RIZIV_TOT_INVAL RIZIV_TOT_MAT RIZIVBasis; 
        BY gecodeerd_insz;
    RUN; 

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach;
