/*
Met dit programma voeren we manipulaties uit op de RKW data
Gegevens worden geordend op het niveau van het rechtgevend kind
Per lijn wordt een begindatum en een einddatum van betaling bepaald, een rechthebbende en
een bijslagtrekkende
*/
/*Zet gebruikersopties*/
%let LIB1       = D_rkw08;                    /*bibliotheek waar RKW-gegevens staan*/
%let SubFile1   = rkw_081;
%let SubFile2   = rkw_082;
%let SubFile3   = rkw_083;
%let SubFile4   = rkw_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RKW;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    /*Start processing data of a given quarter*/
    DATA RKWBasis;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;

    /*Check values of Hoed that appear to guarantee that all cases are covered*/        
    PROC FREQ DATA=RKWBasis;
        TABLES  hoed / OUT=OutFreq;
    RUN;    

    /*Steek gegevens in drie verschillende files*/
    DATA RKW_RH;
        SET RKWBasis(WHERE=(hoed="101"));

        gecodeerd_insz_RH   = gecodeerd_insz;
        KEEP kbf bureau dossier beg_bet eind_bet gecodeerd_insz_RH;
    RUN;
    /*Manipulate data to squeeze lines*/
    PROC SORT DATA=RKW_RH;
        BY gecodeerd_insz_RH kbf bureau dossier;
    RUN;
    DATA RKW_RH;
        SET RKW_RH;
        BY gecodeerd_insz_RH kbf bureau dossier;
    
        RETAIN beg_bet_RH eind_bet_RH 0;

        /*Start summing values*/
        IF FIRST.gecodeerd_insz_RH OR FIRST.kbf OR FIRST.bureau OR FIRST.dossier THEN DO;
            beg_bet_RH = beg_bet;
            eind_bet_RH = eind_bet;
        END;    
        ELSE DO;
            IF beg_bet LT beg_bet_RH    AND beg_bet NE .    THEN beg_bet_RH = beg_bet;
            IF eind_bet GT eind_bet_RH  AND eind_bet NE .   THEN eind_bet_RH = eind_bet;
        END;
        IF LAST.gecodeerd_insz_RH OR LAST.kbf OR LAST.bureau OR LAST.dossier THEN OUTPUT;

        KEEP kbf bureau dossier beg_bet_RH eind_bet_RH gecodeerd_insz_RH;
    RUN;

    DATA RKW_BT;
        SET RKWBasis(WHERE=(hoed="102" OR hoed="103"));

        gecodeerd_insz_BT   = gecodeerd_insz;
        KEEP kbf bureau dossier beg_bet eind_bet gecodeerd_insz_BT;
    RUN;
    /*Manipulate data to squeeze lines*/
    PROC SORT DATA=RKW_BT;
        BY gecodeerd_insz_BT kbf bureau dossier;
    RUN;
    DATA RKW_BT;
        SET RKW_BT;
        BY gecodeerd_insz_BT kbf bureau dossier;
    
        RETAIN beg_bet_BT eind_bet_BT 0;

        /*Start summing values*/
        IF FIRST.gecodeerd_insz_BT OR FIRST.kbf OR FIRST.bureau OR FIRST.dossier THEN DO;
            beg_bet_BT = beg_bet;
            eind_bet_BT = eind_bet;
        END;    
        ELSE DO;
            IF beg_bet LT beg_bet_BT    AND beg_bet NE .    THEN beg_bet_BT = beg_bet;
            IF eind_bet GT eind_bet_BT  AND eind_bet NE .   THEN eind_bet_BT = eind_bet;
        END;
        IF LAST.gecodeerd_insz_BT OR LAST.kbf OR LAST.bureau OR LAST.dossier THEN OUTPUT;

        KEEP kbf bureau dossier beg_bet_BT eind_bet_BT gecodeerd_insz_BT;
    RUN;

    DATA RKW_RG;
        SET RKWBasis(WHERE=(hoed="104"));

        gecodeerd_insz_RG   = gecodeerd_insz;
        KEEP kbf bureau dossier beg_bet eind_bet gecodeerd_insz_RG;
    RUN;
    /*Manipulate data to squeeze lines*/
    PROC SORT DATA=RKW_RG;
        BY gecodeerd_insz_RG kbf bureau dossier;
    RUN;
    DATA RKW_RG;
        SET RKW_RG;
        BY gecodeerd_insz_RG kbf bureau dossier;
    
        RETAIN beg_bet_RG eind_bet_RG 0;

        /*Start summing values*/
        IF FIRST.gecodeerd_insz_RG OR FIRST.kbf OR FIRST.bureau OR FIRST.dossier THEN DO;
            beg_bet_RG = beg_bet;
            eind_bet_RG = eind_bet;
        END;    
        ELSE DO;
            IF beg_bet LT beg_bet_RG    AND beg_bet NE .    THEN beg_bet_RG = beg_bet;
            IF eind_bet GT eind_bet_RG  AND eind_bet NE .   THEN eind_bet_RG = eind_bet;
        END;
        IF LAST.gecodeerd_insz_RG OR LAST.kbf OR LAST.bureau OR LAST.dossier THEN OUTPUT;

        KEEP kbf bureau dossier beg_bet_RG eind_bet_RG gecodeerd_insz_RG;
    RUN;

    /*Test of er kinderen zijn die met meer dan n lijn voorkomen in het rechtgevende bestand*/
    /*Zo ja, druk gegevens samen*/
    /*controleer frequentie van voorkomen*/
    PROC FREQ DATA=RKW_RG(WHERE=(gecodeerd_insz_RG <> 'geen ind gevonden' AND gecodeerd_insz_RG <> 'niet in populatie'))  NOPRINT;
        TABLES  gecodeerd_insz_RG / OUT=test;
    RUN;
    DATA teldub;
        SET test(WHERE=(COUNT>1));
    RUN;
    /*steek aantal keer dat een individu meer dan 1 keer voorkomt in een macro-variabele
      veronderstelling is dat dubbels of meer meerdere betalingslijnen zijn in hetzelfde dossier met over de lijnen
      verschillende betalingsdatums*/  
    %LET dsid = %sysfunc(open(teldub));
    %LET nuseobs = %sysfunc(attrn(&dsid,nobs));
    %LET rc = %sysfunc(close(&dsid));
    /*discrimineer bij uitvoering tussen gevallen met en zonder dubbels*/
    %IF %EVAL(&nuseobs) NE 0 %THEN %DO;
        PROC SORT DATA=RKW_RG;
            BY gecodeerd_insz_RG;
        RUN;
        DATA ManipDate;
            SET RKW_RG;
            BY gecodeerd_insz_RG;

            RETAIN BegDatum EndDatum 0;
            /*Start inspection values*/
            IF FIRST.gecodeerd_insz_RG THEN DO;
                BegDatum = beg_bet_RG;
                EndDatum = eind_bet_RG;
            END;    
            ELSE DO;
                IF beg_bet_RG  LT BegDatum AND beg_bet_RG  NE . THEN BegDatum = beg_bet_RG;
                IF eind_bet_RG LT EndDatum AND eind_bet_RG NE . THEN EndDatum = eind_bet_RG;
            END;
            KEEP kbf bureau dossier BegDatum EndDatum gecodeerd_insz_RG;
            IF LAST.gecodeerd_insz_RG OR gecodeerd_insz_RG EQ 'geen ind gevonden' OR gecodeerd_insz_RG EQ 'niet in populatie' THEN OUTPUT;
        RUN;
        DATA RKW_RG;
            SET ManipDate(RENAME=(BegDatum=beg_bet_RG EndDatum=eind_bet_RG));
        RUN;                
    %END;

    /*Voeg drie bestanden samen*/
    /*Merk op: niet alle gegevens zijn gekend in drie bestanden
    PROC SQL noprint;
        CREATE TABLE Samen as
        SELECT *
        FROM RKW_RH, RKW_BT, RKW_RG
        WHERE  RKW_RH.kbf_bureau_dossier = RKW_BT.kbf_bureau_dossier = RKW_RG.kbf_bureau_dossier;
    QUIT;
    */
    PROC SORT DATA=RKW_RH;
        BY kbf bureau dossier;
    RUN;            
    PROC SORT DATA=RKW_BT;
        BY kbf bureau dossier;
    RUN;            
    PROC SORT DATA=RKW_RG;
        BY kbf bureau dossier;
    RUN;            

    DATA &LIB2..&ResFile;

        MERGE RKW_RH(in=In_A) RKW_BT(in=In_B) RKW_RG(in=In_C);
        BY kbf bureau dossier;

        /*Fill in missing values*/
        beg_bet = beg_bet_RG;
        eind_bet = eind_bet_RG;
        IF beg_bet = . THEN beg_bet = beg_bet_BT;
        IF eind_bet = . THEN eind_bet = eind_bet_BT;
        IF beg_bet = . THEN beg_bet = beg_bet_RH;
        IF eind_bet = . THEN eind_bet = eind_bet_RH;

        /*Maak variabele gewaarborgde kinderbijslag aan*/
        RKW_GWB_&Year. = 0;
        IF Bureau EQ "09915" OR Bureau EQ "09918" THEN RKW_GWB_&Year. = 1; 

        /*Rename variables*/
        %DateManip(beg_bet,BEGINRKW_&Year.);
        %DateManip(eind_bet,EINDRKW_&Year.);
        RH_RKW_&Year.       = gecodeerd_insz_RH;
        BT_RKW_&Year.       = gecodeerd_insz_BT;
        RG_RKW_&Year.       = gecodeerd_insz_RG;

        /*Label variables*/
        LABEL BEGINRKW_&Year. = "Begindatum betaling kinderbijslag voor kind in een ander stelsel dan dat van de zelfstandigen (&Year.)";                                              
        LABEL EINDRKW_&Year.  = "Einddatum betaling kinderbijslag voor kind in een ander stelsel dan dat van de zelfstandigen (&Year.)"; 
        LABEL RH_RKW_&Year.   = "Geanonimiseerd identificatienummer van het individu dat recht op kinderbijslag opent in een ander stelsel dan dat van de zelfstandigen (&Year.)"; 
        LABEL BT_RKW_&Year.   = "Geanonimiseerd identificatienummer van het individu dat kinderbijslag ontvangt in een ander stelsel dan dat van de zelfstandigen (&Year.)"; 
        LABEL RG_RKW_&Year.   = "Geanonimiseerd identificatienummer van het kind dat recht op kinderbijslag genereert in een ander stelsel dan dat van de zelfstandigen (&Year.)"; 
        LABEL RKW_GWB_&Year.  = "Individu ontvangt kinderbijslag in stelsel van gewaarborgde kinderbijslag (&Year.)"; 

        KEEP
        BEGINRKW_&Year.  
        EINDRKW_&Year.   
        RH_RKW_&Year.    
        BT_RKW_&Year.    
        RG_RKW_&Year. 
        RKW_GWB_&Year.
        ;
        
    RUN;            
/*
    data &LIB2..&ResFile.;
        set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
    run;
*/
    data &LIB2..&ResFile.;
        set &LIB2..&ResFile. (rename = (RH_RKW_&Year. = insz_rh
                                        BT_RKW_&Year. = insz_bt
                                        RG_RKW_&Year. = insz_rg));
    run;

%MEND ForEach;
%ForEach;
