/*
Met dit programma worden oude Rijksregister gegevens opgehaald voor nog in leven zijnde individuen
*/
/*Zet gebruikersopties*/
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let SubFile1   = ms_geg_rr_ed_01;
%let Year       = 2002;


/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

 /*   %DO I = 1 %to 1;*/

        DATA &LIB2..mim2008_&SubFile1._New;

            MERGE   &LIB2..&SubFile1 (In=InA rename = (insz_refpers = insz_ref))
                    &LIB2..&SubFile7   (In=InB keep = insz)
            ;
            BY /*gecodeerd_*/insz;
            IF ina=1 and inb=1;

            /*Maak variabelen*/
/*            NAREGNIS_REFPERS_&Year = insz_ref;*/
            NAREGNIS_HH_ID_&Year = HH_ID;
            NAREGNIS_RND_SLCT_&Year = RND_SLCT;
            NAREGNIS_RELATION_&Year = RELATION;
            NAREGNIS_CIVIL_&Year = CIVIL;

            /*Geef labels aan variabelen*/
            LABEL INSZ_REF /*NAREGNIS_REFPERS_&Year*/ = "Geanonimiseerd identificatienummer van de referentiepersoon in het gezin op 1 januari &Year";
            LABEL NAREGNIS_HH_ID_&Year = "Geanonimiseerd identificatienummer van het gezin waartoe het individu behoort op 1 januari &Year";
            LABEL NAREGNIS_RND_SLCT_&Year = "Aanduiding of het individu geselecteerd werd bij het trekken van de steekproef (= ja of nee) op 1 januari &Year";
            LABEL NAREGNIS_RELATION_&Year = "Verband tussen het individu en het huishoudhoofd op 1 januari &Year";
            LABEL NAREGNIS_CIVIL_&Year = "Burgerlijke staat van het individu op 1 januari &Year";
            
            KEEP
            INSZ 
            INSZ_REF /*NAREGNIS_REFPERS_&Year*/
            NAREGNIS_HH_ID_&Year
            NAREGNIS_RND_SLCT_&Year
            NAREGNIS_RELATION_&Year
            NAREGNIS_CIVIL_&Year
            ;
            
        RUN;            

 /*   %END;*/

%MEND ForEach;
%ForEach;
