/*
Met dit programma voeren we manipulaties uit op de RSVZ data
*/
/*Zet gebruikersopties*/
%let LIB1       = D_rsvz08;                    /*bibliotheek waar RSVZ-gegevens staan*/
%let SubFile1   = rsvz_081;
%let SubFile2   = rsvz_082;
%let SubFile3   = rsvz_083;
%let SubFile4   = rsvz_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RSVZ;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I (In=InA drop = jaar rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;            
    %END;
    /*Start processing data of a given quarter*/
    DATA RSVZBasis;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;
    /*Sort by variables that can be squeezed*/
    PROC SORT DATA=RSVZBasis;
        BY gecodeerd_insz beroepc nacec bijdcat hoed;
    RUN;

    /*Maak eindbestand*/
    DATA &LIB2..&ResFile;
        SET RSVZBasis;
        BY gecodeerd_insz beroepc nacec bijdcat hoed;

        RETAIN BEGAANSC_R SCHAANSC_R;

        /*Start defining dates*/
        IF FIRST.gecodeerd_insz OR FIRST.beroepc OR FIRST.nacec OR FIRST.bijdcat OR FIRST.hoed THEN DO;
            BEGAANSC_R = begaansc;
            SCHAANSC_R = schaansc;
        END;    
        ELSE DO;
            IF begaansc LT BEGAANSC_R AND begaansc NE . THEN BEGAANSC_R = begaansc;
            IF schaansc GT SCHAANSC_R AND schaansc NE . THEN SCHAANSC_R = schaansc;
        END;

        /*Rename variables*/
        %DateManip(BEGAANSC_R,BEGAANSC_&Year.);
        %DateManip(SCHAANSC_R,SCHAANSC_&Year.);
        BEROEPC_&Year.  = beroepc; 
        NACEC_&Year.    = substr(nacec,1,2);   
        BIJDCAT_&Year.  = bijdcat; 
        HOEDRSVZ_&Year. = hoed;    

        /*Label variables*/
        LABEL GECODEERD_INSZ    = "Geanonimiseerd identificatienummer van het individu";
        LABEL BEROEPC_&Year.    = "Beroepscode bij RSVZ (&Year.)";
        LABEL NACEC_&Year.      = "Activiteit van een zelfstandige weergegeven onder de vorm van een NACE code (&Year.)";
        LABEL BIJDCAT_&Year.    = "Code van de bijdragecategorie bij RSVZ (in hoofdberoep, bijberoep, na pensioenleeftijd, ...) (&Year.)";
        LABEL HOEDRSVZ_&Year.   = "Code van hoedanigheid bij RSVZ (&Year.)";
        LABEL BEGAANSC_&Year.   = "Aanvangsdatum van de aansluiting bij de RSVZ (&Year.)";
        LABEL SCHAANSC_&Year.   = "Datum van het einde van de aansluiting bij de RSVZ (&Year.)";

        IF LAST.gecodeerd_insz OR LAST.beroepc OR LAST.nacec OR LAST.bijdcat OR LAST.hoed THEN OUTPUT;

        KEEP
        GECODEERD_INSZ 
        BEROEPC_&Year.  
        NACEC_&Year.    
        BIJDCAT_&Year.  
        HOEDRSVZ_&Year. 
        BEGAANSC_&Year. 
        SCHAANSC_&Year. 
        ;

    RUN;            

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach;
