/*
Met dit programma voeren we manipulaties uit op de RSVZ-kinderbijslag data
In feite alleen relabelen van de variabelen want data zijn al georganiseerd op het
niveau van het rechtgevende kind
Dubbels komen enkel voor waarde 'geen ind gevonden' of 'niet in populatie'
*/
/*Zet gebruikersopties*/
%let LIB1       = D_rsvz08;                    /*bibliotheek waar RSVZ-gegevens staan*/
%let SubFile1   = rsvz_kb_081;
%let SubFile2   = rsvz_kb_082;
%let SubFile3   = rsvz_kb_083;
%let SubFile4   = rsvz_kb_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RSVZ_KB;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        PROC SORT DATA=&LIB1..&&SubFile&I out = &&SubFile&I;
            BY insz_rg;
        RUN;            
        DATA Quart&I;
            MERGE   &&SubFile&I         (In=InA rename = (insz_rg  = gecodeerd_insz))
                    &LIB2..&SubFile7    (In=InB rename = (insz     = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
            InQuart&I = 1;
            gecodeerd_insz_rg = gecodeerd_insz;
            DROP gecodeerd_insz;
        RUN;            
    %END;

    /*Start processing data*/
    DATA RSVZ_KBBasis (drop = insz_RH insz_BT);
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
        gecodeerd_insz_RH = insz_RH;
        gecodeerd_insz_BT = insz_BT;
    RUN;
    PROC SORT DATA=RSVZ_KBBasis;
        BY gecodeerd_insz_RH gecodeerd_insz_BT gecodeerd_insz_RG;
    RUN;            

    /*Check values of Hoed that appear to guarantee that all cases are covered*/        
    PROC FREQ DATA=RSVZ_KBBasis;
        TABLES  bt_hoed / OUT=OutFreq;
    RUN;    

    /*Maak tussenbestand*/
    DATA TussenFile;
        SET RSVZ_KBBasis;
        BY gecodeerd_insz_RH gecodeerd_insz_BT gecodeerd_insz_RG;

        RETAIN Kwart1 Kwart2 Kwart3 Kwart4 " ";
        
        IF FIRST.gecodeerd_insz_RH OR FIRST.gecodeerd_insz_BT OR FIRST.gecodeerd_insz_RG THEN DO;
            Kwart1 = "0";
            Kwart2 = "0"; 
            Kwart3 = "0"; 
            Kwart4 = "0";
            IF InQuart1 EQ 1 THEN Kwart1 = "1";
            IF InQuart2 EQ 1 THEN Kwart2 = "1";
            IF InQuart3 EQ 1 THEN Kwart3 = "1";
            IF InQuart4 EQ 1 THEN Kwart4 = "1";
        END;    
        ELSE DO;
            IF InQuart1 EQ 1 THEN Kwart1 = "1";
            IF InQuart2 EQ 1 THEN Kwart2 = "1";
            IF InQuart3 EQ 1 THEN Kwart3 = "1";
            IF InQuart4 EQ 1 THEN Kwart4 = "1";
        END;        

        IF LAST.gecodeerd_insz_RH OR LAST.gecodeerd_insz_BT OR LAST.gecodeerd_insz_RG THEN OUTPUT;
        
    RUN;            

    /*Maak eindbestand*/
    DATA &LIB2..&ResFile;

        SET TussenFile;

        LENGTH QUART_RSVZKB_&Year. $4.;
        
        QUART_RSVZKB_&Year. = Kwart1 || Kwart2 || Kwart3 || Kwart4;

        /*Rename variables*/
        BT_HOED_&Year.       = bt_hoed;
        RH_RSVZ_&Year.       = gecodeerd_insz_RH;
        BT_RSVZ_&Year.       = gecodeerd_insz_BT;
        RG_RSVZ_&Year.       = gecodeerd_insz_RG;

        /*Label variables*/
        LABEL BT_HOED_&Year. = "Hoedanigheid van de persoon die kinderbijslag ontvangt in het stelsel der zelfstandigen (&Year.)";
        LABEL RH_RSVZ_&Year. = "Geanonimiseerd identificatienummer van het individu dat recht op kinderbijslag opent in het stelsel der zelfstandigen (&Year.)"; 
        LABEL BT_RSVZ_&Year. = "Geanonimiseerd identificatienummer van het individu dat kinderbijslag ontvangt in het stelsel der zelfstandigen (&Year.)"; 
        LABEL RG_RSVZ_&Year. = "Geanonimiseerd identificatienummer van het individu dat kinderbijslag genereert in het stelsel der zelfstandigen (&Year.)"; 
        LABEL QUART_RSVZKB_&Year.   = "Aanduiding van de kwartalen van het jaar &Year. waarin de gegeven combinatie geobserveerd wordt in RSVZ kinderbijslagbestanden";

        KEEP
        BT_HOED_&Year.
        RH_RSVZ_&Year.
        BT_RSVZ_&Year.
        RG_RSVZ_&Year.
        QUART_RSVZKB_&Year.
        ;

    RUN;            

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (RH_RSVZ_2008 = insz_rh
										BT_RSVZ_2008 = insz_bt
										RG_RSVZ_2008 = insz_rg));
	run;

%MEND ForEach;
%ForEach;




