/*
Met dit programma worden een aantal kwartaalgegevens van de RSZPPO samengevoegd in n bestand
*/
/*Zet gebruikersopties*/
%let LIB1       = D_ppo08;                    /*bibliotheek waar RSZPPO-gegevens staan*/
%let SubFile1   = ppo_084;
%let SubFile2   = stbf_084;
%let SubFile3   = cuppo_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RSZPPOQuart;
%let EEJJK      = 20084;
%let AantFiles  = 3;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*selecteer gegevens RSZPPO basis*/
    DATA MIMOSIS&EEJJ._ppo_&JJK.;
        MERGE   &LIB1..&SubFile1   (In=InA rename = (insz = gecodeerd_insz))
                &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
        ;
        BY gecodeerd_insz;
        IF ina=1 and inb=1;
    RUN;
    PROC SORT DATA=MIMOSIS&EEJJ._ppo_&JJK.;
        BY wrpid OccupationSequenceNbr;
    RUN;

    /*selecteer gegevens RSZPPO Statbasef*/
    DATA MIMOSIS&EEJJ._ppo_stbf_&JJK.;
        SET &LIB1..&SubFile2;
    RUN;
    PROC SORT DATA=MIMOSIS&EEJJ._ppo_stbf_&JJK.;
        BY wrpid OccupationSequenceNbr;
    RUN;

    /*Merge deelbestanden op basis van wrpid, OccupationSequenceNbr*/
    DATA COMBIN;
        MERGE MIMOSIS&EEJJ._ppo_&JJK. MIMOSIS&EEJJ._ppo_stbf_&JJK.; 
        BY wrpid OccupationSequenceNbr;
    RUN;
    PROC SORT DATA=COMBIN;
        BY matric cattra;
    RUN;

    /*selecteer gegevens RSZPPO Cuppo*/
    DATA MIMOSIS&EEJJ._ppo_cuppo_&JJK.;
        SET &LIB1..&SubFile3;
    RUN;
    PROC SORT DATA=MIMOSIS&EEJJ._ppo_cuppo_&JJK.;
        BY matric cattra;
    RUN;

    /*Merge deelbestanden op basis van matric, cattra*/
    DATA COMBIN;
        MERGE COMBIN MIMOSIS&EEJJ._ppo_cuppo_&JJK.; 
        BY matric cattra;
    RUN;

    /*Write final output file*/
    DATA &LIB2..&ResFile;

        SET COMBIN;
        
        /*Rename variables*/        
        cattra_&EEJJK.                    = cattra;
        insemp_&EEJJK.                    = insemp;
        codimp_&EEJJK.                    = codimp;
        codtra_&EEJJK.                    = codtra;
        clatraApl_&EEJJK.                 = clatraApl;
        clatr2Apl_&EEJJK.                 = clatr2Apl;
        clatraOnss_&EEJJK.                = clatraOnss;
        clatr2Onss_&EEJJK.                = clatr2Onss;
        days_pc1_&EEJJK.                  = days_pc1;
        hrs_pc1_&EEJJK.                   = hrs_pc1;
        days_pc10_&EEJJK.                 = days_pc10;
        hrs_pc10_&EEJJK.                  = hrs_pc10;
        days_pc21_&EEJJK.                 = days_pc21;
        hrs_pc21_&EEJJK.                  = hrs_pc21;
        days_pc23_&EEJJK.                 = days_pc23;
        hrs_pc23_&EEJJK.                  = hrs_pc23;
        days_pc30_&EEJJK.                 = days_pc30;
        hrs_pc30_&EEJJK.                  = hrs_pc30;
        days_pc50_&EEJJK.                 = days_pc50;
        hrs_pc50_&EEJJK.                  = hrs_pc50;
        days_pc60_&EEJJK.                 = days_pc60;
        hrs_pc60_&EEJJK.                  = hrs_pc60;
        days_pc70_&EEJJK.                 = days_pc70;
        hrs_pc70_&EEJJK.                  = hrs_pc70;
        t_prest_&EEJJK.                   = t_prest;
        apltauxpt_&EEJJK.                 = apltauxpt;
        aplcatept_&EEJJK.                 = aplcatept;
        eqtpsp_paid_&EEJJK.               = eqtpsp_paid;
        eqtpsp_similar_&EEJJK.            = eqtpsp_similar;
        tauxaa_&EEJJK.                    = tauxaa;
        eqtpsp_other_&EEJJK.              = eqtpsp_other;
        t_dnrb_&EEJJK.                    = t_dnrb;
        r_exclus_&EEJJK.                  = r_exclus;
        maatman_&EEJJK.                   = maatman;
        MeanWorkingHours_&EEJJK.          = MeanWorkingHours;
        RefMeanWorkingHours_&EEJJK.       = RefMeanWorkingHours;
        regime_&EEJJK.                    = regime;
        LMS_CH_&EEJJK.                    = LMS_CH;
        Cot_CH_&EEJJK.                    = Cot_CH;
        Cot_SPC_&EEJJK.                   = Cot_SPC;
        LMS_FMP_&EEJJK.                   = LMS_FMP;
        Cot_FMP_&EEJJK.                   = Cot_FMP;
        LMS_IX_&EEJJK.                    = LMS_IX;
        LMS_DPV_&EEJJK.                   = LMS_DPV;
        COT_DPV_&EEJJK.                   = COT_DPV;
        LMS_DPV2_&EEJJK.                  = LMS_DPV2;
        COT_DPV2_&EEJJK.                  = COT_DPV2;
        %NomValManip(sal100,sal100_&EEJJK.,10);
        %NomValManip(salcot,salcot_&EEJJK.,10);
        %NomValManip(primes,primes_&EEJJK.,10);
        /*vehsoc_&EEJJK.                    = vehsoc;*/
        %NomValManip(vehsoc,vehsoc_&EEJJK.,10);
        /*
        rem417_&EEJJK.                    = rem417;
        rem817_&EEJJK.                    = rem817;
        */
        %NomValManip(rembase,rembase_&EEJJK.,10);
        %NomValManip(preavi,preavi_&EEJJK.,10);
        saljrs_&EEJJK.                    = saljrs;
        function_&EEJJK.                  = function;
        %NomValManip(cotpat,cotpat_&EEJJK.,10);
        %NomValManip(cotper,cotper_&EEJJK.,10);
        %NomValManip(mntdedwr,mntdedwr_&EEJJK.,10);
        %NomValManip(mntdedocc,mntdedocc_&EEJJK.,10);
        TypeContract_&EEJJK.              = TypeContract;
        Status_&EEJJK.                    = Status;
        Notfro_&EEJJK.                    = Notfro;
        Reorg_&EEJJK.                     = Reorg;
        Promo_&EEJJK.                     = Promo;
        Appr_&EEJJK.                      = Appr;
        RemMth_&EEJJK.                    = RemMth;
        TT_&EEJJK.                        = TT;
        days_just_&EEJJK.                 = days_just;
        illness_&EEJJK.                   = illness;
        Maribel_&EEJJK.                   = Maribel;
        %NomValManip(STremAmt,STremAmt_&EEJJK.,10);
        STndays_&EEJJK.                   = STndays;
/*        STctrAmt_&EEJJK.                  = STctrAmt;*/
		%NomValManip(STctrAmt,STctrAmt_&EEJJK.,10);
        LMS_671_&EEJJK.                   = LMS_671;
        LMS_672_&EEJJK.                   = LMS_672;
        Cot_671_&EEJJK.                   = Cot_671;
        Cot_672_&EEJJK.                   = Cot_672;
        Days_671_&EEJJK.                  = Days_671;
        Days_672_&EEJJK.                  = Days_672;
        COT_CS_&EEJJK.                    = COT_CS;
        COT_PX_&EEJJK.                    = COT_PX;
        CuCOT_DPV_&EEJJK.                 = CuCOT_DPV;
        CuCOT_DPV2_&EEJJK.                = CuCOT_DPV2;
        CuLMS_DPV_&EEJJK.                 = CuLMS_DPV;
        CuLMS_DPV2_&EEJJK.                = CuLMS_DPV2;
        LMS_CS_&EEJJK.                    = LMS_CS;
        LMS_PX_&EEJJK.                    = LMS_PX;
        matric_&EEJJK.                    = matric;
        OccupationSequenceNbr_&EEJJK.     = OccupationSequenceNbr;
        wrpid_&EEJJK.                     = wrpid;

        /*Label variables*/
        LABEL cattra_&EEJJK.                    = "Werkgeverscategorie (code voor vakantieregime niet-vastbenoemden, code voor pensioenstelsel vastbenoemden).";
        LABEL insemp_&EEJJK.                    = "NIS-code van de gemeente waar de aangesloten werkgever gevestigd is.";
        LABEL codimp_&EEJJK.                    = "Code van de dimensieklasse van de werkgever ";
        LABEL codtra_&EEJJK.                    = "Met het oog op een correcte inning van de socialezekerheidsbijdragen maakt deze variabele een onderscheid tussen handarbeiders, hoofdarbeiders, gesubsidieerde contractuelen, vastbenoemden,  ";
        LABEL clatraApl_&EEJJK.                 = "Groepering van de werknemerscodes in een aantal werknemersklassen.";
        LABEL clatr2Apl_&EEJJK.                 = "Gedetailleerde groepering van de werknemerscodes.";
        LABEL clatraOnss_&EEJJK.                = "Werknemersklasse ";
        LABEL clatr2Onss_&EEJJK.                = "Werknemersklasse speciaal ";
        LABEL days_pc1_&EEJJK.                  = "Aantal gepresteerde dagen met prestatiecodes 1, 2 en 301:";
        LABEL hrs_pc1_&EEJJK.                   = "Aantal gepresteerde uren met prestatiecodes 1, 2 en 301:";
        LABEL days_pc10_&EEJJK.                 = "Aantal gepresteerde dagen met prestatiecodes 10, 11 en 13:";
        LABEL hrs_pc10_&EEJJK.                  = "Aantal gepresteerde uren met prestatiecodes 10, 11 en 13:";
        LABEL days_pc21_&EEJJK.                 = "Aantal gepresteerde dagen met prestatiecodes 21, 22, 24 en 25:";
        LABEL hrs_pc21_&EEJJK.                  = "Aantal gepresteerde uren met prestatiecodes 21, 22, 24 en 25:";
        LABEL days_pc23_&EEJJK.                 = "Aantal gepresteerde dagen met prestatiecode 23 (=carensdag).";
        LABEL hrs_pc23_&EEJJK.                  = "Aantal gepresteerde uren met prestatiecode 23 (=carensdag).";
        LABEL days_pc30_&EEJJK.                 = "Aantal gepresteerde dagen met prestatiecode 30 (=alle gegevens met betrekking tot de arbeidstijd waarvoor de werkgever geen loon of vergoeding betaalt, met uitzondering van deze die onder een andere code vermeld worden).";
        LABEL hrs_pc30_&EEJJK.                  = "Aantal gepresteerde uren met prestatiecode 30 (=alle gegevens met betrekking tot de arbeidstijd waarvoor de werkgever geen loon of vergoeding betaalt, met uitzondering van deze die onder een andere code vermeld worden).";
        LABEL days_pc50_&EEJJK.                 = "Aantal gepresteerde dagen met prestatiecodes 50, 51 en 52:";
        LABEL hrs_pc50_&EEJJK.                  = "Aantal gepresteerde uren met prestatiecodes 50, 51 en 52:";
        LABEL days_pc60_&EEJJK.                 = "Aantal gepresteerde dagen met prestatiecodes 60 en 61:";
        LABEL hrs_pc60_&EEJJK.                  = "Aantal gepresteerde uren met prestatiecodes 60 en 61:";
        LABEL days_pc70_&EEJJK.                 = "Aantal gepresteerde dagen met prestatiecode = 70-71-72-73-74:";
        LABEL hrs_pc70_&EEJJK.                  = "Aantal gepresteerde uren met prestatiecodes 70, 71, 72, 73 en 74:";
        LABEL t_prest_&EEJJK.                   = "Code (voltijds, deeltijds, speciaal) die informatie verstrekt over het arbeidsregime op de laatste dag van het kwartaal ";
        LABEL apltauxpt_&EEJJK.                 = "Percentage deeltijds ";
        LABEL aplcatept_&EEJJK.                 = "Code van de klasse deeltijdarbeid";
        LABEL eqtpsp_paid_&EEJJK.               = "Voltijds equivalent exclusief gelijkgestelde dagen";
        LABEL eqtpsp_similar_&EEJJK.            = "Voltijds equivalent exclusief betaalde dagen";
        LABEL tauxaa_&EEJJK.                    = "Voltijds equivalent inclusief gelijkgestelde dagen";
        LABEL eqtpsp_other_&EEJJK.              = "Voltijds equivalent andere dagen";
        LABEL t_dnrb_&EEJJK.                    = "type dnrb";
        LABEL r_exclus_&EEJJK.                  = "Code die aanduidt of een record moet worden meegeteld of niet. ";
        LABEL maatman_&EEJJK.                   = "maatman";
        LABEL MeanWorkingHours_&EEJJK.          = "Aantal uren dat de betrokken werknemer wekelijks dient te presteren volgens het arbeidscontract";
        LABEL RefMeanWorkingHours_&EEJJK.       = "Aantal wekelijks te presteren uren door de maatman.";
        LABEL regime_&EEJJK.                    = "Aantal dagen per week van het arbeidsstelsel van de werknemer. ";
        LABEL LMS_CH_&EEJJK.                    = "Loonmassa waarop de bijdrage van 1,69% betreffende werkloosheid berekend wordt";
        LABEL Cot_CH_&EEJJK.                    = "Werkloosheidsbijdrage van 1,69%";
        LABEL Cot_SPC_&EEJJK.                   = "Bijzondere bijdrage Sociale Zekerheid";
        LABEL LMS_FMP_&EEJJK.                   = "Loonmassa waarop de bijdrage op vergoeding voor periode van tijdelijke arbeidsongeschiktheid wegens (erkende) beroepsziekte berekend wordt";
        LABEL Cot_FMP_&EEJJK.                   = "Bijdrage op vergoeding voor periode van tijdelijke arbeidsongeschiktheid wegens (erkende) beroepsziekte";
        LABEL LMS_IX_&EEJJK.                    = "Loonmassa vrijgesteld van bijdragen";
        LABEL LMS_DPV_&EEJJK.                   = "Loonmassa dubbel vakantiegeld";
        LABEL COT_DPV_&EEJJK.                   = "Bijdrage betaald op dubbel vakantiegeld";
        LABEL LMS_DPV2_&EEJJK.                  = "Loonmassa aanvullend vakantiegeld";
        LABEL COT_DPV2_&EEJJK.                  = "Bijdrage betaald op aanvullend vakantiegeld";
        LABEL sal100_&EEJJK.                    = "Bedrag van de gewone bezoldiging in het kwartaal.";
        LABEL salcot_&EEJJK.                    = "Bedrag van de bijdrageplichtige loonmassa inzake sociale zekerheid in het kwartaal";
        LABEL primes_&EEJJK.                    = "Het bedrag van de bezoldigingen in het kwartaal die niet rechtstreeks verbonden zijn met de prestaties gedurende een bepaald kwartaal.";
        LABEL vehsoc_&EEJJK.                    = "Voordeel betreffende het individueel en persoonlijk gebruik van een voertuig ter beschikking gesteld door een werkgever";
        /*
        LABEL rem417_&EEJJK.                    = "Eindejaarspremie vrijgesteld van bijdragen";
        LABEL rem817_&EEJJK.                    = "Eindejaarspremie onderworpen aan bijdragen";
        */
        LABEL rembase_&EEJJK.                   = "Basisloon";
        LABEL preavi_&EEJJK.                    = "Het bedrag van de verbrekingsvergoeding aangegeven bij de RSZPPO.";
        LABEL saljrs_&EEJJK.                    = "Gemiddeld dagloon";
        LABEL function_&EEJJK.                  = "Enkel voor werknemers die volledig of gedeeltelijk bezoldigd worden met fooien of bedieningsgeld ";
        LABEL cotpat_&EEJJK.                    = "Patronale bijdragen Sociale Zekerheid";
        LABEL cotper_&EEJJK.                    = "Persoonlijke bijdragen Sociale Zekerheid";
        LABEL mntdedwr_&EEJJK.                  = "Bedrag bijdragevermindering werkgever";
        LABEL mntdedocc_&EEJJK.                 = "Bedrag bijdragevermindering werknemer";
        LABEL TypeContract_&EEJJK.              = "Voltijds of deeltijds";
        LABEL Status_&EEJJK.                    = "Statuut van de werknemer";
        LABEL Notfro_&EEJJK.                    = "Code die aangeeft of de arbeidsprestatie al dan niet door een grensarbeider uitgevoerd wordt.";
        LABEL Reorg_&EEJJK.                     = "Maatregel tot reorganisatie van de arbeidstijd.";
        LABEL Promo_&EEJJK.                     = "Code van de maatregelen ter bevordering van de werkgelegenheid";
        LABEL Appr_&EEJJK.                      = "Code die toelaat de verschillende soorten leerlingen te onderscheiden.";
        LABEL RemMth_&EEJJK.                    = "Code die aanduidt of de werknemer betaald wordt volgens een bijzondere bezoldigingswijze";
        LABEL TT_&EEJJK.                        = "Code die aanduidt of de leerkracht betaald wordt in tienden of twaalfden";
        LABEL days_just_&EEJJK.                 = "Code die aanduidt dat de werknemer in de loop van het kwartaal tewerkgesteld is volgens een bijzondere arbeidscyclus.";
        LABEL illness_&EEJJK.                   = "Datum waarop het vastbenoemde personeelslid sinds zes maanden of meer ziek is.";
        LABEL Maribel_&EEJJK.                   = "Code die aangeeft of de werknemer aangeworven werd in het kader van de sociale maribel.";
        LABEL STremAmt_&EEJJK.                  = "Loon student";
        LABEL STndays_&EEJJK.                   = "Aantal gepresteerde dagen door de student in het kwartaal";
        LABEL STctrAmt_&EEJJK.                  = "Bijdrage werknemer-student";
        LABEL LMS_671_&EEJJK.                   = "Refertebrutoloon (voor Ziekte-en Invaliditeitsuitkering) ontslagen statutaire werknemer";
        LABEL LMS_672_&EEJJK.                   = "Refertebrutoloon (voor werkloosheid) ontslagen statutaire werknemer";
        LABEL Cot_671_&EEJJK.                   = "Bijdrage (voor Ziekte-en Invaliditeitsuitkering) ontslagen statutaire werknemer";
        LABEL Cot_672_&EEJJK.                   = "Bijdrage (voor werkloosheid) ontslagen statutaire werknemer";
        LABEL Days_671_&EEJJK.                  = "Aantal werkdagen waarvoor de onderwerping aan sociale zekerheid gevraagd wordt.";
        LABEL Days_672_&EEJJK.                  = "Aantal werkdagen waarvoor de onderwerping aan sociale zekerheid gevraagd wordt.";
        LABEL COT_CS_&EEJJK.                    = "Solidariteitsbijdrage op het gebruik van een voertuig voor persoonlijke doeleinden of voor woon- werkverkeer";
        LABEL COT_PX_&EEJJK.                    = "Bijdrage op stortingen van werkgevers voor de vorming van een buitenwettelijk pensioen";
        LABEL CuCOT_DPV_&EEJJK.                 = "Bijdrage verschuldigd op het (dubbel) vakantiegeld met uitzondering van de mandatarissen en het politiepersoneel";
        LABEL CuCOT_DPV2_&EEJJK.                = "Bijdrage verschuldigd op het (dubbel) vakantiegeld van de mandatarissen en het politiepersoneel";
        LABEL CuLMS_DPV_&EEJJK.                 = "Loonmassa (dubbel) vakantiegeld met uitzondering van de mandatarissen en het politiepersoneel";
        LABEL CuLMS_DPV2_&EEJJK.                = "Loonmassa (dubbel) vakantiegeld van de mandatarissen en het politiepersoneel";
        LABEL LMS_CS_&EEJJK.                    = "Loonmassa solidariteitsbijdrage op het gebruik van een voertuig voor persoonlijke doeleinden of voor woon-werkverkeer";
        LABEL LMS_PX_&EEJJK.                    = "Loonmassa stortingen van werkgevers voor de vorming van een buitenwettelijk pensioen";
        LABEL matric_&EEJJK.                    = "gehercodeerde waarde van het inschrijvingsnummer van de werkgever";
        LABEL OccupationSequenceNbr_&EEJJK.     = "OccupationSequenceNbr: betekenisloos nummer gebruikt om gegevens te koppelen";
        LABEL wrpid_&EEJJK.                     = "wrpid: betekenisloos nummer gebruikt om gegevens te koppelen";


        /*Keep variables*/ 
        KEEP
        gecodeerd_insz
        cattra_&EEJJK.                    
        codimp_&EEJJK.                    
        codtra_&EEJJK.                    
        clatraApl_&EEJJK.                 
        clatr2Apl_&EEJJK.                 
        days_pc1_&EEJJK.                  
        hrs_pc1_&EEJJK.                   
        days_pc10_&EEJJK.                 
        hrs_pc10_&EEJJK.                  
        days_pc21_&EEJJK.                 
        hrs_pc21_&EEJJK.                  
        t_prest_&EEJJK.                   
        apltauxpt_&EEJJK.                 
        eqtpsp_paid_&EEJJK.               
        eqtpsp_similar_&EEJJK.            
        tauxaa_&EEJJK.                    
        r_exclus_&EEJJK.                  
        MeanWorkingHours_&EEJJK.          
        RefMeanWorkingHours_&EEJJK.       
        regime_&EEJJK.                    
        sal100_&EEJJK.                    
        salcot_&EEJJK.                    
        primes_&EEJJK.                    
        vehsoc_&EEJJK.                    
        preavi_&EEJJK.                    
        saljrs_&EEJJK.                    
        cotpat_&EEJJK.                    
        cotper_&EEJJK.                    
        mntdedwr_&EEJJK.                  
        mntdedocc_&EEJJK.                 
        Maribel_&EEJJK.                   
        STremAmt_&EEJJK.                  
        STndays_&EEJJK.                   
        STctrAmt_&EEJJK.                  
        matric_&EEJJK.                    
        maatman_&EEJJK.                   
        t_dnrb_&EEJJK.                    
        rembase_&EEJJK.                   
        ;
        
    RUN;

    /*Merk op: in vergelijking met het programma aangemaakt bij de KSZ worden nu geen gegevens meer ingelezen
    vanuit het bestand RSZPPO WG wegens niet beschikbaarheid van dit bestand.
    */

	proc sort data = &LIB2..&ResFile.; by gecodeerd_insz; run;

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach;

