/*
Met dit programma worden een aantal jaarvariabelen afgeleid op basis van de kwartaal RSZPPO data
Manipulatie wordt jaar per jaar uitgevoerd
Het programma moet gelanceerd worden voor jaren voorafgaand aan 2005 
Merk op:
De variabelen 
Vte Activte P_ur100a P_ur100b P_ur200 P_ur300 P_ur000
zijn noodzakelijk voor de bepaling van de te reconstrueren gegevens maar
zitten niet in de test-files. Die zouden dus voor een run nog eest moeten toegevoegd worden aan
de basis-files.

*/

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/

%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;

%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach(EEJJK);

    /*Zet gebruikersopties*/
    %let EEJJ       = %SUBSTR(&EEJJK,1,4);
    %let Year       = %SUBSTR(&EEJJK,1,4);
    %let JJK        = %SUBSTR(&EEJJK,3,3);
    %let JJ         = %SUBSTR(&EEJJK,3,2);
    %let LIB1       = D_PPO&JJ.;                    /*bibliotheek waar RSZPPO-gegevens staan*/
    %let SubFile1   = ppo_&JJ.1;
    %let SubFile2   = ppo_&JJ.2;
    %let SubFile3   = ppo_&JJ.3;
    %let SubFile4   = ppo_&JJ.4;
    %let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
    %let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
    %let ResFile    = mim2008_RSZPPOYear;
    %let AantFiles  = 4;

    /*Start loop over aantal files*/
    %DO I = 1 %to &AantFiles;
             
        /*Verwerk gegevens van een gegeven kwartaal*/
        DATA RSZBasis&I;

            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;

            /*Definieer groepen bepaling dubbel vakantiegeld*/
            GROEP_DV = 0;
            %IF %EVAL(&Year.) GT 2003 %THEN %DO;
                IF Wcatcd IN (102, 104, 106, 119, 130, 132, 144, 149, 164, 
                              166, 184, 191, 193, 195, 200, 202, 204, 206, 
                              219, 230, 232, 239, 242, 245, 250, 259, 260,
                              261, 262, 264, 266, 274, 275, 277, 284, 285, 
                              287, 291, 293, 295, 297, 731, 733, 735, 737, 
                              771, 773, 775, 777, 781, 783, 785, 787, 108, 
                              112, 113, 114, 115, 134, 208, 212, 213, 214, 
                              215, 229) THEN GROEP_DV = 1;
            %END;
            %ELSE %DO;            
                IF Wcatcd IN (102, 104, 106, 119, 130, 132, 144, 149, 164, 
                              166, 184, 191, 193, 195, 200, 202, 204, 206, 
                              219, 230, 232, 239, 242, 245, 250, 259, 260, 
                              261, 262, 264, 266, 274, 275, 277, 284, 285, 
                              287, 291, 293, 295, 297, 731, 733, 735, 737, 
                              771, 773, 775, 777, 781, 783, 785, 787) 
                              THEN GROEP_DV = 1;
            %END;
            IF GROEP_DV EQ 0 THEN GROEP_DV = 2;
            
            /*Schat dubbel vakantiegeld en bijdragen op dubbel vakantiegeld*/
            GeschatDubbelVakantieGeld = 0;
            BijzondereBijdrageDV = 0;
            IF GROEP_DV EQ 1 THEN DO;
                IF Activte NE 0 AND Activte NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((lmasamt)+(lmasamt)*((Vte-Activte)/Activte)));
                END;                    
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((lmasamt)+(lmasamt)*((Vte-Activte)/100)));
                END;                    
                BijzondereBijdrageDV        = 0.120755*GeschatDubbelVakantieGeld;
            END;
            IF GROEP_DV EQ 2 THEN DO;
                IF Activte NE 0 AND Activte NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((lmasamt)+(lmasamt)*((Vte-Activte)/Activte)));
                END;                    
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((lmasamt)+(lmasamt)*((Vte-Activte)/100)));
                END;                    
                BijzondereBijdrageDV        = 0.1307*GeschatDubbelVakantieGeld;
            END;
            
        RUN;
    
    %END;

    DATA Combin;
        SET
            %DO I = 1 %to &AantFiles;
                RSZBasis&I
            %END;
        ;

        /*Construeer later te behandelen variabelen*/
        IF lmasamt                      EQ . THEN lmasamt = 0;                  
        IF Preavi                       EQ . THEN Preavi = 0;                    
        IF bijdr                        EQ . THEN bijdr   = 0;                    
        IF GeschatDubbelVakantieGeld    EQ . THEN GeschatDubbelVakantieGeld = 0;   
        IF BijzondereBijdrageDV         EQ . THEN BijzondereBijdrageDV = 0;  
        IF P_dg100a EQ . THEN P_dg100a = 0;
        IF P_dg100b EQ . THEN P_dg100b = 0; 
        IF P_dg200  EQ . THEN P_dg200 = 0;  
        IF P_dg300  EQ . THEN P_dg300 = 0;  
        IF P_dg000  EQ . THEN P_dg000 = 0;  
        IF P_ur100a EQ . THEN P_ur100a = 0;
        IF P_ur100b EQ . THEN P_ur100b = 0; 
        IF P_ur200  EQ . THEN P_ur200 = 0;  
        IF P_ur300  EQ . THEN P_ur300 = 0;  
        IF P_ur000  EQ . THEN P_ur000 = 0;  
        RemunDay  = P_dg100a; 
        AssimDay  = P_dg100b;  
        OthDay    = P_dg200 + P_dg300 + P_dg000;
        RemunHour = P_ur100a; 
        AssimHour = P_ur100b;  
        OthHour   = P_ur200 + P_ur300 + P_ur000;
        
        KEEP 
        gecodeerd_insz
        lmasamt                     Preavi                  bijdr
        GeschatDubbelVakantieGeld   BijzondereBijdrageDV    saljrs
        RemunDay                    AssimDay                OthDay              
        RemunHour                   AssimHour               OthHour     
        ;
         
    RUN;
    
    PROC SORT DATA=Combin;
        BY gecodeerd_insz saljrs;
    RUN;
    
    DATA AggYear;
        SET Combin;
        BY gecodeerd_insz;
        RETAIN SumConcept1-SumConcept11 0;
    
        IF FIRST.gecodeerd_insz THEN DO;
            SumConcept1  = lmasamt;                      
            SumConcept2  = Preavi;          
            SumConcept3  = bijdr;
            SumConcept4  = GeschatDubbelVakantieGeld;  
            SumConcept5  = BijzondereBijdrageDV;   
            SumConcept6  = RemunDay;                   
            SumConcept7  = AssimDay;               
            SumConcept8  = OthDay;             
            SumConcept9  = RemunHour;                  
            SumConcept10 = AssimHour;              
            SumConcept11 = OthHour;    
        END;
        ELSE DO;
            SumConcept1  = SumConcept1  + lmasamt;                      
            SumConcept2  = SumConcept2  + Preavi;          
            SumConcept3  = SumConcept3  + bijdr;  
            SumConcept4  = SumConcept4  + GeschatDubbelVakantieGeld;  
            SumConcept5  = SumConcept5  + BijzondereBijdrageDV;   
            SumConcept6  = SumConcept6  + RemunDay;                   
            SumConcept7  = SumConcept7  + AssimDay;               
            SumConcept8  = SumConcept8  + OthDay;             
            SumConcept9  = SumConcept9  + RemunHour;                  
            SumConcept10 = SumConcept10 + AssimHour;              
            SumConcept11 = SumConcept11 + OthHour;    
        END;
        IF LAST.gecodeerd_insz THEN OUTPUT;
    RUN;

    /*Write final output file*/
    DATA &LIB2..&ResFile._&Year.;

        SET AggYear;
        
        /*Rename variables*/        
        lmasamt_&Year. =                      SumConcept1 ;
        Preavi_&Year. =                       SumConcept2 ;
        bijdr_&Year. =                        SumConcept3 ;
        %NomValManip(SumConcept4,GeschatDubbelVakantieGeld_&Year.,10);
        BijzondereBijdrageDV_&Year. =         SumConcept5 ;
        RemunDay_&Year. =                     SumConcept6 ;
        AssimDay_&Year. =                     SumConcept7 ;
        OthDay_&Year. =                       SumConcept8 ;
        RemunHour_&Year. =                    SumConcept9 ;
        AssimHour_&Year. =                    SumConcept10;
        OthHour_&Year. =                      SumConcept11; 
        saljrs_&Year. =                       saljrs      ;
        
        SumSal = lmasamt_&Year. + Preavi_&Year. ;
        %NomValManip(SumSal,SumSal_&Year.,10);

        /*Label amount variables*/
        LABEL lmasamt_&Year. =                     "Het bedrag van de gewone bezoldigingen op jaarbasis (som voor jaar = &Year)";
        LABEL Preavi_&Year. =                      "Verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL SumSal_&Year. =                      "Som gewone bezoldigingen, premies en verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL bijdr_&Year. =                       "Bedrag van de normale persoonlijke bijdrage en werkgeversbijdragen op basis van de bezoldigingen (som voor jaar = &Year)";
        LABEL GeschatDubbelVakantieGeld_&Year. =   "Dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL BijzondereBijdrageDV_&Year. =        "Bijzondere bijdrage op dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL RemunDay_&Year. =                    "Vergoede dagen (som voor jaar = &Year)";
        LABEL AssimDay_&Year. =                    "Gelijkgestelde dagen waarvoor vergoeding betaald wordt door werkgever (som voor jaar = &Year)";
        LABEL OthDay_&Year. =                      "Gelijkgestelde dagen waarvoor geen vergoeding betaald wordt door werkgever (som voor jaar = &Year)";
        LABEL RemunHour_&Year. =                   "Vergoede uren (som voor jaar = &Year)";
        LABEL AssimHour_&Year. =                   "Gelijkgestelde uren waarvoor vergoeding betaald wordt door werkgever (som voor jaar = &Year)";
        LABEL OthHour_&Year. =                     "Gelijkgestelde uren waarvoor geen vergoeding betaald wordt door werkgever (som voor jaar = &Year)"; 
        LABEL saljrs_&Year. =                      "Het gemiddeld dagloon (som voor jaar = &Year)";

        /*Keep nodige variabelen*/
        KEEP
        GECODEERD_INSZ 
        SumSal_&Year. 
        GeschatDubbelVakantieGeld_&Year.   
        RemunDay_&Year.                    
        AssimDay_&Year.                    
        RemunHour_&Year.                   
        AssimHour_&Year.                   
        saljrs_&Year.                      
        ;
    RUN;        

	data &LIB2..&ResFile._&Year.;
		set &LIB2..&ResFile._&Year. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;

%ForEach(20024);
%ForEach(20034);
%ForEach(20044);
