/*
Met dit programma worden een aantal jaarvariabelen afgeleid op basis van de kwartaal RSZPPO data
Manipulatie wordt jaar per jaar uitgevoerd
Het programma moet gelanceerd worden vanaf 2005 tot en met jaar x waar x+1 het jaar de steekproeftrekking is
Vermoedelijk zal x+1 2009 zijn (i.e. in het geval de steekproef op 1 januari 2009 getrokken wordt)

Merk op: voor persoonlijke bijdragen wordt nu een variabele uit het basisbestand genomen terwijl misschien
beter een variabele uit stbf genomen zou worden.

*/

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach(EEJJK);

    /*Zet gebruikersopties*/
    %let EEJJ       = %SUBSTR(&EEJJK,1,4);
    %let Year       = %SUBSTR(&EEJJK,1,4);
    %let JJK        = %SUBSTR(&EEJJK,3,3);
    %let JJ         = %SUBSTR(&EEJJK,3,2);
    %let LIB1       = D_PPO&JJ.;                    /*bibliotheek waar RSZPPO-gegevens staan*/
    %let SubFile1   = ppo_&JJ.1;
    %let SubFile2   = ppo_&JJ.2;
    %let SubFile3   = ppo_&JJ.3;
    %let SubFile4   = ppo_&JJ.4;
    %let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
    %let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
    %let ResFile    = mim2008_RSZPPOYear;
    %let AantFiles  = 4;

    /*Start loop over aantal files*/
    %DO I = 1 %to &AantFiles;
             
        /*Verwerk gegevens van een gegeven kwartaal*/
        DATA RSZBasis&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;

            /*Definieer groepen bepaling dubbel vakantiegeld*/
            GROEP_DV = 0;
            IF Cattra EQ 951 THEN GROEP_DV = 1; 
            IF Cattra NE 951 THEN GROEP_DV = 2; 

            /*Schat dubbel vakantiegeld en bijdragen op dubbel vakantiegeld*/
            GeschatDubbelVakantieGeld = 0;
            BijzondereBijdrageDV = 0;
            IF GROEP_DV EQ 1 THEN DO;
                IF eqtpsp_paid NE 0 AND eqtpsp_paid NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100)+(Sal100)*((tauxaa-eqtpsp_paid)/eqtpsp_paid)));
                END;                    
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100)+(Sal100)*((tauxaa-eqtpsp_paid)/100)));
                END;                    
                BijzondereBijdrageDV        = 0.120755*GeschatDubbelVakantieGeld;
            END;
            IF GROEP_DV EQ 2 THEN DO;
                IF eqtpsp_paid NE 0 AND eqtpsp_paid NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100)+(Sal100)*((tauxaa-eqtpsp_paid)/eqtpsp_paid)));
                END;                    
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100)+(Sal100)*((tauxaa-eqtpsp_paid)/100)));
                END;                    
                BijzondereBijdrageDV        = 0.1307*GeschatDubbelVakantieGeld;
            END;
            
        RUN;
    
    %END;

    DATA Combin;
        SET
            %DO I = 1 %to &AantFiles;
                RSZBasis&I
            %END;
        ;

        /*Construeer later te behandelen variabelen*/
        IF Sal100                       EQ . THEN Sal100 = 0;                  
        IF Primes                       EQ . THEN Primes = 0;                             
        IF Preavi                       EQ . THEN Preavi = 0;                    
        IF Cotper                       EQ . THEN Cotper = 0;                    
        IF mntdedwr                     EQ . THEN mntdedwr = 0;                 
        IF GeschatDubbelVakantieGeld    EQ . THEN GeschatDubbelVakantieGeld = 0;   
        IF BijzondereBijdrageDV         EQ . THEN BijzondereBijdrageDV = 0;  
        /*Merk op:
        We delen hier door 100 zonder dat de DWH documentatie expliciet stelt dat gegevens uitgedrukt zijn in 
        veelvoud van 100. Observatie van de data suggereert dat echter*/
        RemunDay                        = (days_pc1)/100;
        AssimDay                        = (days_pc10 + days_pc21)/100;  
        OthDay                          = (days_pc23 + days_pc30 + days_pc50 + days_pc60 + days_pc70)/100;
        RemunHour                       = (hrs_pc1)/100; 
        AssimHour                       = (hrs_pc10 + hrs_pc21)/100;
        OthHour                         = (hrs_pc23 + hrs_pc30 + hrs_pc50 + hrs_pc60 + hrs_pc70)/100;
        
        KEEP 
        gecodeerd_insz
        Sal100                      Primes                  Preavi          Cotper  mntdedwr
        GeschatDubbelVakantieGeld   BijzondereBijdrageDV    saljrs
        RemunDay                    AssimDay                OthDay              
        RemunHour                   AssimHour               OthHour     
        ;
         
    RUN;
    
    PROC SORT DATA=Combin;
        BY gecodeerd_insz saljrs;
    RUN;
    
    DATA AggYear;
        SET Combin;
        BY gecodeerd_insz;
        RETAIN SumConcept1-SumConcept13 0;
    
        IF FIRST.gecodeerd_insz THEN DO;
            SumConcept1  = Sal100;                      
            SumConcept2  = Primes;                  
            SumConcept3  = Preavi;          
            SumConcept4  = Cotper;  
            SumConcept5  = mntdedwr;
            SumConcept6  = GeschatDubbelVakantieGeld;  
            SumConcept7  = BijzondereBijdrageDV;   
            SumConcept8  = RemunDay;                   
            SumConcept9  = AssimDay;               
            SumConcept10 = OthDay;             
            SumConcept11 = RemunHour;                  
            SumConcept12 = AssimHour;              
            SumConcept13 = OthHour;    
        END;
        ELSE DO;
            SumConcept1  = SumConcept1 + Sal100;                      
            SumConcept2  = SumConcept2 + Primes;                  
            SumConcept3  = SumConcept3 + Preavi;          
            SumConcept4  = SumConcept4 + Cotper;  
            SumConcept5  = SumConcept5 + mntdedwr;
            SumConcept6  = SumConcept6 + GeschatDubbelVakantieGeld;  
            SumConcept7  = SumConcept7 + BijzondereBijdrageDV;   
            SumConcept8  = SumConcept8 + RemunDay;                   
            SumConcept9  = SumConcept9 + AssimDay;               
            SumConcept10 = SumConcept10 + OthDay;             
            SumConcept11 = SumConcept11 + RemunHour;                  
            SumConcept12 = SumConcept12 + AssimHour;              
            SumConcept13 = SumConcept13 + OthHour;    
        END;
        IF LAST.gecodeerd_insz THEN OUTPUT;
    RUN;

    /*Write final output file*/
    DATA &LIB2..&ResFile._&Year.;

        SET AggYear;
        
        /*Rename variables*/        
        Sal100_&Year. =                       SumConcept1 ;
        Primes_&Year. =                       SumConcept2 ;
        Preavi_&Year. =                       SumConcept3 ;
        Cotper_&Year. =                       SumConcept4 ;
        Mntdedwr_&Year. =                     SumConcept5 ;
        %NomValManip(SumConcept6,GeschatDubbelVakantieGeld_&Year.,10);
        BijzondereBijdrageDV_&Year. =         SumConcept7 ;
        RemunDay_&Year. =                     SumConcept8 ;
        AssimDay_&Year. =                     SumConcept9 ;
        OthDay_&Year. =                       SumConcept10;
        RemunHour_&Year. =                    SumConcept11;
        AssimHour_&Year. =                    SumConcept12;
        OthHour_&Year. =                      SumConcept13; 
        saljrs_&Year. =                       saljrs      ;

        SumSal = Sal100_&Year. + Primes_&Year. + Preavi_&Year. ;
        %NomValManip(SumSal,SumSal_&Year.,10);
        
        /*Label amount variables*/
        LABEL Sal100_&Year. =                      "Het bedrag van de gewone bezoldigingen op jaarbasis (som voor jaar = &Year)";
        LABEL Primes_&Year. =                      "Het bedrag van de bezoldigingen die niet rechtstreeks verbonden zijn met de prestaties (som voor jaar = &Year)";
        LABEL Preavi_&Year. =                      "Verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL SumSal_&Year. =                      "Som gewone bezoldigingen, premies en verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL Cotper_&Year. =                      "Bedrag van de normale persoonlijke bijdrage op basis van de bezoldigingen (som voor jaar = &Year)";
        LABEL Mntdedwr_&Year. =                    "Vermindering op persoonlijke bijdrage (som voor jaar = &Year)";
        LABEL GeschatDubbelVakantieGeld_&Year. =   "Dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL BijzondereBijdrageDV_&Year. =        "Bijzondere bijdrage op dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL RemunDay_&Year. =                    "Vergoede dagen (som voor jaar = &Year)";
        LABEL AssimDay_&Year. =                    "Gelijkgestelde dagen waarvoor vergoeding betaald wordt door werkgever (som voor jaar = &Year)";
        LABEL OthDay_&Year. =                      "Gelijkgestelde dagen waarvoor geen vergoeding betaald wordt door werkgever (som voor jaar = &Year)";
        LABEL RemunHour_&Year. =                   "Vergoede uren (som voor jaar = &Year)";
        LABEL AssimHour_&Year. =                   "Gelijkgestelde uren waarvoor vergoeding betaald wordt door werkgever (som voor jaar = &Year)";
        LABEL OthHour_&Year. =                     "Gelijkgestelde uren waarvoor geen vergoeding betaald wordt door werkgever (som voor jaar = &Year)"; 
        LABEL saljrs_&Year. =                      "Het gemiddeld dagloon (som voor jaar = &Year)";

        /*Keep nodige variabelen*/
        KEEP
        GECODEERD_INSZ
        SumSal_&Year. 
        GeschatDubbelVakantieGeld_&Year.   
        RemunDay_&Year.                    
        AssimDay_&Year.                    
        RemunHour_&Year.                   
        AssimHour_&Year.                   
        saljrs_&Year.                      
        ;
    RUN;        

	data &LIB2..&ResFile._&Year.;
		set &LIB2..&ResFile._&Year. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach(20054);
%ForEach(20064);
%ForEach(20074);
%ForEach(20084);


