/*
Met dit programma worden een aantal kwartaalgegevens van de RSZ samengevoegd in n bestand
*/
/*Zet gebruikersopties*/
%let LIB1       = D_RSZ08;                    /*bibliotheek waar RSZ-gegevens staan*/
%let SubFile1   = rsz_084;
%let SubFile2   = statbaseplus_084;
%let SubFile3   = statbasef_084;
%let SubFile4   = statbasem_084;
%let SubFile5   = statbased_084;
%let SubFile6   = statbasecm_;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RSZQuart;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*selecteer gegevens RSZ basis*/
    DATA MIMOSIS&EEJJ._rsz_&JJK.;
        MERGE   &LIB1..&SubFile1   (In=InA rename = (insz = gecodeerd_insz))
                &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
        ;
        BY gecodeerd_insz;
        IF ina=1 and inb=1;
        /*(keep= insz tfwrpid OccupationSequenceNbr TFEdpid CATTRA)*/
    RUN;
    PROC SORT DATA=MIMOSIS&EEJJ._rsz_&JJK.;
        BY tfwrpid OccupationSequenceNbr;
    RUN;
    
    /*selecteer gegevens RSZ Statbaseplus*/
    DATA MIMOSIS&EEJJ._rsz_statbaseplus_&JJK.;
        SET &LIB1..&SubFile2;
        BY tfwrpid OccupationSequenceNbr;
    RUN;

    /*selecteer gegevens RSZ Statbasef*/
    PROC SORT DATA=&LIB1..&SubFile3 OUT = &SubFile3; BY tfwrpid OccupationSequenceNbr; run;

    DATA MIMOSIS&EEJJ._rsz_statbasef_&JJK.;
        SET /*&LIB1..*/&SubFile3;
        BY tfwrpid OccupationSequenceNbr;
    RUN;

    /*selecteer gegevens RSZ StatbaseD*/
    PROC SORT DATA=&LIB1..&SubFile5 OUT = &SubFile5; BY tfwrpid OccupationSequenceNbr; run;

    DATA MIMOSIS&EEJJ._rsz_statbaseD_&JJK.;
        SET &SubFile5(KEEP = tfwrpid OccupationSequenceNbr InsEtab);
        InsEtab_Arr = SUBSTR(InsEtab,1,2);
        BY tfwrpid OccupationSequenceNbr;
    RUN;
    
    /*Merk op: gegevens die in StatbaseC zitten zijn de variabelen Bijdrage en Bijdragecode: deze variabelen werden niet apart aangevraagd
    Vermoedelijk in de veronderstelling dat het bijdrageregime bepaald kan worden op basis van andere gegevens
    StatBaseC moet dus niet gentegreerd worden*/
    
    /*Merge deelbestanden tot dusver, i.e. op combinatie tfwrpid OccupationSequenceNbr*/
    DATA COMBIN;
        MERGE MIMOSIS&EEJJ._rsz_&JJK.(in=ina) MIMOSIS&EEJJ._rsz_statbaseplus_&JJK. MIMOSIS&EEJJ._rsz_statbasef_&JJK. MIMOSIS&EEJJ._rsz_statbaseD_&JJK.; 
        BY tfwrpid OccupationSequenceNbr;
        if ina=1;
    RUN;

    PROC SORT DATA=COMBIN;
        BY TFEdpid CATTRA;
    RUN;

    /*Selecteer bestanden die geordend moeten worden op TFEdpid CATTRA
    StatbaseM verdwijnt vanaf het tweede kwartaal van 2008 en wordt gentegreerd in StatbaseCM
    Daarom aangepaste procedure vanaf tweede kwartaal 2008
    Variabelen die uit StatbaseM gehaald worden en later verwerkt worden, zijn: Mcotdpv en MPecVac
    Deze variabelen kunnen vanaf tweede kwartaal 2008 aangemaakt worden door te selecteren op ContributionCode: 870 vanaf 2de kwartaal 2008*/

    %IF &EEJJK. LT 20082 %THEN %DO;
            
        /*selecteer gegevens RSZ Statbasem*/
        DATA MIMOSIS&EEJJ._rsz_statbasem_&JJK.;
            SET &LIB1..&SubFile4;
        RUN;
        PROC SORT DATA=MIMOSIS&EEJJ._rsz_statbasem_&JJK.(rename=(Employerclass=CATTRA));
            BY TFEdpid CATTRA;
        RUN;
        
        DATA COMBIN;
            MERGE 
            MIMOSIS&EEJJ._rsz_statbasem_&JJK.
            COMBIN(in=InA) 
            ; 
            BY TFEdpid CATTRA;
            IF InA EQ 0 THEN DELETE;
        RUN;
    
    %END;
    %ELSE %DO;

        proc sql;
            create table MIMOSIS&EEJJ._rsz_statbasem_&JJK. as
            select TFEdpid, sum(CONTRIBUTIONCALCULATIONBASIS) as MPecVac,
                            sum(CONTRIBUTIONAMOUNT) as MCotDPV
            from &LIB1..&SubFile6.&JJK.
            where CONTRIBUTIONCODE = 870
            group by TFEdpid;
        quit;

        DATA COMBIN;
            MERGE 
            MIMOSIS&EEJJ._rsz_statbasem_&JJK.
            COMBIN(in=InA) 
            ; 
            BY TFEdpid;
            IF InA EQ 0 THEN DELETE;
        RUN;

    %END;
    
    /*selecteer gegevens RSZ Statbasecm*/
    /*Enkel combineren op basis van variabele TFEDpid*/
    %DO I = 1 %to 4;

        proc sql;
            create table MIMOSIS&EEJJ._rsz_statbasecm_&JJ.&I. as
            select TFEdpid, sum(CONTRIBUTIONCODE) as CONTRIBUTIONCODE_&JJ.&I.,
                            sum(CONTRIBUTIONCALCULATIONBASIS) as CONTRIBUTIONCALCULATIONBASIS,
                            sum(CONTRIBUTIONAMOUNT) as CONTRIBUTIONAMOUNT
            from &LIB1..&SubFile6.&JJ.&I.
            where CONTRIBUTIONCODE <> 870
            group by TFEdpid;
        quit;

        data MIMOSIS&EEJJ._rsz_statbasecm_&JJ.&I.;
            set MIMOSIS&EEJJ._rsz_statbasecm_&JJ.&I.;

            %NomValManip(CONTRIBUTIONCALCULATIONBASIS,CONTRIBUTIONCALCULATIONBASIS_&JJ.&I.,3);
            %NomValManip(CONTRIBUTIONAMOUNT,CONTRIBUTIONAMOUNT_&JJ.&I.,3);
            /*Label variables*/
            LABEL CONTRIBUTIONCODE_&JJ.&I.              = "De code van de bijdrage (in kwartaal &i van &Year)";
            LABEL CONTRIBUTIONCALCULATIONBASIS_&JJ.&I.  = "Berekeningsbasis van de bijdrage (in kwartaal &i van &Year)";
            LABEL CONTRIBUTIONAMOUNT_&JJ.&I.            = "Bedrag van de bijdrage (in kwartaal &i van &Year)";
        run;

    %END;    
    
    DATA COMBIN;
        MERGE 
        %DO I = 1 %to 4;
            MIMOSIS&EEJJ._rsz_statbasecm_&JJ.&I.
        %END; 
        COMBIN(in=InA) 
        ; 
        BY TFEdpid;
        IF InA EQ 0 THEN DELETE;
    RUN;
    
    /*Write final output file*/
    DATA &LIB2..&ResFile;

        SET COMBIN;
        
        /*Rename variables*/        
        insemp_&EEJJK. =                    insemp;                      
        codimp_&EEJJK. =                    codimp;                      
        secemp_&EEJJK. =                    secemp;                      
        pouorg_&EEJJK. =                    pouorg;                      
        nr_cp_&EEJJK. =                     nr_cp;                       
        codtra_&EEJJK. =                    codtra;                      
        clatra_&EEJJK. =                    clatra;                      
        clatr2_&EEJJK. =                    clatr2;                      
        jrsrem_f_&EEJJK. =                  jrsrem_f;                    
        jrsrem_p_&EEJJK. =                  jrsrem_p;                    
        jrspre_&EEJJK. =                    jrspre;                      
        jrsvac_&EEJJK. =                    jrsvac;                      
        jrsasm_&EEJJK. =                    jrsasm;                      
        codasm_&EEJJK. =                    codasm;                      
        heurpt_&EEJJK. =                    heurpt;                      
        devise_&EEJJK. =                    devise;                      
        %NomValManip(sal100,sal100_&EEJJK.,10);
        %NomValManip(primes,primes_&EEJJK.,10);
        %NomValManip(preavi,preavi_&EEJJK.,10);
        %NomValManip(salatt,salatt_&EEJJK.,10);
        %NomValManip(salfor,salfor_&EEJJK.,10);
        saljrs_&EEJJK. =                    saljrs;                      
        salcla_&EEJJK. =                    salcla;                      
        salcl_pt_&EEJJK. =                  salcl_pt;                    
        catept_&EEJJK. =                    catept;                      
        t_prest_&EEJJK. =                   t_prest;                     
        tauxpt_&EEJJK. =                    tauxpt;                      
        eqtpsp_&EEJJK. =                    eqtpsp;                      
        tauxsa_&EEJJK. =                    tauxsa;                      
        tauxaa_&EEJJK. =                    tauxaa;                      
/*        fictif_&EEJJK. =                    fictif;                      */
        t_dnrb_&EEJJK. =                    t_dnrb;                      
        r_exclus_&EEJJK. =                  r_exclus;                    
        pp_rrnmc_&EEJJK. =                  pp_rrnmc;                    
/*        codred_&EEJJK. =                    codred;   */                   
        %NomValManip(mntded,mntded_&EEJJK.,10);
        %NomValManip(cotpat,cotpat_&EEJJK.,10);
        %NomValManip(cotper,cotper_&EEJJK.,10);
        %NomValManip(cotspe,cotspe_&EEJJK.,10);
/*        codffe_&EEJJK. =                    codffe;                      
        cotffe_&EEJJK. =                    cotffe;                      
        cotfse_&EEJJK. =                    cotfse;                      
        cotfor_&EEJJK. =                    cotfor;                      
        cotach_&EEJJK. =                    cotach;                      
        cotm_s_&EEJJK. =                    cotm_s;                      
        cotons_&EEJJK. =                    cotons;                      
        cotacc_&EEJJK. =                    cotacc;                      
        cotcht_&EEJJK. =                    cotcht;                      
        cotveh_&EEJJK. =                    cotveh;                      
        cotedu_&EEJJK. =                    cotedu; */                     
        notfro_&EEJJK. =                    notfro;                      
        notart_&EEJJK. =                    notart;                      
        notdom_&EEJJK. =                    notdom;                      
/*        not1ep_&EEJJK. =                    not1ep;                      */
        notsai_&EEJJK. =                    notsai;                      
        notint_&EEJJK. =                    notint;                      
/*        vehsoc_&EEJJK. =                    vehsoc;   */
        %NomValManip(vehsoc,vehsoc_&EEJJK.,10); 
        maatman_&EEJJK. =                   maatman;                     
        regime_&EEJJK. =                    regime;                      
        matric_&EEJJK. =                    matric;                      
        ReorgWorkregime_&EEJJK. =           ReorgWorkregime;             
        EmploymentPromotion_&EEJJK. =       EmploymentPromotion;         
        EmploymentPromotionType_&EEJJK. =   EmploymentPromotionType;     
        ProximityJobs_&EEJJK. =             ProximityJobs;               
        TypeOfApprenticeShip_&EEJJK. =      TypeOfApprenticeShip;        
        ExtraHoreca_&EEJJK. =               ExtraHoreca;                 
        Workerstatus_&EEJJK. =              Workerstatus;                
        DeductionCode_&EEJJK. =             DeductionCode;               
 /*       DeductionCalculationBasis_&EEJJK. = DeductionCalculationBasis;   */
        %NomValManip(DeductionCalculationBasis,DeductionCalculationBasis_&EEJJK.,10);
        %NomValManip(DeductionAmount,DeductionAmount_&EEJJK.,10);
        %NomValManip(mpecvac,mpecvac_&EEJJK.,10);
        %NomValManip(mcotdpv,mcotdpv_&EEJJK.,10);
        CATTRA_&EEJJK. =                    CATTRA;                     
        OccupationSequenceNbr_&EEJJK. =     OccupationSequenceNbr;
        tfwrpid_&EEJJK. =                   tfwrpid;
        /*Nieuwe variabelen*/
        InsEtab_&EEJJK. =                   InsEtab_Arr;

        /*Label variables*/
        LABEL insemp_&EEJJK. =                    "INS-code van de vestigingsplaats van de werkgever";
        LABEL codimp_&EEJJK. =                    "belangrijkheidscode";
        LABEL secemp_&EEJJK. =                    "sector (1-prive 2-openbare)";
        LABEL pouorg_&EEJJK. =                    "inrichtende overheid";
        LABEL nr_cp_&EEJJK. =                     "nummer paritair comite";
        LABEL codtra_&EEJJK. =                    "werknemerscode";
        LABEL clatra_&EEJJK. =                    "werknemersklasse";
        LABEL clatr2_&EEJJK. =                    "speciale klasse werknemer";
        LABEL jrsrem_f_&EEJJK. =                  "aantal normale bezoldigde fulltimedagen";
        LABEL jrsrem_p_&EEJJK. =                  "aantal bezoldigde parttimedagen";
        LABEL jrspre_&EEJJK. =                    "aantal bezoldigde dagen vooropzeg";
        LABEL jrsvac_&EEJJK. =                    "aantal bezoldigde vakantiedagen";
        LABEL jrsasm_&EEJJK. =                    "aantal bezoldigde gelijkgestelde dagen";
        LABEL codasm_&EEJJK. =                    "hoofdcode van de gelijkgestelde dagen";
        LABEL heurpt_&EEJJK. =                    "uren deeltijds";
        LABEL devise_&EEJJK. =                    "munteenheid staat";
        LABEL sal100_&EEJJK. =                    "loon 100%";
        LABEL primes_&EEJJK. =                    "premies";
        LABEL preavi_&EEJJK. =                    "vooropzeg";
        LABEL salatt_&EEJJK. =                    "wachtloon";
        LABEL salfor_&EEJJK. =                    "forfaitair loon";
        LABEL saljrs_&EEJJK. =                    "berekend dagloon";
        LABEL salcla_&EEJJK. =                    "fulltime loonklasse";
        LABEL salcl_pt_&EEJJK. =                  "parttime loonklasse";
        LABEL catept_&EEJJK. =                    "kengetal parttime";
        LABEL t_prest_&EEJJK. =                   "type prestatie";
        LABEL tauxpt_&EEJJK. =                    "percentage parttime";
        LABEL eqtpsp_&EEJJK. =                    "VTE excl gelijkgestelde dagen ";
        LABEL tauxsa_&EEJJK. =                    "percentage zonder gelijkgestelde dagen";
        LABEL tauxaa_&EEJJK. =                    "percentage met gelijkgestelde dagen";
/*        LABEL fictif_&EEJJK. =                    "code fictieve creatie";*/
        LABEL t_dnrb_&EEJJK. =                    "type dnrb";
        LABEL r_exclus_&EEJJK. =                  "reden voor uitsluiting dnrb";
        LABEL pp_rrnmc_&EEJJK. =                  "hoofdprestatie van de combinatie rrn/stamnummer/kengetal";
/*        LABEL codred_&EEJJK. =                    "verminderingscode";*/
        LABEL mntded_&EEJJK. =                    "gecumuleerd bedrag van de vermindering";
        LABEL cotpat_&EEJJK. =                    "bedrag werkgeversbijdrage";
        LABEL cotper_&EEJJK. =                    "bedrag persoonlijke bijdrage";
        LABEL cotspe_&EEJJK. =                    "bedrag bijzondere bijdragen";
/*        LABEL codffe_&EEJJK. =                    "Fso-code";
        LABEL cotffe_&EEJJK. =                    "809-10 bijdrage fso";
        LABEL cotfse_&EEJJK. =                    "Bijdrage Fonds voor Bestaanszekerheid";
        LABEL cotfor_&EEJJK. =                    "Bijdrage bestemd voor de maatregelen ten voordele van de werkgelegenheid en de vorming van de risicogroepen";
        LABEL cotach_&EEJJK. =                    "Bijdrage begeleiding werklozen";
        LABEL cotm_s_&EEJJK. =                    "Bijdrage werkloosheid van 1,60%";
        LABEL cotons_&EEJJK. =                    "Bijzondere RSZ-bijdrage";
        LABEL cotacc_&EEJJK. =                    "Bijdrage kinderopvang";
        LABEL cotcht_&EEJJK. =                    "Bijdrage tijdelijke werkloosheid";
        LABEL cotveh_&EEJJK. =                    "Solidariteitsbijdrage bedrijfsvoertuig";
        LABEL cotedu_&EEJJK. =                    "Bijdrage educatief verlof";*/
        LABEL notfro_&EEJJK. =                    "Notie grensarbeider ";
        LABEL notart_&EEJJK. =                    "Notie artiest ";
        LABEL notdom_&EEJJK. =                    "Notie huisarbeid ";
 /*       LABEL not1ep_&EEJJK. =                    "eerste werkervaring";*/
        LABEL notsai_&EEJJK. =                    "Notie seizoenarbeid ";
        LABEL notint_&EEJJK. =                    "Notie bij tussenpozen ";
        LABEL vehsoc_&EEJJK. =                    "bedrag van het voordeel (bedrijfsvoertuig)";
        LABEL maatman_&EEJJK. =                   "Maatman";
        LABEL regime_&EEJJK. =                    "Werkregime (onderscheid tussen 5 en 6 dagenweek)";
        LABEL matric_&EEJJK. =                    "RSZ-stamnummer";
        LABEL ReorgWorkregime_&EEJJK. =           "Aanduiding of het gaat om een stelsel van verminderde prestaties";
        LABEL EmploymentPromotion_&EEJJK. =       "Code die aangeeft of er externe financiering is in het kader van een tewerkstellingsmaatregel";
        LABEL EmploymentPromotionType_&EEJJK. =   "Code die aangeeft of het gaat om tewerkstellingsmaatregelen met het oog op de intrede in de arbeidsmarkt";
        LABEL ProximityJobs_&EEJJK. =             "Aanduiding of het gaat om tewerkstelling in het kader van dienstencheques";
        LABEL TypeOfApprenticeShip_&EEJJK. =      "Aanduiding of het gaat om tewerkstelling in het kader van een leerovereenkomst";
        LABEL ExtraHoreca_&EEJJK. =               "Type aanwerving in de horeca";
        LABEL Workerstatus_&EEJJK. =              "Aanduiding van speciale types tewerkstelling";
        LABEL DeductionCode_&EEJJK. =             "Code van de bijdragevermindering";
        LABEL DeductionCalculationBasis_&EEJJK. = "Basis waarop de bijdragevermindering wordt berekend";
        LABEL DeductionAmount_&EEJJK. =           "Bedrag van de toegestane bijdragevermindering";
        LABEL mpecvac_&EEJJK. =                   "geaggregeerd dubbel vakantiegeld";
        LABEL mcotdpv_&EEJJK. =                   "Bijdrage op geaggregeerd dubbel vakantiegeld";
        LABEL CATTRA_&EEJJK. =                    "Werkgeverskengetal";
        LABEL OccupationSequenceNbr_&EEJJK. =     "OccupationSequenceNbr: betekenisloos nummer gebruikt om gegevens te koppelen";
        LABEL tfwrpid_&EEJJK. =                   "tfwrpid: betekenisloos nummer gebruikt om gegevens te koppelen";
        LABEL InsEtab_&EEJJK. =                   "Arrondissement van de lokale vestigingseenheid";

        /*Keep variables*/ 
        KEEP
        gecodeerd_insz
        secemp_&EEJJK. 
        nr_cp_&EEJJK. 
        codtra_&EEJJK. 
        clatra_&EEJJK. 
        clatr2_&EEJJK. 
        jrsrem_f_&EEJJK. 
        jrsrem_p_&EEJJK. 
        jrspre_&EEJJK. 
        jrsvac_&EEJJK. 
        jrsasm_&EEJJK. 
        codasm_&EEJJK. 
        sal100_&EEJJK. 
        primes_&EEJJK. 
        preavi_&EEJJK. 
        salatt_&EEJJK. 
        salfor_&EEJJK. 
        saljrs_&EEJJK. 
        t_prest_&EEJJK. 
        tauxpt_&EEJJK. 
        tauxsa_&EEJJK. 
        tauxaa_&EEJJK. 
        t_dnrb_&EEJJK. 
        r_exclus_&EEJJK. 
        pp_rrnmc_&EEJJK. 
 /*       codred_&EEJJK. */
        mntded_&EEJJK. 
        cotpat_&EEJJK. 
        cotper_&EEJJK. 
        cotspe_&EEJJK. 
        maatman_&EEJJK. 
        DeductionCode_&EEJJK. 
        DeductionCalculationBasis_&EEJJK. 
        DeductionAmount_&EEJJK. 
        mpecvac_&EEJJK. 
        mcotdpv_&EEJJK. 
        CATTRA_&EEJJK. 
        InsEtab_&EEJJK.
/*        %DO I = 1 %to 4;
            CONTRIBUTIONCODE_&JJ.&I.
            CONTRIBUTIONCALCULATIONBASIS_&JJ.&I.
            CONTRIBUTIONAMOUNT_&JJ.&I.
        %END;*/
            CONTRIBUTIONCODE_&JJ.1 CONTRIBUTIONCODE_&JJ.2 CONTRIBUTIONCODE_&JJ.3 CONTRIBUTIONCODE_&JJ.4
            CONTRIBUTIONCALCULATIONBASIS_&JJ.1 CONTRIBUTIONCALCULATIONBASIS_&JJ.2 CONTRIBUTIONCALCULATIONBASIS_&JJ.3 CONTRIBUTIONCALCULATIONBASIS_&JJ.4
            CONTRIBUTIONAMOUNT_&JJ.1 CONTRIBUTIONAMOUNT_&JJ.2 CONTRIBUTIONAMOUNT_&JJ.3 CONTRIBUTIONAMOUNT_&JJ.4
        ;
        
    RUN;

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;

	proc sort data = &LIB2..&ResFile.; by insz; run;

%MEND ForEach;
%ForEach;

