/*
Met dit programma worden een aantal jaarvariabelen afgeleid op basis van de kwartaal RSZ data
Manipulatie wordt jaar per jaar uitgevoerd
Het programma moet gelanceerd worden voor gegevens voor 2003
*/

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach(EEJJK);

    /*Zet gebruikersopties*/
    %let EEJJ       = %SUBSTR(&EEJJK,1,4);
    %let Year       = %SUBSTR(&EEJJK,1,4);
    %let JJK        = %SUBSTR(&EEJJK,3,3);
    %let JJ         = %SUBSTR(&EEJJK,3,2);
    %let LIB1       = D_RSZ&JJ.;                    /*bibliotheek waar RSZ-gegevens staan*/
    %let SubFile1   = rsz_&JJ.1;
    %let SubFile2   = rsz_&JJ.2;
    %let SubFile3   = rsz_&JJ.3;
    %let SubFile4   = rsz_&JJ.4;
    %let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
    %let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
    %let ResFile    = mim2008_RSZYear;
    %let AantFiles  = 4;

    /*Start loop over aantal files*/
    %DO I = 1 %to &AantFiles;
             
        /*Verwerk gegevens van een gegeven kwartaal*/
        DATA RSZBasis&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;

            if fictif = 'R';

            CONTRIB_LABMSTAT_PRIV_QT = 0;
            IF SECEMP EQ '1' AND CLATRA EQ 1 THEN CONTRIB_LABMSTAT_PRIV_QT = 1;
            IF SECEMP EQ '1' AND CLATRA EQ 2 THEN CONTRIB_LABMSTAT_PRIV_QT = 2;

            CONTRIB_LABMSTAT_PUB_QT = 0;
            IF SECEMP EQ '2' OR CLATRA EQ 3 THEN DO;
                IF CODTRA IN (10, 11, 12, 13, 14, 15, 16, 22, 24, 25, 27, 35, 41, 45)           THEN CONTRIB_LABMSTAT_PUB_QT = 1;
                IF CODTRA IN (439, 484, 485, 487, 492, 493, 494, 495, 673, 840, 876, 877, 879)  THEN CONTRIB_LABMSTAT_PUB_QT = 2;
                IF CODTRA IN (671, 675)                                                         THEN CONTRIB_LABMSTAT_PUB_QT = 4;
            END;

            /*Ingrepen voor dubbelzinnige gevallen*/            
            IF CONTRIB_LABMSTAT_PRIV_QT EQ 0 AND CONTRIB_LABMSTAT_PUB_QT EQ 0 THEN CONTRIB_LABMSTAT_PRIV_QT = 2;
            IF CONTRIB_LABMSTAT_PRIV_QT NE 0 AND CONTRIB_LABMSTAT_PUB_QT NE 0 THEN DO;
                CONTRIB_LABMSTAT_PRIV_QT = 0;
            END;

            /*Bepaal extra variabelen voor groepen enkel vakantiegeld*/
            /*Schat enkel vakantiegeld voor arbeiders*/
            GeschatEnkelVakantieGeld = 0;
            IF CONTRIB_LABMSTAT_PRIV_QT EQ 1 OR CONTRIB_LABMSTAT_PUB_QT EQ 1 THEN DO;
                IF (JRSREM_F+JRSREM_P) NE 0 AND (JRSREM_F+JRSREM_P) NE . THEN DO;
                    GeschatEnkelVakantieGeld = 0.08*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*(JRSASM/(JRSREM_F+JRSREM_P))));
                END;
                ELSE IF JRSASM LT 312 THEN DO;
                    GeschatEnkelVakantieGeld = 0.08*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*(JRSASM/(312-JRSASM))));
                END;
                ELSE DO;
                    GeschatEnkelVakantieGeld = 0.08*(1.08*(Sal100+Salatt+Primes));
                END;
            END;
            /*Schat normale persoonlijke bijdrage voor ambtenaren*/
            NPB = 0;
            IF CONTRIB_LABMSTAT_PUB_QT IN (3, 4) THEN DO;
                NPB = 0.1105*(Sal100+Primes+Preavi);
            END;

            /*Bepaal extra variabelen voor groepen dubbel vakantiegeld*/
            /*Schat dubbel vakantiegeld en bijdragen op dubbel vakantiegeld*/
            GeschatDubbelVakantieGeld = 0;
            BijzondereBijdrageDV = 0;
            SolBijdrageDV = 0;
            IF CONTRIB_LABMSTAT_PRIV_QT EQ 1 OR CONTRIB_LABMSTAT_PUB_QT EQ 1 THEN DO;
                IF (JRSREM_F+JRSREM_P) NE 0 AND (JRSREM_F+JRSREM_P) NE . THEN DO;
                    GeschatDubbelVakantieGeld   = 0.0738*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*(JRSASM/(JRSREM_F+JRSREM_P))));
                    BijzondereBijdrageDV        = 0.1307*0.068*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*(JRSASM/(JRSREM_F+JRSREM_P))));
                END;
                ELSE IF JRSASM LT 312 THEN DO;
                    GeschatDubbelVakantieGeld   = 0.0738*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*(JRSASM/(312-JRSASM))));
                    BijzondereBijdrageDV        = 0.1307*0.068*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*(JRSASM/(312-JRSASM))));
                END;
                ELSE DO;
                    GeschatDubbelVakantieGeld   = 0.0738*(1.08*(Sal100+Salatt+Primes));
                    BijzondereBijdrageDV        = 0.1307*0.068*(1.08*(Sal100+Salatt+Primes));
                END;
                SolBijdrageDV               = 0.01*GeschatDubbelVakantieGeld;
            END;
            IF CONTRIB_LABMSTAT_PRIV_QT EQ 2 OR CONTRIB_LABMSTAT_PUB_QT EQ 2 THEN DO;
                IF (JRSREM_F+JRSREM_P) NE 0 AND (JRSREM_F+JRSREM_P) NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*(JRSASM/(JRSREM_F+JRSREM_P))));
                END;
                ELSE IF JRSASM LT 312 THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*(JRSASM/(312-JRSASM))));
                END;
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)));
                END;
                BijzondereBijdrageDV        = 0.120755*GeschatDubbelVakantieGeld;
            END;
            IF CONTRIB_LABMSTAT_PUB_QT IN (3, 4) THEN DO;
                IF (JRSREM_F+JRSREM_P) NE 0 AND (JRSREM_F+JRSREM_P) NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*(JRSASM/(JRSREM_F+JRSREM_P))));
                END;
                ELSE IF JRSASM LT 312 THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*(JRSASM/(312-JRSASM))));
                END;
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)));
                END;
                BijzondereBijdrageDV        = 0.1307*GeschatDubbelVakantieGeld;
            END;
            
        RUN;
    
    %END;

    DATA Combin;
        SET
            %DO I = 1 %to &AantFiles;
                RSZBasis&I
            %END;
        ;

        /*Construeer later te behandelen variabelen*/
        IF Sal100                       EQ . THEN Sal100 = 0;                  
        IF Salatt                       EQ . THEN Salatt = 0;                                     
        IF Primes                       EQ . THEN Primes = 0;                             
        IF Preavi                       EQ . THEN Preavi = 0;                    
        IF Cotper                       EQ . THEN Cotper = 0;                    
        IF Mntded                       EQ . THEN Mntded   = 0;                 
        IF jrsasm                       EQ . THEN jrsasm = 0;                    
        IF jrsrem_f                     EQ . THEN jrsrem_f = 0;                                     
        IF jrsrem_p                     EQ . THEN jrsrem_p = 0;                                 
        IF GeschatDubbelVakantieGeld    EQ . THEN GeschatDubbelVakantieGeld = 0;   
        IF BijzondereBijdrageDV         EQ . THEN BijzondereBijdrageDV = 0;         
        IF SolBijdrageDV                EQ . THEN SolBijdrageDV = 0;               
        IF GeschatEnkelVakantieGeld     EQ . THEN GeschatEnkelVakantieGeld = 0;
        IF NPB                          EQ . THEN NPB = 0;
        
        KEEP 
        gecodeerd_insz
        Sal100                      Salatt                  Primes          Preavi                   Cotper Mntded
        jrsasm                      jrsrem_f                jrsrem_p 
        GeschatDubbelVakantieGeld   BijzondereBijdrageDV    SolBijdrageDV   GeschatEnkelVakantieGeld NPB    saljrs
        CONTRIB_LABMSTAT_PUB_QT;
         
    RUN;
    
    PROC SORT DATA=Combin;
        BY gecodeerd_insz saljrs;
    RUN;
    
    DATA AggYear;
        SET Combin;
        BY gecodeerd_insz;
        RETAIN SumConcept1-SumConcept15 0;
    
        IF FIRST.gecodeerd_insz THEN DO;
            SumConcept1  = Sal100;                      
            SumConcept2  = Salatt;                  
            SumConcept3  = Primes;          
            SumConcept4  = Preavi; 
            IF CONTRIB_LABMSTAT_PUB_QT IN (3, 4) THEN DO;
                SumConcept15  = Cotper; 
            END;                
            ELSE DO;
                SumConcept5  = Cotper; 
            END;                
            SumConcept6  = Mntded;
            SumConcept7  = GeschatDubbelVakantieGeld;   
            SumConcept8  = BijzondereBijdrageDV;    
            SumConcept9  = SolBijdrageDV;   
            SumConcept10 = jrsasm; 
            SumConcept11 = jrsrem_f;                    
            SumConcept12 = jrsrem_p;                
            SumConcept13 = GeschatEnkelVakantieGeld;
            SumConcept14 = NPB;
        END;
        ELSE DO;
            SumConcept1  = SumConcept1  + Sal100;                      
            SumConcept2  = SumConcept2  + Salatt;                  
            SumConcept3  = SumConcept3  + Primes;          
            SumConcept4  = SumConcept4  + Preavi; 
            IF CONTRIB_LABMSTAT_PUB_QT IN (3, 4) THEN DO;
                SumConcept15  = SumConcept15 + Cotper; 
            END;                
            ELSE DO;
                SumConcept5  = SumConcept5 + Cotper; 
            END;                
            SumConcept6  = SumConcept6  + Mntded;
            SumConcept7  = SumConcept7  + GeschatDubbelVakantieGeld;   
            SumConcept8  = SumConcept8  + BijzondereBijdrageDV;    
            SumConcept9  = SumConcept9  + SolBijdrageDV;   
            SumConcept10 = SumConcept10 + jrsasm; 
            SumConcept11 = SumConcept11 + jrsrem_f;                    
            SumConcept12 = SumConcept12 + jrsrem_p;                
            SumConcept13 = SumConcept13 + GeschatEnkelVakantieGeld;
            SumConcept14 = SumConcept14 + NPB;
        END;
        IF LAST.gecodeerd_insz THEN OUTPUT;
    RUN;

    /*Write final output file*/
    DATA &LIB2..&ResFile._&Year.;
    
        SET AggYear;
        
        /*Rename variables*/        
        Sal100_&Year. =                       SumConcept1 ;
        Salatt_&Year. =                       SumConcept2 ;
        Primes_&Year. =                       SumConcept3 ;
        Preavi_&Year. =                       SumConcept4 ;
        Cotper12_&Year. =                     SumConcept5 ;
        Mntded_&Year. =                       SumConcept6 ;
        %NomValManip(SumConcept7,GeschatDubbelVakantieGeld_&Year.,10);
        BijzondereBijdrageDV_&Year. =         SumConcept8 ;
        SolBijdrageDV_&Year. =                SumConcept9 ;
        jrsasm_&Year. =                       SumConcept10;
        jrsrem_f_&Year. =                     SumConcept11;
        jrsrem_p_&Year. =                     SumConcept12;
        %NomValManip(SumConcept13,GeschatEnkelVakantieGeld_&Year.,10);
        NPB_&Year. =                          SumConcept14;
        Cotper3_&Year. =                      SumConcept15;
        saljrs_&Year. =                       saljrs      ;

        SumSal = Sal100_&Year. + Salatt_&Year. + Primes_&Year. + Preavi_&Year. ;
        %NomValManip(SumSal,SumSal_&Year.,10);
        
        /*Label amount variables*/
        LABEL Sal100_&Year. =                      "Het bedrag van de gewone bezoldigingen op jaarbasis (som voor jaar = &Year)";
        LABEL Salatt_&Year. =                      "Het bedrag van het loon betaald aan bestuurders voor wachttijden (som voor jaar = &Year)";
        LABEL Primes_&Year. =                      "Het bedrag van de bezoldigingen die niet rechtstreeks verbonden zijn met de prestaties (som voor jaar = &Year)";
        LABEL Preavi_&Year. =                      "Verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL SumSal_&Year. =                      "Som gewone bezoldigingen, loon bestuurders wachttijden, premies en verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL Cotper12_&Year. =                    "Bedrag van de normale persoonlijke bijdrage op basis van de bezoldigingen voor groepen EV 1 en 2 (som voor jaar = &Year)";
        LABEL Mntded_&Year. =                      "Vermindering op bijdragen (merk op: som van alle bijdrageverminderingen) (som voor jaar = &Year)";
        LABEL GeschatDubbelVakantieGeld_&Year. =   "Dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL BijzondereBijdrageDV_&Year. =        "Bijzondere bijdrage op dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL SolBijdrageDV_&Year. =               "Solidariteitsbijdrage betaald op vakantiegeld van arbeiders (som voor jaar = &Year)";
        LABEL jrsasm_&Year. =                      "Aantal gelijkgestelde dagen (som voor jaar = &Year)";
        LABEL jrsrem_f_&Year. =                    "Aantal bezoldigde dagen: full time (som voor jaar = &Year)";
        LABEL jrsrem_p_&Year. =                    "Aantal bezoldigde dagen: part time (som voor jaar = &Year)";
        LABEL GeschatEnkelVakantieGeld_&Year. =    "Geschat enkel vakantiegeld van arbeiders (som voor jaar = &Year)";
        LABEL NPB_&Year. =                         "Geschatte persoonlijke bijdrage voor bepaalde bedienden (som voor jaar = &Year)";
        LABEL Cotper3_&Year. =                     "Bedrag van de normale persoonlijke bijdrage op basis van de bezoldigingen voor groep EV 3 (som voor jaar = &Year)";
        LABEL saljrs_&Year. =                      "Het gemiddeld dagloon (som voor jaar = &Year)";

        /*Keep nodige variabelen*/
        KEEP
        GECODEERD_INSZ 
        SumSal_&Year.
        GeschatDubbelVakantieGeld_&Year.
        GeschatEnkelVakantieGeld_&Year.    
        jrsasm_&Year. 
        jrsrem_f_&Year.
        jrsrem_p_&Year. 
        saljrs_&Year.
        ;        
    RUN;  

	data &LIB2..&ResFile._&Year.;
		set &LIB2..&ResFile._&Year. (rename = (gecodeerd_insz = insz));
	run; 

%MEND ForEach;

%ForEach(20024);

