/*
Met dit programma worden een aantal jaarvariabelen afgeleid op basis van de kwartaal RSZ data
Manipulatie wordt jaar per jaar uitgevoerd
Het programma moet gelanceerd worden vanaf 2003 tot en met jaar x waar x+1 het jaar de steekproeftrekking is
Vermoedelijk zal x+1 2009 zijn (i.e. in het geval de steekproef op 1 januari 2009 getrokken wordt)
Merk op:
In geen van de gevraagde test-files waren alle noodzakelijke variabelen aanwezig.
Voor het lopen van het programma moet er dus nog een aanpassing gebeuren van de nodige variabelen

Variabelen die moeten aangevuld worden zijn
Cattra
Clatr2
tauxsa
tauxaa
eqtpsp

Deze aanvulling gebeurt in principe automatisch door het programma op de basisbestanden te laten lopen

Merk op: voor persoonlijke bijdragen wordt nu variabele uit basisbestand genomen terwijl misschien
beter een variabele uit statbasef genomen zou worden.
*/

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach(EEJJK);

    /*Zet gebruikersopties*/
    %let EEJJ       = %SUBSTR(&EEJJK,1,4);
    %let Year       = %SUBSTR(&EEJJK,1,4);
    %let JJK        = %SUBSTR(&EEJJK,3,3);
    %let JJ         = %SUBSTR(&EEJJK,3,2);
    %let LIB1       = D_RSZ&JJ.;                    /*bibliotheek waar RSZ-gegevens staan*/
    %let SubFile1   = rsz_&JJ.1;
    %let SubFile2   = rsz_&JJ.2;
    %let SubFile3   = rsz_&JJ.3;
    %let SubFile4   = rsz_&JJ.4;
    %let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
    %let SubFile7   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
    %let ResFile    = mim2008_RSZYear;
    %let AantFiles  = 4;

    /*Start loop over aantal files*/
    %DO I = 1 %to &AantFiles;
             
        /*Verwerk gegevens van een gegeven kwartaal*/
        DATA RSZBasis&I;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SubFile7   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;

            /*Definieer groepen bepaling enkel vakantiegeld*/
            GROEP_EV = 0;
            IF                   Clatra EQ 2 AND                                    Clatr2 IN ('EU', 'ER') THEN GROEP_EV = 1; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 1   AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 1   AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 1   AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 1   AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 1   AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 1   AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 16  AND Codtra EQ 10 AND Clatr2 EQ 'OX'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 16  AND Codtra EQ 20 AND Clatr2 EQ 'OY'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 17  AND Codtra EQ 10 AND Clatr2 EQ 'OX'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 17  AND Codtra EQ 20 AND Clatr2 EQ 'OY'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 27  AND Codtra EQ 13 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 27  AND Codtra EQ 15 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 27  AND Codtra EQ 16 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 27  AND Codtra EQ 27 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 27  AND Codtra EQ 41 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 27  AND Codtra EQ 45 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 28  AND Codtra EQ 13 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 28  AND Codtra EQ 15 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 28  AND Codtra EQ 16 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 28  AND Codtra EQ 27 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 28  AND Codtra EQ 45 AND Clatr2 EQ 'XA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 34  AND Codtra EQ 11 AND Clatr2 EQ 'XC'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 34  AND Codtra EQ 15 AND Clatr2 EQ 'XC'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 40  AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 40  AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 40  AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 42  AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 42  AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 42  AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 43  AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 43  AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 45  AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 45  AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 45  AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 46  AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 46  AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 50  AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 50  AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 50  AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 50  AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 50  AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 71  AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 96  AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 96  AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 96  AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 96  AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 96  AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 97  AND Codtra EQ 10 AND Clatr2 EQ 'OZ'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 97  AND Codtra EQ 10 AND Clatr2 EQ 'OH'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 97  AND Codtra EQ 20 AND Clatr2 EQ 'OY'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 97  AND Codtra EQ 22 AND Clatr2 EQ 'OJ'         THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 101 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 140 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 145 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 150 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 175 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 175 AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 175 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 175 AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 193 AND Codtra EQ 10 AND Clatr2 EQ 'OH'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 193 AND Codtra EQ 22 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 194 AND Codtra EQ 10 AND Clatr2 EQ 'OH'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 194 AND Codtra EQ 22 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 196 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 245 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 245 AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 245 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 296 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 296 AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 296 AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 296 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;  
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 296 AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 347 AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 347 AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 351 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 351 AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 351 AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 351 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 351 AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 396 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 396 AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 396 AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 396 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 396 AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 440 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 440 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 441 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 441 AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 441 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 441 AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 443 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 443 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 445 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 445 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 494 AND Codtra EQ 10 AND Clatr2 EQ 'OH'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 494 AND Codtra EQ 22 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 496 AND Codtra EQ 15 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 496 AND Codtra EQ 19 AND Clatr2 EQ 'OO'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 496 AND Codtra EQ 24 AND Clatr2 EQ 'OS'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 496 AND Codtra EQ 27 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 496 AND Codtra EQ 35 AND Clatr2 EQ 'OA'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 497 AND Codtra EQ 10 AND Clatr2 EQ 'OZ'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 497 AND Codtra EQ 20 AND Clatr2 EQ 'OY'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 594 AND Codtra EQ 10 AND Clatr2 EQ 'OH'         THEN GROEP_EV = 2;
            IF GROEP_EV EQ 0 AND Clatra EQ 1 AND Cattra EQ 594 AND Codtra EQ 22 AND Clatr2 EQ 'OE'         THEN GROEP_EV = 2;            
            IF GROEP_EV EQ 0 AND Clatra EQ 1                                                               THEN GROEP_EV = 1; 
            IF GROEP_EV EQ 0 AND Clatra EQ 2                                                               THEN GROEP_EV = 2; 
            IF GROEP_EV EQ 0 AND Clatra EQ 3                                                               THEN GROEP_EV = 3; 
            IF GROEP_EV EQ 0                                                                               THEN GROEP_EV = 2; 
            /*Bepaal extra variabelen voor groepen enkel vakantiegeld*/
            /*Schat enkel vakantiegeld voor GROEP_EV = 1*/
            GeschatEnkelVakantieGeld = 0;
            IF GROEP_EV EQ 1 THEN DO;
                IF tauxsa NE 0 AND tauxsa NE . THEN DO;
                    GeschatEnkelVakantieGeld = 0.08*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*((tauxaa-tauxsa)/tauxsa)));
                END;
                ELSE DO;
                    GeschatEnkelVakantieGeld = 0.08*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*((tauxaa-tauxsa)/100)));
                END;
            END;
            /*Schat normale persoonlijke bijdrage voor GROEP_EV = 3*/
            NPB = 0;
            IF GROEP_EV EQ 3 THEN DO;
                NPB = 0.1105*(Sal100+Primes+Preavi);
            END;

            /*Definieer groepen bepaling dubbel vakantiegeld*/
            GROEP_DV = 0;
            IF                   Clatra EQ 2 AND                                    Clatr2 IN ('EU', 'ER') THEN GROEP_DV = 1; 
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 1                                          THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 40                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 42                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 45                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 46                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 47                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 50                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 75                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 96                                         THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 101                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 134                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 140                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 145                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 146                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 150                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 175                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 196                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 245                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 246                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 272                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 296                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 346                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 347                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 350                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 351                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 372                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 396                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 399                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 411                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 437                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 440                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 441                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 445                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 496                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 497                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra IN (1, 2) AND Cattra EQ 599                                        THEN GROEP_DV = 3;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 16  AND Codtra EQ 10 AND Clatr2 EQ 'OX'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 16  AND Codtra EQ 20 AND Clatr2 EQ 'OY'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 17  AND Codtra EQ 10 AND Clatr2 EQ 'OX'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 17  AND Codtra EQ 20 AND Clatr2 EQ 'OY'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 27  AND Codtra EQ 13 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 27  AND Codtra EQ 15 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 27  AND Codtra EQ 16 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 27  AND Codtra EQ 27 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 27  AND Codtra EQ 41 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 27  AND Codtra EQ 45 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 28  AND Codtra EQ 13 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 28  AND Codtra EQ 15 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 28  AND Codtra EQ 16 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 28  AND Codtra EQ 27 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 28  AND Codtra EQ 45 AND Clatr2 EQ 'XA'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 34  AND Codtra EQ 11 AND Clatr2 EQ 'XC'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 34  AND Codtra EQ 15 AND Clatr2 EQ 'XC'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 43  AND Codtra EQ 15 AND Clatr2 EQ 'OO'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 43  AND Codtra EQ 27 AND Clatr2 EQ 'OE'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 71  AND Codtra EQ 15 AND Clatr2 EQ 'OO'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 97  AND Codtra EQ 10 AND Clatr2 EQ 'OZ'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 97  AND Codtra EQ 10 AND Clatr2 EQ 'OH'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 97  AND Codtra EQ 20 AND Clatr2 EQ 'OY'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 97  AND Codtra EQ 22 AND Clatr2 EQ 'OJ'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 193 AND Codtra EQ 10 AND Clatr2 EQ 'OH'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 193 AND Codtra EQ 22 AND Clatr2 EQ 'OE'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 194 AND Codtra EQ 10 AND Clatr2 EQ 'OH'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 194 AND Codtra EQ 22 AND Clatr2 EQ 'OE'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 443 AND Codtra EQ 15 AND Clatr2 EQ 'OO'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 443 AND Codtra EQ 27 AND Clatr2 EQ 'OE'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 494 AND Codtra EQ 10 AND Clatr2 EQ 'OH'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1      AND Cattra EQ 494 AND Codtra EQ 22 AND Clatr2 EQ 'OE'    THEN GROEP_DV = 2;
            IF GROEP_DV EQ 0 AND Clatra EQ 1                                                               THEN GROEP_DV = 1; 
            IF GROEP_DV EQ 0 AND Clatra EQ 2                                                               THEN GROEP_DV = 2; 
            IF GROEP_DV EQ 0 AND Clatra EQ 3                                                               THEN GROEP_DV = 3; 
            IF GROEP_DV EQ 0                                                                               THEN GROEP_DV = 2; 
            /*Bepaal extra variabelen voor groepen dubbel vakantiegeld*/
            /*Schat dubbel vakantiegeld en bijdragen op dubbel vakantiegeld*/
            GeschatDubbelVakantieGeld = 0;
            BijzondereBijdrageDV = 0;
            SolBijdrageDV = 0;
            IF GROEP_DV EQ 1 THEN DO;
                IF tauxsa NE 0 AND tauxsa NE . THEN DO;
                    GeschatDubbelVakantieGeld   = 0.0738*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*((tauxaa-tauxsa)/tauxsa)));
                    BijzondereBijdrageDV        = 0.1307*0.068*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*((tauxaa-tauxsa)/tauxsa)));
                END;                    
                ELSE DO;
                    GeschatDubbelVakantieGeld   = 0.0738*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*((tauxaa-tauxsa)/100)));
                    BijzondereBijdrageDV        = 0.1307*0.068*(1.08*(Sal100+Salatt+Primes)+((Sal100+Salatt)*((tauxaa-tauxsa)/100)));
                END;                    
                SolBijdrageDV               = 0.01*GeschatDubbelVakantieGeld;
            END;
            IF GROEP_DV EQ 2 THEN DO;
                IF tauxsa NE 0 AND tauxsa NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*((tauxaa-tauxsa)/tauxsa)));
                END;                    
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*((tauxaa-tauxsa)/100)));
                END;                    
                BijzondereBijdrageDV        = 0.120755*GeschatDubbelVakantieGeld;
            END;
            IF GROEP_DV EQ 3 THEN DO;
                IF tauxsa NE 0 AND tauxsa NE . THEN DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*((tauxaa-tauxsa)/tauxsa)));
                END;                    
                ELSE DO;
                    GeschatDubbelVakantieGeld   = (1/12)*(0.92*((Sal100+Salatt)+(Sal100+Salatt)*((tauxaa-tauxsa)/100)));
                END;                    
                BijzondereBijdrageDV        = 0.1307*GeschatDubbelVakantieGeld;
            END;
            
        RUN;
    
    %END;

    DATA Combin;
        SET
            %DO I = 1 %to &AantFiles;
                RSZBasis&I
            %END;
        ;

        /*Construeer later te behandelen variabelen*/
        IF Sal100                       EQ . THEN Sal100 = 0;                  
        IF Salatt                       EQ . THEN Salatt = 0;                                     
        IF Primes                       EQ . THEN Primes = 0;                             
        IF Preavi                       EQ . THEN Preavi = 0;                    
        IF Cotper                       EQ . THEN Cotper = 0;                    
        IF Mntded_p                     EQ . THEN Mntded_p = 0;                 
        IF GeschatDubbelVakantieGeld    EQ . THEN GeschatDubbelVakantieGeld = 0;   
        IF BijzondereBijdrageDV         EQ . THEN BijzondereBijdrageDV = 0;         
        IF SolBijdrageDV                EQ . THEN SolBijdrageDV = 0;               
        IF heurpt                       EQ . THEN heurpt = 0;                    
        IF jrsasm                       EQ . THEN jrsasm = 0;                    
        IF jrspre                       EQ . THEN jrspre = 0;                              
        IF jrsrem_f                     EQ . THEN jrsrem_f = 0;                                     
        IF jrsrem_p                     EQ . THEN jrsrem_p = 0;                                 
        IF jrsvac                       EQ . THEN jrsvac = 0;                              
        IF GeschatEnkelVakantieGeld     EQ . THEN GeschatEnkelVakantieGeld = 0;
        IF NPB                          EQ . THEN NPB = 0;
        
        KEEP 
        gecodeerd_insz
        Sal100                      Salatt                  Primes          Preavi                   Cotper Mntded_p
        GeschatDubbelVakantieGeld   BijzondereBijdrageDV    SolBijdrageDV   heurpt                   jrsasm jrspre           
        jrsrem_f                    jrsrem_p                jrsvac          GeschatEnkelVakantieGeld NPB    saljrs
        GROEP_EV
        ;
         
        /*Merk op: Waarom enkel persoonlijke solidariteitsbijdrage op dubbel vakantiegeld van groep 1: 
        /*Vermoedelijk bestaat er een equivalent in de vorm van een werkgeversbijdrage bij bedienden: nog navragen bij Marc Hubin*/
    RUN;
    
    PROC SORT DATA=Combin;
        BY gecodeerd_insz saljrs;
    RUN;
    
    DATA AggYear;
        SET Combin;
        BY gecodeerd_insz;
        RETAIN SumConcept1-SumConcept18 0;
    
        IF FIRST.gecodeerd_insz THEN DO;
            SumConcept1  = Sal100;                      
            SumConcept2  = Salatt;                  
            SumConcept3  = Primes;          
            SumConcept4  = Preavi; 
            IF GROEP_EV EQ    3  THEN DO;
                SumConcept18  = Cotper; 
            END;                
            ELSE DO;
                SumConcept5  = Cotper; 
            END;                
            SumConcept6  = Mntded_p;
            SumConcept7  = GeschatDubbelVakantieGeld;   
            SumConcept8  = BijzondereBijdrageDV;    
            SumConcept9  = SolBijdrageDV;   
            SumConcept10 = heurpt; 
            SumConcept11 = jrsasm; 
            SumConcept12 = jrspre;           
            SumConcept13 = jrsrem_f;                    
            SumConcept14 = jrsrem_p;                
            SumConcept15 = jrsvac;    
            SumConcept16 = GeschatEnkelVakantieGeld;
            SumConcept17 = NPB;
        END;
        ELSE DO;
            SumConcept1  = SumConcept1  + Sal100;                      
            SumConcept2  = SumConcept2  + Salatt;                  
            SumConcept3  = SumConcept3  + Primes;          
            SumConcept4  = SumConcept4  + Preavi; 
            IF GROEP_EV EQ    3  THEN DO;
                SumConcept18  = SumConcept18 + Cotper; 
            END;                
            ELSE DO;
                SumConcept5  = SumConcept5 + Cotper; 
            END;                
            SumConcept6  = SumConcept6  + Mntded_p;
            SumConcept7  = SumConcept7  + GeschatDubbelVakantieGeld;   
            SumConcept8  = SumConcept8  + BijzondereBijdrageDV;    
            SumConcept9  = SumConcept9  + SolBijdrageDV;   
            SumConcept10 = SumConcept10 + heurpt; 
            SumConcept11 = SumConcept11 + jrsasm; 
            SumConcept12 = SumConcept12 + jrspre;           
            SumConcept13 = SumConcept13 + jrsrem_f;                    
            SumConcept14 = SumConcept14 + jrsrem_p;                
            SumConcept15 = SumConcept15 + jrsvac;           
            SumConcept16 = SumConcept16 + GeschatEnkelVakantieGeld;
            SumConcept17 = SumConcept17 + NPB;
        END;
        IF LAST.gecodeerd_insz THEN OUTPUT;
    RUN;

    /*Write final output file*/
    DATA &LIB2..&ResFile._&Year.;

        SET AggYear;
        
        /*Rename variables*/        
        Sal100_&Year. =                       SumConcept1 ;
        Salatt_&Year. =                       SumConcept2 ;
        Primes_&Year. =                       SumConcept3 ;
        Preavi_&Year. =                       SumConcept4 ;
        Cotper12_&Year. =                     SumConcept5 ;
        Mntded_p_&Year. =                     SumConcept6 ;
        %NomValManip(SumConcept7,GeschatDubbelVakantieGeld_&Year.,10);
        BijzondereBijdrageDV_&Year. =         SumConcept8 ;
        SolBijdrageDV_&Year. =                SumConcept9 ;
        heurpt_&Year. =                       SumConcept10;
        jrsasm_&Year. =                       SumConcept11;
        jrspre_&Year. =                       SumConcept12;
        jrsrem_f_&Year. =                     SumConcept13;
        jrsrem_p_&Year. =                     SumConcept14;
        jrsvac_&Year. =                       SumConcept15;
        %NomValManip(SumConcept16,GeschatEnkelVakantieGeld_&Year.,10);
        NPB_&Year. =                          SumConcept17;
        Cotper3_&Year. =                      SumConcept18;
        saljrs_&Year. =                       saljrs      ;

        SumSal = Sal100_&Year. + Salatt_&Year. + Primes_&Year. + Preavi_&Year. ;
        %NomValManip(SumSal,SumSal_&Year.,10);
        
        /*Label amount variables*/
        LABEL Sal100_&Year. =                      "Het bedrag van de gewone bezoldigingen op jaarbasis (som voor jaar = &Year)";
        LABEL Salatt_&Year. =                      "Het bedrag van het loon betaald aan bestuurders voor wachttijden (som voor jaar = &Year)";
        LABEL Primes_&Year. =                      "Het bedrag van de bezoldigingen die niet rechtstreeks verbonden zijn met de prestaties (som voor jaar = &Year)";
        LABEL Preavi_&Year. =                      "Verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL SumSal_&Year. =                      "Som gewone bezoldigingen, loon bestuurders wachttijden, premies en verbrekingsvergoedingen (som voor jaar = &Year)";
        LABEL Cotper12_&Year. =                    "Bedrag van de normale persoonlijke bijdrage op basis van de bezoldigingen voor groepen EV 1 en 2 (som voor jaar = &Year)";
        LABEL Mntded_p_&Year. =                    "Vermindering op persoonlijke bijdrage (som voor jaar = &Year)";
        LABEL GeschatDubbelVakantieGeld_&Year. =   "Dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL BijzondereBijdrageDV_&Year. =        "Bijzondere bijdrage op dubbel vakantiegeld geschat rekening houdend met arbeidsmarktstatuut van het individu (som voor jaar = &Year)";
        LABEL SolBijdrageDV_&Year. =               "Solidariteitsbijdrage betaald op vakantiegeld van arbeiders (som voor jaar = &Year)";
        LABEL heurpt_&Year. =                      "Aantal uren deeltijds (som voor jaar = &Year)";
        LABEL jrsasm_&Year. =                      "Aantal gelijkgestelde dagen (som voor jaar = &Year)";
        LABEL jrspre_&Year. =                      "Aantal bezoldigde dagen: vooropzeg (som voor jaar = &Year)";
        LABEL jrsrem_f_&Year. =                    "Aantal bezoldigde dagen: full time (som voor jaar = &Year)";
        LABEL jrsrem_p_&Year. =                    "Aantal bezoldigde dagen: part time (som voor jaar = &Year)";
        LABEL jrsvac_&Year. =                      "Aantal bezoldigde dagen: vakantie (som voor jaar = &Year)";
        LABEL GeschatEnkelVakantieGeld_&Year. =    "Geschat enkel vakantiegeld van arbeiders (som voor jaar = &Year)";
        LABEL NPB_&Year. =                         "Geschatte persoonlijke bijdrage voor bepaalde bedienden (som voor jaar = &Year)";
        LABEL Cotper3_&Year. =                     "Bedrag van de normale persoonlijke bijdrage op basis van de bezoldigingen voor groep EV 3 (som voor jaar = &Year)";
        LABEL saljrs_&Year. =                      "Het gemiddeld dagloon (som voor jaar = &Year)";

        /*Keep nodige variabelen*/
        KEEP
        GECODEERD_INSZ 
        SumSal_&Year.
        GeschatDubbelVakantieGeld_&Year.
        GeschatEnkelVakantieGeld_&Year.
        heurpt_&Year.
        jrsasm_&Year. 
        jrsrem_f_&Year.
        jrsrem_p_&Year. 
        saljrs_&Year.
        ;        
    RUN;

	data &LIB2..&ResFile._&Year.;
		set &LIB2..&ResFile._&Year. (rename = (gecodeerd_insz = insz));
	run; 

%MEND ForEach;
%ForEach(20034);
%ForEach(20044);
%ForEach(20054);
%ForEach(20064);
%ForEach(20074);
%ForEach(20084);

