/*
Met dit programma voeren we manipulaties uit op RVA data
Gegevens worden gereduceerd tot n lijn per individu op basis van het hoogst geobserveerde uitbetalingsbedrag
en labels worden toegevoegd voor de weerhouden variabelen
Merk op: onder bijlevering 1 zaten nieuwe RVA files. Het enige verschil tussen de nieuwe en de oude files lijken de
variabelen "begaansc en schaansc" (eerste levering) en "beginact en eindact" (tweede levering) te zijn. Enkel de naamgeving 
verschilt. De waarden zijn gelijk. Vermits deze variabelen niet gebruikt worden, loopt het programma nog steeds op de
oude gegevens.
*/
/*Zet gebruikersopties*/
%let LIB1       = D_rva08;                    /*bibliotheek waar RVA-gegevens staan*/
%let SubFile1   = rva_081;
%let SubFile2   = rva_082;
%let SubFile3   = rva_083;
%let SubFile4   = rva_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile5   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RVA;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;

    /*Maak kwartaal data-sets*/
    %DO I = 1 %to 4;
        DATA Quart&I;
            MERGE   &LIB1..&&SubFile&I. (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SUBFILE5    (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
            InQuart&I = 1;
        RUN;            
    %END;

    DATA RVABasis;
        SET 
        %DO I = 1 %to 4;
            Quart&I
        %END;
        ;
    RUN;
    PROC SORT DATA=RVABasis;
        BY GECODEERD_INSZ fiche7 fiche61 bedragen;
    RUN;
    /*Merk op: is bedrag hier een kwartaalbedrag of het bedrag dat overeenkomt met de laatst geobserveerde maand van het kwartaal?*/
    DATA RVABasis;
        SET RVABasis;
        BY GECODEERD_INSZ fiche7 fiche61 bedragen;

        RETAIN Quart1-Quart4 " ";
        RETAIN SumConcept1-SumConcept3 0;
    
        IF FIRST.GECODEERD_INSZ OR FIRST.fiche7 OR FIRST.fiche61 THEN DO;
            %DO I = 1 %to 4;
                Quart&I = "0";
                IF InQuart&I EQ 1 THEN Quart&I = "1";
            %END;
            SumConcept1  = bedragen;                      
            SumConcept2  = dagen;                      
            SumConcept3  = urenpwa;                      
        END;    
        ELSE DO;
            %DO I = 1 %to 4;
                IF InQuart&I EQ 1 THEN Quart&I = "1";
            %END;
            SumConcept1  = SumConcept1  + bedragen;                      
            SumConcept2  = SumConcept2  + dagen;                      
            SumConcept3  = SumConcept3  + urenpwa;                      
        END;        

        IF LAST.GECODEERD_INSZ OR LAST.fiche7 OR LAST.fiche61 THEN OUTPUT;

    RUN;
    DATA &LIB2..&ResFile;
        SET RVABasis;

        LENGTH MONTH_RVA_&Year. $4.;
        
        MONTH_RVA_&Year. = Quart1 || Quart2 || Quart3 || Quart4 ;

        /*Definieer variabelen*/
        /*Reeds gebruikte variabelen in huidige versie*/     
        FICHE7_&Year.   = fiche7;
        DAGEN_&Year.    = SumConcept2;
        %NomValManip(DGNDMND,DGNDMND_&Year.,2);
        %NomValManip(SumConcept1,BEDRAGEN_&Year.,10);
        REDENLO_&Year.  = redenlo;
        VERMIN_&Year.   = vermin;
        VERHOG_&Year.   = verhog;
        DUUR_&Year.     = duur;
        URENPWA_&Year.  = SumConcept3;
        FICHE61_&Year.  = fiche61;
        /*Variabelen voor uitbreiding*/
        TYPEACT_&Year.  = TYPEACT;
        /*WET_&Year.      = wet;*/
        HOEDRVA_&Year.  = hoed;
        STATUT_&Year.   = statut;
        CONTRAT_&Year.  = contrat;
        CODENACE_&Year. = codenace;
        BREUKACT_&Year. = breukact;
        /*DUURLO_&Year.   = duurlo;*/

        /*Definieer labels variabelen*/
        /*Reeds gebruikte variabelen in huidige versie*/     
        LABEL GECODEERD_INSZ    = "Geanonimiseerd identificatienummer van het individu";
        LABEL FICHE7_&Year.     = "Typering werlkoosheid (statuut persoon bij RVA) (&Year.)";                                                                                                                                       
        LABEL DAGEN_&Year.      = "Aantal dagen waarvoor een werkloosheidsuitkering wordt ontvangen (&Year.)";                                                                                                                      
        LABEL DGNDMND_&Year.    = "Bedrag van de dagvergoeding die aan de werkloze toegekend wordt (&Year.)";                                                                                                                        
        LABEL BEDRAGEN_&Year.   = "bedrag van de werkloosheidsuitkering ontvangen tijdens het kwartaal (&Year.)";                                                                                                                    
        LABEL REDENLO_&Year.    = "Reden van loopbaanonderbreking (&Year.)";                                                                                                                                                        
        LABEL VERMIN_&Year.     = "Vermindering van de werkloosheidsuitkering wegens loopbaanonderbreking (&Year.)"; 
        LABEL VERHOG_&Year.     = "Verhoging van de werkloosheidsuitkering wegens loopbaanonderbreking (&Year.)";                                                                                                                   
        LABEL DUUR_&Year.       = "Werkloosheidsduur (&Year.)";                                                                                                                     
        LABEL URENPWA_&Year.    = "Aantal uren gewerkt in het kader van PWA gedurende het kwartaal (&Year.)";                                                                                                                       
        LABEL FICHE61_&Year.    = "Vergoedingscategorie van de werkloze (categorie van RVA) (&Year.)";                                                                                                                               
        /*Variabelen voor uitbreiding*/
        LABEL TYPEACT_&Year.    = "Code die voor de verschillende activeringsmaatregelen aangeeft aan welke toekenningsvoorwaarden de persoon voldoet (&Year.)"; 
        /*LABEL WET_&Year.        = "Informatie met betrekking tot de reglementering die van toepassing is in geval van loopbaanonderbreking (&Year.)";*/
        LABEL HOEDRVA_&Year.    = "Informatie over de bijkomstige activiteiten van de loopbaanonderbreker (&Year.)";                                                                               
        LABEL STATUT_&Year.     = "personeelsstatuut van de loopbaanonderbreker (&Year.)";                                                                                                              
        LABEL CONTRAT_&Year.    = "Type van arbeidscontract van de loopbaanonderbreker (bediende, arbeider, ...) (&Year.)"; 
        LABEL CODENACE_&Year.   = "Code van de sector waarin de loopbaanonderbreker actief was/is op basis van de NACE code (&Year.)"; 
        LABEL BREUKACT_&Year.   = "Percentage arbeidsduur (&Year.)"; 
        /*LABEL DUURLO_&Year.     = "Duur loopbaanonderbreking (&Year.)"; */
        LABEL MONTH_RVA_&Year.  = "Aanduiding van de maanden van het jaar &Year. waarin de gegeven combinatie geobserveerd wordt in RVA-bestanden";

        KEEP
        GECODEERD_INSZ
        FICHE7_&Year.   
        DAGEN_&Year.    
        DGNDMND_&Year.  
        BEDRAGEN_&Year. 
        REDENLO_&Year.  
        DUUR_&Year.     
        URENPWA_&Year.  
        FICHE61_&Year.
        ;
        
    RUN;

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;

%MEND ForEach;
%ForEach;


