/*
Met dit programma voeren we manipulaties uit op de RVP data
Betalingsgegevens worden samengevoegd tot een aggregaat op jaarbasis per code uit soort_pensioen
en voor ieder gegeven wordt de eerst geobserveerde betalingsdatum geselecteerd
Daarna worden een aantal testen uitgevoerd om te zien of ieder gegeven een datum heeft en of
er mogelijke aggregatiefouten gemaakt werden
*/
/*Zet gebruikersopties*/
%let LIB1       = D_rvp08;                    /*bibliotheek waar RVP-gegevens staan*/
%let SubFile1   = rvp_081;
%let SubFile2   = rvp_082;
%let SubFile3   = rvp_083;
%let SubFile4   = rvp_084;
%let LIB2       = MIMOSIS;                     /*bibliotheek met mimosis-gegevens*/
%let SubFile5   = mim2008_sample;          /*bestand met te gebruiken steekproef-nummers*/
%let ResFile    = mim2008_RVP_NationaalLegaal;
%let EEJJK      = 20084;
%let AantFiles  = 4;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);

/*Macro voor conversie datum-variabelen naar waarden met enkel maand en jaar*/
%Macro DateManip(VarAnal,VarOut);

    LENGTH JAAR  $4.;
    LENGTH MAAND $2.;

    /*Manipuleer jaar indien nodig*/
    JAAR = PUT(YEAR(&VarAnal),4.);
    IF YEAR(&VarAnal) EQ . THEN DO;
        JAAR        = "    ";
    END;
    /*Manipuleer maand indien nodig*/
    IF MONTH(&VarAnal) LT 1     OR  MONTH(&VarAnal) EQ .   THEN MAAND = "  ";
    IF MONTH(&VarAnal) GE 1     AND MONTH(&VarAnal) LT 10  THEN MAAND = "0" || PUT(MONTH(&VarAnal),1.);
    IF MONTH(&VarAnal) GE 10    AND MONTH(&VarAnal) LT 13  THEN MAAND = PUT(MONTH(&VarAnal),2.);
    IF MONTH(&VarAnal) GE 13                               THEN MAAND = "  ";
    &VarOut = MAAND || "-" || JAAR;
%Mend DateManip;
%Macro NomValManip(VarAnal,VarOut,ClassVal);
    
    &VarOut = &VarAnal;
    IF &VarAnal NE . AND &VarAnal NE 0 THEN DO;
        IF &VarAnal GT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal+%eval(&ClassVal))/%eval(&ClassVal));
        IF &VarAnal LT 0 THEN &VarOut = %eval(&ClassVal)*INT((&VarAnal-%eval(&ClassVal))/%eval(&ClassVal));
    END;
    
%Mend NomValManip;

/*Read possible values of type pension*/
DATA PensVal;
    INPUT Soort_Pensioen 1-10;
    DATALINES;
         1  
      1.11
      1.12
         2  
         3  
         4  
       4.1 
         5  
         6  
         7  
         8  
       8.1 
         9  
        10 
        11 
        12 
      12.1
        13 
      13.1
        14 
      14.1
        15 
      15.1
        16 
        17 
   ;
RUN;

/*Roep externe hulpmacro om waarden in array te steken*/
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* MACRO:  ARRAY                                                        *
*  PARAMETERS:                                                         *
*    array-name                                                        *
*    array-elements: either of                                         *
*      horizontal list of array element values                         *
*                      delimiters may be specified, see default list   *
*      vertical   list: dataset w/ variable containing array values    *
*                                                                      *
*  USAGE: 1. %_ARRAY(ARAYNAME,ITEM-LIST);                              *
*         2. %_ARRAY(ARAYNAME,ITEM-LIST,DELIMITR=/);                   *
*         3. %_ARRAY(ARAYNAME,DATA=DATANAME,VAR=Var-Name);             *
*                                                                      *
*  DESCRIPTION:                                                        *
*    This macro returns a series of global macro-variables             *
*    named &ARAYNAME.1  &ARAYNAME.2 .. &ARAYNAME.n                     *
*    and a macro-variable named DIM_&ARAYNAME.                         *
*    i.e. %ARRAY(VAR,Q04A Q04B Q04C);                                  *
*    returns:    VAR1::Q04A VAR2::Q04B VAR3::Q04C, DIM_VAR::3          *
*                                                                      *
*  NOTES:                                                              *
*    length(ARAYNAME) must be <= 4                                     *
*    length(ARAYNAME) + length(dim_ARAYNAME) must be <= 8              *
*                                                                      *
*  CAUTION: creates %GLOBAL macro-variables                            *
*                                                                      *
*  PROCESS: case 1: scan user-provided list of array-elements          *
*           case 2: data set: call symput of variable                  *
*           case 3: error msg                                          *
*                                                                      *
*  KeyWords: array %ARRAY CONTENTS delimiter loop macro PARMBUFF %scan *
*            symput SYSPBUFF %until                                    *
*                                                                      *
*  Author: Ron Fehd,   MS-G25                  RJF2@phpdLs1.em.cdc.gov *
*          Centers for Disease Control, and Prevention                 *
*          4770 Buford Hwy NE                        fax: 404/488-7667 *
*          Atlanta  GA  30341-3724                 voice: 404/488-4316 *
*                                                                      *
*  SAS Guide to Macro Processing, V6 2e,                               *
*   delimiters: see scan                                               *
*   series of macro variables: pg 166                                  *
*   scan  : pg 126                                                     *
*   symput: pg 165                                                     *
RJF2:94Jan18 added DELIMITR=default list                               *
RJF2:95Mar02 polishing                                                 *
RJF2:96Feb13 handling obs=0                                            *
RJF2:96Jul09 rework scan algorithm for SESUG paper                     *
RJF2:96Jul09 changed: replace %scan with %qscan:                       *
RJF2:96Jul09 %qscan simplifies %do %until test                         *
RJF2:96Jul22 simplified error msgs                                     *
RJF2:96Jul22 removed comma and semicolon from DELIMITR                 *
RJF2:96Jul24 added PARMBUFF for error msg, polishing                   *
RJF2:96Dec27 changed scan to qscan to avoid errmsg scanning NOT        *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
%MACRO ARRAY(/*-------------------------------------------------------*/
 ARAYNAME    /*macro-var array-name: len(array-name) must be <= 4     */
,ITEMLIST    /*horizontal list of array-elements                      */
,DATA    =.  /*vertical list: dataset name                            */
,VAR     =.  /*vertical list: variable in dataset                     */
,DELIMITR=%STR( ).<%str(()]&!$*%str())^-/%>\/*delimiter of horiz-list */
)/PARMBUFF;/* PARMBUFF: see SYSPBUFF ---------------------------------*/

%IF  "&ARAYNAME" ne ""/*- case 1: ARAYNAME & ITEMLIST ----------------*/
 and "&ITEMLIST" ne ""
 and %length(&ARAYNAME) le 4 %THEN %DO;
 %local I ITEM;
 %LET I    = 1;
 %LET ITEM = %Qscan(&ITEMLIST,&I.,&DELIMITR);
 %DO %until(&ITEM = ); %global &ARAYNAME.&I;
                       %LET &ARAYNAME.&I = &ITEM.;
                       %LET I            = %eval(&I + 1);
                       %LET ITEM      = %Qscan(&ITEMLIST,&I.,&DELIMITR);
                                                   /* %DO %until*/ %END;
 %global DIM_&ARAYNAME;
 %LET    DIM_&ARAYNAME = %eval(&I - 1);
 %PUT macro proc ARRAY returns array: &ARAYNAME, dim=&&DIM_&ARAYNAME.;
 %PUT from list <&ITEMLIST.>;
 /*........................................ ARAYNAME & ITEMLIST */ %END;

%ELSE %IF "&ARAYNAME" ne "" /*- case 2: ARAYNAME & (DATA & VAR) ------*/
      and "&ITEMLIST" eq ""
      and "&DATA"     ne "." and "&VAR" ne "."
      and %length(&ARAYNAME) le 4 %THEN %DO;

proc CONTENTS data = &DATA   (keep = &VAR.) noprint
              out  = CONTENTS(keep = Nobs Type);

%global DIM_&ARAYNAME;

DATA _NULL_;
 length VarType $ 1;
 set CONTENTS;
 if Type = 1 then VarType = 'N';
 else             VarType = 'C';
 call symput("VARTYPE" ,VarType);
 call symput("DIM_&ARAYNAME",trim(left(put(Nobs,32.))));
stop; run;

%local I;
%DO    I = 1 %TO &&DIM_&ARAYNAME.; %global &ARAYNAME.&I.;          %END;

DATA _NULL_;                   /* symput(mac-var name : prefix + suffix,
 retain I 0;                             mac-var value: variable name */
 do until(EndoFile);
   set &DATA end = EndoFile;
   I + 1;
   call symput("&ARAYNAME" !!        left(put(I   , 7.0 )),
                                trim(left(
     %IF "&VARTYPE" = "N" %THEN           put(&VAR,best32.16)          ;
     %ELSE                                    &VAR                     ;
                                                 /*symput closure*/ )));
                                                  /*do until(EOF)*/ end;
stop; run;
%PUT macro proc ARRAY returns array: &ARAYNAME, dim=&&DIM_&ARAYNAME.;
%PUT from data = &DATA, var = &VAR.;
 /*......................................ARAYNAME & (DATA & VAR)*/ %END;

%ELSE %DO;/* print error msg -----------------------------------------*/

  %PUT ERROR: in macro ARRAY:;
  %PUT array-name : required;
  %PUT array-elements may be list, or (data and var);
  %PUT list    : ARRAY(ARAYNAME,ITEM-LIST);
  %PUT data+var: ARRAY(ARAYNAME,DATA=DATA-NAME,VAR=VAR-NAME);

  %IF %length(&ARAYNAME) gt 4 %THEN
   %PUT length(ARAYNAME) must be <= 4;
  %PUT parmlist: <&SYSPBUFF.>;/*from /PARMBUFF macro statement option*/
  %PUT parm: ARAYNAME = <&ARAYNAME.> length = <%length(&ARAYNAME)>;
  %PUT parm: ITEMLIST = <&ITEMLIST.>;
  %PUT parm: DATA     = <&DATA.>    ;
  %PUT parm: VAR      = <&VAR.>     ;
 /*.................................................. ANY ERRORS*/ %END;
 /*..................................................... ARRAY */ %MEND;

 /*-test data ------------ enable by ending this line with slash (/) **
DATA VQ04;  *convention for %CHECKALL setup;
length Name $ 8;  *can use proc CONTENTS output data set;
Name =  Q04A'; output;
Name =  Q04B'; output;
Name =  Q04C'; output; run;
%MACRO DEMO(DATA_OUT,ITEMLIST);* typical usage -----------------------*;
%IF &ITEMLIST ne %THEN %ARRAY(VAR, &ITEMLIST.);
%ELSE                  %ARRAY(VAR, DATA = V&DATA_OUT., VAR = Name);
%DO I = 1 %TO &DIM_VAR.; %PUT VAR&I. :: &&VAR&I.;                  %END;
 *....................................................... DEMO *; %MEND;
%DEMO(Q03, Q03A Q03B Q03C);  *data exploration usage;
%DEMO(Q04);  *production usage;
%ARRAY(TOOBIG,A B C D E);*see error msg;
%PUT _user_;*show list of macro-variables;
run; /*................................................. TEST DATA END*/


/*Start macro die over files moet uitgevoerd worden*/
%MACRO ForEach;
    /*Start loop over aantal files*/
     %DO I = 1 %to &AantFiles;

        /*Start processing data of a given quarter*/
        /*set only legal pensions according to national legislation*/
        DATA RVPBasis;
            MERGE   &LIB1..&&SubFile&I (In=InA rename = (insz = gecodeerd_insz))
                    &LIB2..&SUBFILE5   (In=InB rename = (insz = gecodeerd_insz))
            ;
            BY gecodeerd_insz;
            IF ina=1 and inb=1;
        RUN;
        /*Sort by starting date: later on the first data that differs from 0 will be used to determine the starting date of the right*/
        PROC SORT DATA=RVPBasis;
            BY gecodeerd_insz begindatum_huidig_recht_c;
        RUN;
        /*Manipulate the data such that impossible values can no longer occur*/
        /*assumption here is that dates lower than 0 or after 2006 can not occur in a data set of 2006: Is this correct???*/
        DATA ManipDate;
            SET RVPBasis;
            BY gecodeerd_insz begindatum_huidig_recht_c;
            /*read in numeric values of year and month*/
/*          yearSTART     = INPUT(SUBSTR(TRIM(begindatum_huidig_recht_c),1,4),8.);
            monthSTART    = INPUT(SUBSTR(TRIM(begindatum_huidig_recht_c),5,2),8.);
*/            
            yearSTART     = FLOOR(begindatum_huidig_recht_c/10000);
            monthSTART    = FLOOR((begindatum_huidig_recht_c-yearSTART*10000)/100);
            /*manipulate numeric values of year and month*/
            IF yearSTART LT 0 OR yearSTART GT %EVAL(&Year) THEN yearSTART = %EVAL(&Year);
            IF monthSTART LT 0 THEN monthSTART = 1;
            IF monthSTART GT 12 THEN monthSTART = 12;
            /*convert numeric values again to final character value of 6 long*/
            LENGTH begindatum_recht $6.;
            LENGTH yearSTART_CHAR   $4.;
            LENGTH monthSTART_CHAR  $2.;
            yearSTART_CHAR   = PUTN(yearSTART,'4.');
            IF monthSTART LT 10 THEN DO;
                monthSTART_CHAR  = '0' || PUTN(monthSTART,'1.'); 
            END;    
            ELSE DO;
                monthSTART_CHAR  = PUTN(monthSTART,'2.');
            END;        
            begindatum_recht = yearSTART_CHAR || monthSTART_CHAR;
            DROP yearSTART monthSTART yearSTART_CHAR monthSTART_CHAR;  
        RUN;
        PROC FREQ DATA=ManipDate;
            TABLES begindatum_recht;
        RUN;            
        /*Use the %array function to put different values of Soort_Pensioen in macro-variable*/
        %ARRAY(Pval,DATA=PensVal,VAR=Soort_Pensioen);           
        /*Create file with variables containing the gross amount and the starting month of payment of the benefit*/
        DATA Q&I._AmountBPlusDateB;
            SET ManipDate;
            BY gecodeerd_insz begindatum_huidig_recht_c;
            /*Make arrays to store results*/
            LENGTH  Q&I._DateB1-Q&I._DateB&dim_Pval. $6.;
            ARRAY   DateB     {%eval(&dim_Pval)} $    Q&I._DateB1-Q&I._DateB&dim_Pval.;
            ARRAY   AmountB   {%eval(&dim_Pval)}      Q&I._AmountB1-Q&I._AmountB&dim_Pval.;
            /*ensure that if a value is identified for an individual, that new values are added: use the RETAIN statement for this*/
            RETAIN Q&I._DateB1-Q&I._DateB&dim_Pval.     ;
            RETAIN Q&I._AmountB1-Q&I._AmountB&dim_Pval. ;
            /*Initialise values to 0 or missing for each individual*/
            IF FIRST.gecodeerd_insz THEN DO;
                %DO j = 1 %to %eval(&dim_Pval);
                    DateB(&j) = '      ';
                    AmountB(&j) = 0;
                %END;   
            END;
            /*Select pension value and put it in the appropriate aggregate*/
            %DO j = 1 %to %eval(&dim_Pval);
                IF soort_pensioen_volledig EQ &&Pval&j THEN DO;                    
                    /*distinguish the first line of an individual and other lines*/
                    IF first.gecodeerd_insz THEN DO;
                        /*only set gross amount if it is not missing*/
                        IF brutobedrag NE . THEN DO;
                            Q&I._AmountB&j. = brutobedrag;
                        END;
                        /*only identify date if it is not missing*/
                        IF begindatum_recht NE '      ' THEN DO;
                            Q&I._DateB&j. = begindatum_recht;
                        END;
                    END;
                    ELSE DO;
                        /*only add a gross amount if it is not missing*/
                        IF brutobedrag NE . THEN DO;
                            Q&I._AmountB&j. = Q&I._AmountB&j. + brutobedrag;
                        END;
                        /*only identify date if it is not missing and has not been identified before*/
                        IF begindatum_recht NE '      ' AND Q&I._DateB&j. EQ '      ' THEN DO;
                            Q&I._DateB&j. = begindatum_recht;
                        END;
                    END;
                END;        
            %END;   
            
            IF LAST.gecodeerd_insz THEN OUTPUT;
            KEEP gecodeerd_insz Q&I._AmountB1-Q&I._AmountB&dim_Pval. Q&I._DateB1-Q&I._DateB&dim_Pval.;
        RUN;
        /*Create file with variables containing other characteristics of the pensioner*/
        DATA Q&I._Characteristics;
            SET RVPBasis(KEEP = gecodeerd_insz code_gezinslast code_echtgenote aantal_kind aantal_andere Code_alleenstaande brutobedrag begindatum_pensioen_c);
        RUN;
        /*Compute some statistics to carry out tests at the end of the program*/
        /*Make sum of all observed amounts*/
        PROC MEANS DATA=ManipDate SUM NOPRINT;
            VAR     brutobedrag;
            OUTPUT  OUT=Q&I._OutMeanTot
                    SUM(brutobedrag)=SumBrutobedrag_Q&I.
                    ;
        RUN;            
        PROC MEANS DATA=Q&I._AmountBPlusDateB SUM NOPRINT;
            VAR     Q&I._AmountB1-Q&I._AmountB&dim_Pval.;
            OUTPUT  OUT=Q&I._OutMeanParts
                    %DO j = 1 %to %eval(&dim_Pval);
                        SUM(Q&I._AmountB&j)=SumQ&I._AmountB&j
                    %END;   
                    ;
        RUN;
                
    %END;
    
    /*Cobine characteristics*/
    DATA COMBIN_Char;
        SET
        %DO I = 1 %to &AantFiles;
            Q&I._Characteristics
        %END;                
        ;
    RUN;
    PROC SORT DATA=COMBIN_Char;
        BY gecodeerd_insz brutobedrag;
    RUN;
    DATA COMBIN_Char;
        SET COMBIN_Char;
        BY  gecodeerd_insz;
        
        code_gezinslast_&Year.          = code_gezinslast; 
        code_echtgenote_&Year.          = code_echtgenote;
        aantal_kind_&Year.              = aantal_kind; 
        aantal_andere_&Year.            = aantal_andere; 
        Code_alleenstaande_&Year.       = Code_alleenstaande; 

        LABEL code_gezinslast_&Year.        = "Code gezinslast (geregistreerd in &Year)";                                                                                                                                                                                         
        LABEL code_echtgenote_&Year.        = "Code echtgenote ten laste (geregistreerd in &Year)";                                                                                                                                                                               
        LABEL aantal_kind_&Year.            = "Aantal kinderen ten laste (geregistreerd in &Year)";                                                                                                                                                                                
        LABEL aantal_andere_&Year.          = "Aantal andere personen ten laste (geregistreerd in &Year)";                                                                                                                                                                        
        LABEL Code_alleenstaande_&Year.     = "Code alleenstaande (geregistreerd in &Year)";                                                                                                                                                                                      
        LABEL begindatum_pensioen_c  = "begindatum_pensioen_c (geregistreerd in &Year)";                                                                                                                                                                                      
        
        IF LAST.gecodeerd_insz THEN OUTPUT;
        KEEP gecodeerd_insz begindatum_pensioen_c code_gezinslast_&Year. code_echtgenote_&Year. aantal_kind_&Year. aantal_andere_&Year. Code_alleenstaande_&Year.;
    RUN;

    /*Merge four quarter files and derive annual values*/
    DATA COMBIN_4Quarters;
        MERGE 
            %DO I = 1 %to &AantFiles;
                Q&I._AmountBPlusDateB
            %END;
            ;
        BY gecodeerd_insz;
        /*Declare arrays of existing variables*/
        %DO I = 1 %to &AantFiles;
            ARRAY   Q&I._DateB    {%eval(&dim_Pval)} $    Q&I._DateB1-Q&I._DateB&dim_Pval.;
            ARRAY   Q&I._AmountB  {%eval(&dim_Pval)}      Q&I._AmountB1-Q&I._AmountB&dim_Pval.;
        %END;                
        /*Declare arrays of new variables*/
        LENGTH  DateB1-DateB&dim_Pval. $6.;
        ARRAY   DateB       {%eval(&dim_Pval)} $    DateB1-DateB&dim_Pval.;
        ARRAY   AmountB     {%eval(&dim_Pval)}      AmountB1-AmountB&dim_Pval.;
        /*set missing numeric values to 0 and initialise basic values*/
        %DO j = 1 %to %eval(&dim_Pval);
            %DO I = 1 %to &AantFiles;
                IF Q&I._AmountB(&j) EQ . THEN Q&I._AmountB(&j) = 0;
            %END;        
            DateB(&j) = '      ';
            AmountB(&j) = 0;
        %END;
        /*Compute annual values*/
        /*use the first date of payment that is not missing as annual value*/
        %DO j = 1 %to %eval(&dim_Pval);
            %DO I = 1 %to &AantFiles;
                AmountB(&j) = AmountB(&j) + Q&I._AmountB(&j);  
                IF (DateB(&j) EQ '      ' AND Q&I._DateB(&j) NE '      ') THEN DateB(&j) = Q&I._DateB(&j);
            %END;        
        %END;
        KEEP gecodeerd_insz AmountB1-AmountB&dim_Pval. DateB1-DateB&dim_Pval.;
    RUN;
    /*Compute test variables to check how many times a date is missing when the amount is positive*/
    DATA TestFreq;
        SET COMBIN_4Quarters;
        /*Declare arrays of existing variables*/
        ARRAY   DateB       {%eval(&dim_Pval)} $    DateB1-DateB&dim_Pval.;
        ARRAY   AmountB     {%eval(&dim_Pval)}      AmountB1-AmountB&dim_Pval.;
        /*Declare array of new created variables*/
        ARRAY   TestFreq    {%eval(&dim_Pval)}      TestFreq1-TestFreq&dim_Pval.;
        /*Identify cases where amount is positive and starting date of payments is missing throughout the whole year*/
        %DO j = 1 %to %eval(&dim_Pval);
            TestFreq(&j) = 0;
            IF AmountB(&j) GT 0 AND DateB(&j) EQ '      ' THEN TestFreq(&j) = 1;
        %END;
    RUN;
    /*Test whether positive amounts have received a date of payement value*/
    %DO j= 1 %TO %eval(&dim_Pval);
        PROC FREQ DATA=TestFreq;
            TABLES  TestFreq&j. / OUT=OutFreq;
        RUN;    
    %END;               
    /*Compute some statistics on amounts to carry out comparisons with previously computed values*/
    PROC MEANS DATA=COMBIN_4Quarters SUM ;
        VAR AmountB1-AmountB&dim_Pval.;
        OUTPUT  OUT=Ann_OutMeanParts
                %DO j = 1 %to %eval(&dim_Pval);
                    SUM(AmountB&j)=SumAnn_AmountB&j
                %END;   
                ;
    RUN;
    /*Combine all computed test statistics in one file*/
    DATA TestValues;
        /*Values from quarter files*/
        %DO I = 1 %to &AantFiles;
            SET Q&I._OutMeanTot;
            SET Q&I._OutMeanParts;
        %END;
        /*Values from combined annual file*/
        SET Ann_OutMeanParts;
        /*Define arrays of existing values*/
        %DO I = 1 %to &AantFiles;
            ARRAY   SumQ&I._AmountB {%eval(&dim_Pval)}    SumQ&I._AmountB1-SumQ&I._AmountB&dim_Pval.;
        %END;
        ARRAY   SumAnn_AmountB      {%eval(&dim_Pval)}    SumAnn_AmountB1-SumAnn_AmountB&dim_Pval.;
        /*Define arrays of new values*/
        ARRAY   SumAnn_Parts        {%eval(&dim_Pval)}    SumAnn_PartsB1-SumAnn_PartsB&dim_Pval.;
        ARRAY   SumQuart_Tot        {%eval(&AantFiles)}   SumQuart_TotQ1-SumQuart_TotQ&AantFiles;
        /*Initialise values of classified cases and set missing values to 0*/
        %DO j = 1 %to %eval(&dim_Pval);
            %DO I = 1 %to &AantFiles;
                IF SumQ&I._AmountB(&j) EQ . THEN SumQ&I._AmountB(&j) = 0;
            %END;
            SumAnn_Parts(&j) = 0;
        %END; 
        DO i=1 TO %eval(&AantFiles);
            SumQuart_Tot(i) = 0;
        END;
        /*Compute annual values of classified cases so that the result can be compared with what is in the merged file*/
        %DO j = 1 %to %eval(&dim_Pval);
            %DO I = 1 %to &AantFiles;
                SumAnn_Parts(&j) = SumAnn_Parts(&j) + SumQ&I._AmountB(&j);
                SumQuart_Tot(&I) = SumQuart_Tot(&I) + SumQ&I._AmountB(&j); 
            %END;
        %END;
    RUN;
    PROC PRINT DATA=TestValues;
    RUN;

    /*Merk op: later eventueel nog een teller toevoegen om maandbedragen beter te berekenen*/
    
    /*Create file for integration in final MIMOSIS input file*/
    DATA &LIB2..&ResFile;
        MERGE COMBIN_4Quarters COMBIN_Char;
        BY GECODEERD_INSZ;

        LABEL GECODEERD_INSZ      = "Geanonimiseerd identificatienummer van het individu";

        /*rename amounts*/
        %NomValManip(AmountB1,RPWE_&Year.,10)
        %NomValManip(AmountB2,FIRPCAP_&Year.,10)
        %NomValManip(AmountB3,FISPCAP_&Year.,10)
        %NomValManip(AmountB4,RPSE_&Year.,10)
        %NomValManip(AmountB5,RPCIV_&Year.,10)
        %NomValManip(AmountB6,RPFOR_&Year.,10)
        %NomValManip(AmountB7,RPDOSZ_&Year.,10)
        %NomValManip(AmountB8,SPWE_&Year.,10)
        %NomValManip(AmountB9,SPSE_&Year.,10)
        %NomValManip(AmountB10,SPCIV_&Year.,10)
        %NomValManip(AmountB11,SPFOR_&Year.,10)
        %NomValManip(AmountB12,SPDOSZ_&Year.,10)
        %NomValManip(AmountB13,CAPFIRST_&Year.,10)
        %NomValManip(AmountB14,IGO_&Year.,10)
        %NomValManip(AmountB15,DISAB_&Year.,10)
        %NomValManip(AmountB16,RPRENT_SPILPRIV_&Year.,10)
        %NomValManip(AmountB17,RPRENT_SPILPUB_&Year.,10)
        %NomValManip(AmountB18,SPRENT_SPILPRIV_&Year.,10)
        %NomValManip(AmountB19,SPRENT_SPILPUB_&Year.,10)
        %NomValManip(AmountB20,RPCAP_SPILPRIV_&Year.,10)
        %NomValManip(AmountB21,RPCAP_SPILPUB_&Year.,10)
        %NomValManip(AmountB22,SPCAP_SPILPRIV_&Year.,10)
        %NomValManip(AmountB23,SPCAP_SPILPUB_&Year.,10)
        %NomValManip(AmountB24,DIRPENS_&Year.,10)
        %NomValManip(AmountB25,OTHPENS_&Year.,10)

		begindatum_pensioen_c_&EEJJ. = substr(begindatum_pensioen_c,1,6);

        /*Label amount variables*/
        LABEL RPWE_&Year.                  =  "rustpensioen werknemer (betalingsjaar = &Year)";
        LABEL FIRPCAP_&Year.               =  "voordelen vrije verzekerden (rust) (kapitaal) (betalingsjaar = &Year)";
        LABEL FISPCAP_&Year.               =  "voordelen vrije verzekerden (overleving) (kapitaal) (betalingsjaar = &Year)";
        LABEL RPSE_&Year.                  =  "rustpensioen zelfstandige (betalingsjaar = &Year)";
        LABEL RPCIV_&Year.                 =  "rustpensioen overheid (betalingsjaar = &Year)";
        LABEL RPFOR_&Year.                 =  "buitenlands rustpensioen (betalingsjaar = &Year)";
        LABEL RPDOSZ_&Year.                =  "rustpensioen DOSZ (betalingsjaar = &Year)";
        LABEL SPWE_&Year.                  =  "overlevingspensioen werknemer (betalingsjaar = &Year)";
        LABEL SPSE_&Year.                  =  "overlevingspensioen zelfstandige (betalingsjaar = &Year)";
        LABEL SPCIV_&Year.                 =  "overlevingspensioen overheid (betalingsjaar = &Year)";
        LABEL SPFOR_&Year.                 =  "buitenlands overlevingspensioen (betalingsjaar = &Year)";
        LABEL SPDOSZ_&Year.                =  "overlevingspensioen DOSZ (betalingsjaar = &Year)";
        LABEL CAPFIRST_&Year.              =  "kapitalen eerste pijler (betalingsjaar = &Year)";
        LABEL IGO_&Year.                   =  "GIB/IGO (betalingsjaar = &Year)";
        LABEL DISAB_&Year.                 =  "tegemoetkoming mindervaliden (betalingsjaar = &Year)";
        LABEL RPRENT_SPILPRIV_&Year.       =  "tweedepijler(rust)pensioen, rente-uitkering door private instelling (betalingsjaar = &Year)";
        LABEL RPRENT_SPILPUB_&Year.        =  "tweedepijler(rust)pensioen, rente-uitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL SPRENT_SPILPRIV_&Year.       =  "tweedepijler(overlevings)pensioen, rente-uitkering door private instelling (betalingsjaar = &Year)";
        LABEL SPRENT_SPILPUB_&Year.        =  "tweedepijler(overlevings)pensioen, rente-uitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL RPCAP_SPILPRIV_&Year.        =  "tweedepijler(rust)pensioen, kapitaaluitkering door private instelling (betalingsjaar = &Year)";
        LABEL RPCAP_SPILPUB_&Year.         =  "tweedepijler(rust)pensioen, kapitaaluitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL SPCAP_SPILPRIV_&Year.        =  "tweedepijler(overlevings)pensioen, kapitaaluitkering door private instelling (betalingsjaar = &Year)";
        LABEL SPCAP_SPILPUB_&Year.         =  "tweedepijler(overlevings)pensioen, kapitaaluitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL DIRPENS_&Year.               =  "afgeleide pensioenen (betalingsjaar = &Year)";
        LABEL OTHPENS_&Year.               =  "overige pensioenbedragen (betalingsjaar = &Year)";

        /*rename dates*/
        RPWE_PDATE_&Year.                  =  DateB1    ;
        FIRPCAP_PDATE_&Year.               =  DateB2    ;
        FISPCAP_PDATE_&Year.               =  DateB3    ;
        RPSE_PDATE_&Year.                  =  DateB4    ;
        RPCIV_PDATE_&Year.                 =  DateB5    ;
        RPFOR_PDATE_&Year.                 =  DateB6    ;
        RPDOSZ_PDATE_&Year.                =  DateB7    ;
        SPWE_PDATE_&Year.                  =  DateB8    ;
        SPSE_PDATE_&Year.                  =  DateB9    ;
        SPCIV_PDATE_&Year.                 =  DateB10    ;
        SPFOR_PDATE_&Year.                 =  DateB11    ;
        SPDOSZ_PDATE_&Year.                =  DateB12    ;
        CAPFIRST_PDATE_&Year.              =  DateB13    ;
        IGO_PDATE_&Year.                   =  DateB14    ;
        DISAB_PDATE_&Year.                 =  DateB15    ;
        RPRENT_SPILPRIV_PDATE_&Year.       =  DateB16    ;
        RPRENT_SPILPUB_PDATE_&Year.        =  DateB17    ;
        SPRENT_SPILPRIV_PDATE_&Year.       =  DateB18    ;
        SPRENT_SPILPUB_PDATE_&Year.        =  DateB19    ;
        RPCAP_SPILPRIV_PDATE_&Year.        =  DateB20    ;
        RPCAP_SPILPUB_PDATE_&Year.         =  DateB21    ;
        SPCAP_SPILPRIV_PDATE_&Year.        =  DateB22    ;
        SPCAP_SPILPUB_PDATE_&Year.         =  DateB23    ;
        DIRPENS_PDATE_&Year.               =  DateB24    ;
        OTHPENS_PDATE_&Year.               =  DateB25    ;
        /*Label date variables*/
        LABEL RPWE_PDATE_&Year.                  =  "startdatum betaling rustpensioen werknemer (betalingsjaar = &Year)";
        LABEL FIRPCAP_PDATE_&Year.               =  "startdatum betaling voordelen vrije verzekerden (rust) (kapitaal) (betalingsjaar = &Year)";
        LABEL FISPCAP_PDATE_&Year.               =  "startdatum betaling voordelen vrije verzekerden (overleving) (kapitaal) (betalingsjaar = &Year)";
        LABEL RPSE_PDATE_&Year.                  =  "startdatum betaling rustpensioen zelfstandige (betalingsjaar = &Year)";
        LABEL RPCIV_PDATE_&Year.                 =  "startdatum betaling rustpensioen overheid (betalingsjaar = &Year)";
        LABEL RPFOR_PDATE_&Year.                 =  "startdatum betaling buitenlands rustpensioen (betalingsjaar = &Year)";
        LABEL RPDOSZ_PDATE_&Year.                =  "startdatum betaling rustpensioen DOSZ (betalingsjaar = &Year)";
        LABEL SPWE_PDATE_&Year.                  =  "startdatum betaling overlevingspensioen werknemer (betalingsjaar = &Year)";
        LABEL SPSE_PDATE_&Year.                  =  "startdatum betaling overlevingspensioen zelfstandige (betalingsjaar = &Year)";
        LABEL SPCIV_PDATE_&Year.                 =  "startdatum betaling overlevingspensioen overheid (betalingsjaar = &Year)";
        LABEL SPFOR_PDATE_&Year.                 =  "startdatum betaling buitenlands overlevingspensioen (betalingsjaar = &Year)";
        LABEL SPDOSZ_PDATE_&Year.                =  "startdatum betaling overlevingspensioen DOSZ (betalingsjaar = &Year)";
        LABEL CAPFIRST_PDATE_&Year.              =  "startdatum betaling kapitalen eerste pijler (betalingsjaar = &Year)";
        LABEL IGO_PDATE_&Year.                   =  "startdatum betaling GIB/IGO (betalingsjaar = &Year)";
        LABEL DISAB_PDATE_&Year.                 =  "startdatum betaling tegemoetkoming mindervaliden (betalingsjaar = &Year)";
        LABEL RPRENT_SPILPRIV_PDATE_&Year.       =  "startdatum betaling tweedepijler(rust)pensioen, rente-uitkering door private instelling (betalingsjaar = &Year)";
        LABEL RPRENT_SPILPUB_PDATE_&Year.        =  "startdatum betaling tweedepijler(rust)pensioen, rente-uitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL SPRENT_SPILPRIV_PDATE_&Year.       =  "startdatum betaling tweedepijler(overlevings)pensioen, rente-uitkering door private instelling (betalingsjaar = &Year)";
        LABEL SPRENT_SPILPUB_PDATE_&Year.        =  "startdatum betaling tweedepijler(overlevings)pensioen, rente-uitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL RPCAP_SPILPRIV_PDATE_&Year.        =  "startdatum betaling tweedepijler(rust)pensioen, kapitaaluitkering door private instelling (betalingsjaar = &Year)";
        LABEL RPCAP_SPILPUB_PDATE_&Year.         =  "startdatum betaling tweedepijler(rust)pensioen, kapitaaluitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL SPCAP_SPILPRIV_PDATE_&Year.        =  "startdatum betaling tweedepijler(overlevings)pensioen, kapitaaluitkering door private instelling (betalingsjaar = &Year)";
        LABEL SPCAP_SPILPUB_PDATE_&Year.         =  "startdatum betaling tweedepijler(overlevings)pensioen, kapitaaluitkering door publieke instelling (betalingsjaar = &Year)";
        LABEL DIRPENS_PDATE_&Year.               =  "startdatum betaling afgeleide pensioenen (betalingsjaar = &Year)";
        LABEL OTHPENS_PDATE_&Year.               =  "startdatum betaling overige pensioenbedragen (betalingsjaar = &Year)";
        
        KEEP
        GECODEERD_INSZ 
        RPWE_&Year.                 
        FIRPCAP_&Year.                  
        FISPCAP_&Year.              
        RPSE_&Year.                  
        RPCIV_&Year.                
        RPFOR_&Year.                    
        RPDOSZ_&Year.               
        SPWE_&Year.                  
        SPSE_&Year.                 
        SPCIV_&Year.                    
        SPFOR_&Year.                
        SPDOSZ_&Year.                
        CAPFIRST_&Year.             
        IGO_&Year.                      
        DISAB_&Year.                
        RPRENT_SPILPRIV_&Year.       
        RPRENT_SPILPUB_&Year.       
        SPRENT_SPILPRIV_&Year.          
        SPRENT_SPILPUB_&Year.       
        RPCAP_SPILPRIV_&Year.        
        RPCAP_SPILPUB_&Year.        
        SPCAP_SPILPRIV_&Year.           
        SPCAP_SPILPUB_&Year.        
        DIRPENS_&Year.               
        OTHPENS_&Year.               
        RPWE_PDATE_&Year.           
        FIRPCAP_PDATE_&Year.            
        FISPCAP_PDATE_&Year.        
        RPSE_PDATE_&Year.                
        RPCIV_PDATE_&Year.          
        RPFOR_PDATE_&Year.              
        RPDOSZ_PDATE_&Year.         
        SPWE_PDATE_&Year.                
        SPSE_PDATE_&Year.           
        SPCIV_PDATE_&Year.              
        SPFOR_PDATE_&Year.          
        SPDOSZ_PDATE_&Year.              
        CAPFIRST_PDATE_&Year.       
        IGO_PDATE_&Year.                
        DISAB_PDATE_&Year.          
        RPRENT_SPILPRIV_PDATE_&Year.     
        RPRENT_SPILPUB_PDATE_&Year. 
        SPRENT_SPILPRIV_PDATE_&Year.    
        SPRENT_SPILPUB_PDATE_&Year. 
        RPCAP_SPILPRIV_PDATE_&Year.      
        RPCAP_SPILPUB_PDATE_&Year.  
        SPCAP_SPILPRIV_PDATE_&Year.     
        SPCAP_SPILPUB_PDATE_&Year.  
        DIRPENS_PDATE_&Year.             
        OTHPENS_PDATE_&Year.             
        code_gezinslast_&Year.      
        code_echtgenote_&Year.          
        aantal_kind_&Year.          
        aantal_andere_&Year. 
        Code_alleenstaande_&Year.   
        begindatum_pensioen_c_&Year.
        ;
    RUN;

	data &LIB2..&ResFile.;
		set &LIB2..&ResFile. (rename = (gecodeerd_insz = insz));
	run;
 
%MEND ForEach;
%ForEach;
