/*
Met dit programma leggen we de lijst aan van steekproefnummers voor de MIMOSIS gegevens van het jaar 2008
Finale steekproef wordt getrokken op 1 januari 2009
*/
/*Zet bibliotheek en output-filenaam*/
%let EEJJK      = 20084;
%let EEJJ       = %SUBSTR(&EEJJK,1,4);
%let Year       = %SUBSTR(&EEJJK,1,4);
%let JJK        = %SUBSTR(&EEJJK,3,3);
%let JJ         = %SUBSTR(&EEJJK,3,2);
%let LIB1       = D_insz01;                 /*bibliotheek met persoonsgegevens vorige steekproef*/
%let SUBFILE1   = nis_014;                  /*bestand met persoonsgegevens*/
%let LIB2       = D_insz&JJ.;               /*bibliotheek met persoonsgegevens nieuwe steekproef*/
%let SUBFILE2   = nis_&JJ.4;                /*bestand met persoonsgegevens*/
%let LIB3       = MIMOSIS;                  /*bibliotheek met oorspronkelijke mimosis-gegevens*/
%let SubFile3   = MIMOSIS_Orig;             /*bestand met oorspronkelijke steeproefnummers*/
%let RESFILE    = Sample_MIMOSIS2008;           /*bestandsnaam van de file met gemanipuleerde gegevens*/
%let ClassSize  = 5;
%let ClassNum   = 20;

/*Roep externe hulpmacro om waarden in array te steken*/
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* MACRO:  ARRAY                                                        *
*  PARAMETERS:                                                         *
*    array-name                                                        *
*    array-elements: either of                                         *
*      horizontal list of array element values                         *
*                      delimiters may be specified, see default list   *
*      vertical   list: dataset w/ variable containing array values    *
*                                                                      *
*  USAGE: 1. %_ARRAY(ARAYNAME,ITEM-LIST);                              *
*         2. %_ARRAY(ARAYNAME,ITEM-LIST,DELIMITR=/);                   *
*         3. %_ARRAY(ARAYNAME,DATA=DATANAME,VAR=Var-Name);             *
*                                                                      *
*  DESCRIPTION:                                                        *
*    This macro returns a series of global macro-variables             *
*    named &ARAYNAME.1  &ARAYNAME.2 .. &ARAYNAME.n                     *
*    and a macro-variable named DIM_&ARAYNAME.                         *
*    i.e. %ARRAY(VAR,Q04A Q04B Q04C);                                  *
*    returns:    VAR1::Q04A VAR2::Q04B VAR3::Q04C, DIM_VAR::3          *
*                                                                      *
*  NOTES:                                                              *
*    length(ARAYNAME) must be <= 4                                     *
*    length(ARAYNAME) + length(dim_ARAYNAME) must be <= 8              *
*                                                                      *
*  CAUTION: creates %GLOBAL macro-variables                            *
*                                                                      *
*  PROCESS: case 1: scan user-provided list of array-elements          *
*           case 2: data set: call symput of variable                  *
*           case 3: error msg                                          *
*                                                                      *
*  KeyWords: array %ARRAY CONTENTS delimiter loop macro PARMBUFF %scan *
*            symput SYSPBUFF %until                                    *
*                                                                      *
*  Author: Ron Fehd,   MS-G25                  RJF2@phpdLs1.em.cdc.gov *
*          Centers for Disease Control, and Prevention                 *
*          4770 Buford Hwy NE                        fax: 404/488-7667 *
*          Atlanta  GA  30341-3724                 voice: 404/488-4316 *
*                                                                      *
*  SAS Guide to Macro Processing, V6 2e,                               *
*   delimiters: see scan                                               *
*   series of macro variables: pg 166                                  *
*   scan  : pg 126                                                     *
*   symput: pg 165                                                     *
RJF2:94Jan18 added DELIMITR=default list                               *
RJF2:95Mar02 polishing                                                 *
RJF2:96Feb13 handling obs=0                                            *
RJF2:96Jul09 rework scan algorithm for SESUG paper                     *
RJF2:96Jul09 changed: replace %scan with %qscan:                       *
RJF2:96Jul09 %qscan simplifies %do %until test                         *
RJF2:96Jul22 simplified error msgs                                     *
RJF2:96Jul22 removed comma and semicolon from DELIMITR                 *
RJF2:96Jul24 added PARMBUFF for error msg, polishing                   *
RJF2:96Dec27 changed scan to qscan to avoid errmsg scanning NOT        *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
%MACRO ARRAY(/*-------------------------------------------------------*/
 ARAYNAME    /*macro-var array-name: len(array-name) must be <= 4     */
,ITEMLIST    /*horizontal list of array-elements                      */
,DATA    =.  /*vertical list: dataset name                            */
,VAR     =.  /*vertical list: variable in dataset                     */
,DELIMITR=%STR( ).<%str(()]&!$*%str())^-/%>\/*delimiter of horiz-list */
)/PARMBUFF;/* PARMBUFF: see SYSPBUFF ---------------------------------*/

%IF  "&ARAYNAME" ne ""/*- case 1: ARAYNAME & ITEMLIST ----------------*/
 and "&ITEMLIST" ne ""
 and %length(&ARAYNAME) le 4 %THEN %DO;
 %local I ITEM;
 %LET I    = 1;
 %LET ITEM = %Qscan(&ITEMLIST,&I.,&DELIMITR);
 %DO %until(&ITEM = ); %global &ARAYNAME.&I;
                       %LET &ARAYNAME.&I = &ITEM.;
                       %LET I            = %eval(&I + 1);
                       %LET ITEM      = %Qscan(&ITEMLIST,&I.,&DELIMITR);
                                                   /* %DO %until*/ %END;
 %global DIM_&ARAYNAME;
 %LET    DIM_&ARAYNAME = %eval(&I - 1);
 %PUT macro proc ARRAY returns array: &ARAYNAME, dim=&&DIM_&ARAYNAME.;
 %PUT from list <&ITEMLIST.>;
 /*........................................ ARAYNAME & ITEMLIST */ %END;

%ELSE %IF "&ARAYNAME" ne "" /*- case 2: ARAYNAME & (DATA & VAR) ------*/
      and "&ITEMLIST" eq ""
      and "&DATA"     ne "." and "&VAR" ne "."
      and %length(&ARAYNAME) le 4 %THEN %DO;

proc CONTENTS data = &DATA   (keep = &VAR.) noprint
              out  = CONTENTS(keep = Nobs Type);

%global DIM_&ARAYNAME;

DATA _NULL_;
 length VarType $ 1;
 set CONTENTS;
 if Type = 1 then VarType = 'N';
 else             VarType = 'C';
 call symput("VARTYPE" ,VarType);
 call symput("DIM_&ARAYNAME",trim(left(put(Nobs,32.))));
stop; run;

%local I;
%DO    I = 1 %TO &&DIM_&ARAYNAME.; %global &ARAYNAME.&I.;          %END;

DATA _NULL_;                   /* symput(mac-var name : prefix + suffix,
 retain I 0;                             mac-var value: variable name */
 do until(EndoFile);
   set &DATA end = EndoFile;
   I + 1;
   call symput("&ARAYNAME" !!        left(put(I   , 7.0 )),
                                trim(left(
     %IF "&VARTYPE" = "N" %THEN           put(&VAR,best32.16)          ;
     %ELSE                                    &VAR                     ;
                                                 /*symput closure*/ )));
                                                  /*do until(EOF)*/ end;
stop; run;
%PUT macro proc ARRAY returns array: &ARAYNAME, dim=&&DIM_&ARAYNAME.;
%PUT from data = &DATA, var = &VAR.;
 /*......................................ARAYNAME & (DATA & VAR)*/ %END;

%ELSE %DO;/* print error msg -----------------------------------------*/

  %PUT ERROR: in macro ARRAY:;
  %PUT array-name : required;
  %PUT array-elements may be list, or (data and var);
  %PUT list    : ARRAY(ARAYNAME,ITEM-LIST);
  %PUT data+var: ARRAY(ARAYNAME,DATA=DATA-NAME,VAR=VAR-NAME);

  %IF %length(&ARAYNAME) gt 4 %THEN
   %PUT length(ARAYNAME) must be <= 4;
  %PUT parmlist: <&SYSPBUFF.>;/*from /PARMBUFF macro statement option*/
  %PUT parm: ARAYNAME = <&ARAYNAME.> length = <%length(&ARAYNAME)>;
  %PUT parm: ITEMLIST = <&ITEMLIST.>;
  %PUT parm: DATA     = <&DATA.>    ;
  %PUT parm: VAR      = <&VAR.>     ;
 /*.................................................. ANY ERRORS*/ %END;
 /*..................................................... ARRAY */ %MEND;

 /*-test data ------------ enable by ending this line with slash (/) **
DATA VQ04;  *convention for %CHECKALL setup;
length Name $ 8;  *can use proc CONTENTS output data set;
Name =  Q04A'; output;
Name =  Q04B'; output;
Name =  Q04C'; output; run;
%MACRO DEMO(DATA_OUT,ITEMLIST);* typical usage -----------------------*;
%IF &ITEMLIST ne %THEN %ARRAY(VAR, &ITEMLIST.);
%ELSE                  %ARRAY(VAR, DATA = V&DATA_OUT., VAR = Name);
%DO I = 1 %TO &DIM_VAR.; %PUT VAR&I. :: &&VAR&I.;                  %END;
 *....................................................... DEMO *; %MEND;
%DEMO(Q03, Q03A Q03B Q03C);  *data exploration usage;
%DEMO(Q04);  *production usage;
%ARRAY(TOOBIG,A B C D E);*see error msg;
%PUT _user_;*show list of macro-variables;
run; /*................................................. TEST DATA END*/

/*Leg lijst aan van gevallen die nog in leven zijn van de vorige steekproef*/
%MACRO AliveSinceStart;

    DATA Alive_Start;
        MERGE   &LIB2..&SubFile2 (In=InA Keep = INSZ CodNis)
                &LIB3..&SubFile3 (In=InB Keep = INSZ RND_SLCT)
        ;
        BY insz;
        /*Individuen die in de deelverzameling: laatste meetpunt en vorige steekproef zitten
        zijn individuen die nog in leven zijn uit de vorige steekproef*/
        IF ina=1 and inb=1;
        /*Gemeente = INPUT(CodNis, 8.);*/
	Gemeente = codnis;
        IF Gemeente LT 11000 OR Gemeente GT 93090 THEN DELETE;
    RUN;       

    DATA _NULL_;

        SET Alive_Start(KEEP=RND_SLCT WHERE=(RND_SLCT=1)) END=eof;
        
        IF EOF THEN DO;
            /*trim(left( procedure laten staan omdat die conversie naar karakter doet. Symput vereist karaktervariabelen*/
            CALL SYMPUT('NOldRan',trim(left(_N_)));             
            NewRanObs = 100000 - _N_;
            IF NewRanObs LT 0 OR NewRanObs EQ . THEN NewRanObs = 0; 
            CALL SYMPUT('NNewRan',trim(left(NewRanObs)));             
        END;

    RUN;

%Mend AliveSinceStart;
%AliveSinceStart;

%MACRO AgeDist;

    /*Maak data set met klasse-nummers*/
    DATA NewNum;

        RETAIN AgeClass;
        
        DO I = 1 TO %eval(&ClassNum);
            AgeClass = I;
            AgeClass_MinEen = I-1;
            OUTPUT;
        END;

    RUN;
    PROC SORT DATA=NewNum;
        BY AgeClass;
    RUN;        

    /*Maak leeftijdsverdeling aan voor hele populatie*/
    DATA AgePop;
    
        SET &LIB2..&SubFile2(KEEP = d_geboor CodNis);

        /*Gemeente = INPUT(CodNis, 8.);*/
	Gemeente = codnis;
        IF Gemeente LT 11000 OR Gemeente GT 93090 THEN DELETE;
        
        JAAR = Year(d_geboor);
        IF JAAR EQ . THEN DELETE;
        
        AgeClass = 0;
        DO I = 1 TO %eval(&ClassNum);
            HIGH  = %eval(&Year) -  (I-1)*%eval(&ClassSize);    
            LOW   = %eval(&Year) -  (I)*%eval(&ClassSize);    
            IF I EQ 1 THEN DO;
                IF JAAR GT LOW                  THEN AgeClass = I;
            END;
            ELSE IF I GT 1 AND I LT %eval(&ClassNum) THEN DO;
                IF JAAR LE HIGH AND JAAR GT LOW THEN AgeClass = I;
            END;
            ELSE DO;
                IF JAAR LE HIGH                 THEN AgeClass = I;
            END;
        END;

    RUN;       

    /*Bereken frequentie van voorkomen per klasse in populatie*/
    PROC FREQ DATA=AgePop;
	Title "Agepop: Bereken frequentie van voorkomen per klasse in populatie";
        TABLES AgeClass / OUT = OutFreq_Pop;
    RUN;
    PROC SORT DATA=OutFreq_Pop;
        BY AgeClass;
    RUN;        

    /*Maak leeftijdsverdeling aan voor nog levende individu in de steekproef die voorheen random getrokken werden*/
    DATA Random_Alive;
        
        MERGE   &LIB2..&SubFile2 (In=InA Keep = INSZ d_geboor CodNis)
                &LIB3..&SubFile3 (In=InB Keep = INSZ RND_SLCT)
        ;
        BY insz;
        IF ina=1 and inb=1;
        IF RND_SLCT EQ 1;
        
        /*Gemeente = INPUT(CodNis, 8.);*/
	Gemeente = codnis;
        IF Gemeente LT 11000 OR Gemeente GT 93090 THEN DELETE;

        JAAR = Year(d_geboor);
        IF JAAR EQ . THEN DELETE;
        
        AgeClass = 0;
        DO I = 1 TO %eval(&ClassNum);
            HIGH  = %eval(&Year) -  (I-1)*%eval(&ClassSize);    
            LOW   = %eval(&Year) -  (I)*%eval(&ClassSize);    
            IF I EQ 1 THEN DO;
                IF JAAR GT LOW                  THEN AgeClass = I;
            END;
            ELSE IF I GT 1 AND I LT %eval(&ClassNum) THEN DO;
                IF JAAR LE HIGH AND JAAR GT LOW THEN AgeClass = I;
            END;
            ELSE DO;
                IF JAAR LE HIGH                 THEN AgeClass = I;
            END;
        END;

    RUN;       

    /*Bereken frequentie van voorkomen per klasse in populatie*/
    PROC FREQ DATA=Random_Alive;
	Title "Random_Alive: Bereken frequentie van voorkomen per klasse in populatie";
        TABLES AgeClass / OUT = OutFreq_RAlive;
    RUN;
    PROC SORT DATA=OutFreq_RAlive;
        BY AgeClass;
    RUN;        

    /*Maak leeftijdsverdeling aan voor individuen in basispopulatie die voorheen niet random getrokken werden*/
    /*Dit is de groep waar later uit zal getrokken worden*/
    DATA NotRandom;
        
        MERGE   &LIB2..&SubFile2  (In=InA Keep = INSZ d_geboor CodNis)
                &LIB3..&SubFile3  (In=InB Keep = INSZ RND_SLCT)
        ;
        BY insz;
        IF ina=1;
        IF RND_SLCT EQ 1 THEN DELETE;
        
        /*Gemeente = INPUT(CodNis, 8.);*/
	Gemeente = codnis;
        IF Gemeente LT 11000 OR Gemeente GT 93090 THEN DELETE;

        JAAR = Year(d_geboor);
        IF JAAR EQ . THEN DELETE;
	AGE = %eval(&Year) - JAAR;
        
        AgeClass = 0;
        DO I = 1 TO %eval(&ClassNum);
            HIGH  = %eval(&Year) -  (I-1)*%eval(&ClassSize);    
            LOW   = %eval(&Year) -  (I)*%eval(&ClassSize);    
            IF I EQ 1 THEN DO;
                IF JAAR GT LOW                  THEN AgeClass = I;
            END;
            ELSE IF I GT 1 AND I LT %eval(&ClassNum) THEN DO;
                IF JAAR LE HIGH AND JAAR GT LOW THEN AgeClass = I;
            END;
            ELSE DO;
                IF JAAR LE HIGH                 THEN AgeClass = I;
            END;
        END;

    RUN;       
        
    PROC SORT DATA=NotRandom;
        BY AGE;
    RUN;

    DATA NotRandom;

        SET NotRandom;
        BY AGE;
        
        Obs_Line = _N_;

    RUN;       
    
    /*Bereken frequentie van voorkomen per klasse in populatie*/
    PROC FREQ DATA=NotRandom;
	Title "NotRandom: Bereken frequentie van voorkomen per klasse in populatie";
        TABLES AgeClass / OUT = OutFreq_NotRandom;
    RUN;
    PROC SORT DATA=OutFreq_NotRandom;
        BY AgeClass;
    RUN;        

    /*Voeg alle gegevens samen*/
    DATA AgeCount;

        MERGE
        NewNum(in=InA)
        OutFreq_Pop       (KEEP = AgeClass COUNT PERCENT RENAME = (COUNT = COUNT_Pop        PERCENT = PERCENT_Pop))
        OutFreq_RAlive    (KEEP = AgeClass COUNT PERCENT RENAME = (COUNT = COUNT_RAlive     PERCENT = PERCENT_RAlive))
        OutFreq_NotRandom (KEEP = AgeClass COUNT PERCENT RENAME = (COUNT = COUNT_NotRandom  PERCENT = PERCENT_NotRandom))
        ;
        BY AgeClass;
        IF InA EQ 1;
        
        /*Vul missing values in*/
        IF COUNT_Pop        EQ . THEN COUNT_Pop = 0;
        IF COUNT_RAlive     EQ . THEN COUNT_RAlive = 0;
        IF COUNT_NotRandom  EQ . THEN COUNT_NotRandom = 0;

        /*Objectief per leeftijdsklasse is populatiepercentage maal 100000*/
        Obj_PAgeClass = 0;
        IF PERCENT_Pop NE . THEN Obj_PAgeClass = (PERCENT_Pop/100)*100000;
        /*Met bijtrekking vullen we ontbrekend aantal gevallen per leeftijdsklasse aan*/
        BijTrek = ROUND(Obj_PAgeClass - COUNT_RAlive,1);
        IF BijTrek LT 0 THEN BijTrek = 0;
        
        KEEP AgeClass AgeClass_MinEen COUNT_Pop PERCENT_Pop COUNT_RAlive PERCENT_RAlive COUNT_NotRandom PERCENT_NotRandom BijTrek Obj_PAgeClass;
        
    RUN; 

    /*Bereken totaal aantal bij te trekken gevallen en steek ze in een macro-variabele*/
    PROC MEANS DATA=AgeCount NOPRINT;
        VAR BijTrek;
        OUTPUT OUT=OutMean1 SUM(BijTrek)=SUM_BijTrek;
    RUN;                    
    DATA _NULL_;
        SET OutMean1;
        CALL SYMPUT('TotBijTrek',TRIM(LEFT(SUM_BijTrek)));
    RUN;
    
    /*Voeg procedure toe om gegevens naar beneden toe te herschalen
    zodat exact 100000 gevallen random getrokken worden.
    Afwijking is mogelijk als er in de oorspronkelijke steekproef een oververtegenwoordiging was
    van bepaalde leeftijdsgroepen uit de huidige populatie*/
    %IF %eval(&NNewRan) LT %eval(&TotBijTrek) AND %eval(&TotBijTrek) NE 0 %THEN %DO;
        DATA AgeCount;
            SET AgeCount;
/*            BijTrek = (%eval(&NNewRan)/%eval(&TotBijTrek))*BijTrek;*/
            BijTrek = (&NNewRan/&TotBijTrek)*BijTrek;
	    Bijtrek = round(Bijtrek);
        RUN;
    %END;
    
    /*Use the %array function to put different values of Soort_Pensioen in macro-variable*/
    %ARRAY(BTV,DATA=AgeCount,VAR=BijTrek);           
    %ARRAY(CNTN,DATA=AgeCount,VAR=COUNT_NotRandom);           
    %ARRAY(AGC,DATA=AgeCount,VAR=AgeClass_MinEen);           
    
%MEND AgeDist;
%AgeDist;

/*Leg lijst aan met nieuw toe te voegen INSZ nummers*/
%MACRO SelectNewLines;

    /*Hou voor bepaling selectienummers rekening met plafond van vorige klasse om juiste lijnnummers te selecteren*/
    DATA NewNum;

        RETAIN uni Bodem;

        %DO I = 1 %TO %eval(&ClassNum);
        
            /*Bepaal ondergrens*/
            %IF %eval(&I) EQ 1 %THEN %DO;
                Bodem = 0;
            %END;
            %ELSE %DO;
				%let teller =  &&AGC&I.;
/*				%put &teller.;*/
/*				%put &&CNTN&teller.;*/
                Bodem = Bodem + %eval(&&CNTN&teller.);

/*				 put Bodem;*/
            %END;

            /*bepaal x uit nota, i.e. PopulatieOmvang/Steekproefomvang*/
            /*en maak lijst met nummers*/
            x = 0;

/*			%put &&BTV&I.;*/

            %IF &&BTV&I. GT 0 %THEN %DO;
/*            %IF %eval(&&BTV&I.) GT 0 %THEN %DO;*/

/*                x = ROUND(%eval(&&CNTN&I.)/%eval(&&BTV&I.),1);*/


/*                x = ROUND(&&CNTN&I./&&BTV&I.,1);*/
				x = &&CNTN&I./&&BTV&I.;
/*				put x;*/

                uni = x*ranuni(3);
/*                DO j= 1 to %eval(&&BTV&I.);*/
                DO j= 1 to &&BTV&I.;
                    Obs_Line = Bodem + ROUND(uni+(j-1)*x,1);
/*					put Obs_line;*/
/*                    Obs_Line = Bodem + ROUND(uni+(j-1)*x);*/
					IF Obs_Line > &&CNTN&I. + bodem - 200 THEN put Obs_Line; /****/
                    IF Obs_Line > &&CNTN&I. + bodem THEN Obs_Line = &&CNTN&I. + bodem;
                    OUTPUT;
                END;

            %END;

        %END;

    RUN;

    PROC SORT DATA=NewNum;
        BY Obs_Line;
    RUN;    
    
    PROC SORT DATA=NotRandom;
        BY Obs_Line;
    RUN;        

    DATA New_INSZ;
        MERGE   NewNum      (In=InA keep = Obs_Line)
                NotRandom   (In=InB)
        ;
        BY Obs_Line;
        IF ina=1 and inb=1;
    RUN;  

    PROC FREQ DATA=New_INSZ;
        TITLE "Frequentie nieuwe INSZ nummers naar leeftijdsklasse";
        TABLES AgeClass ;
    RUN;

%Mend SelectNewLines;
%SelectNewLines;

proc sql;
	create table Alive_Start2 as
	select *
	from Alive_Start
	where insz not in (select insz from New_INSZ);
quit;


DATA OldNew;
    SET
        Alive_Start2(in=InA)
        New_INSZ(in=InB)
    ;
    RND_SLCT_OLD = 9;
    IF InA EQ 1 THEN RND_SLCT_OLD = RND_SLCT;
    RND_SLCT_NEW = 9;
    IF InB EQ 1 THEN RND_SLCT_NEW = 1;

    RND_SLCT_COMB = 0;
    IF RND_SLCT_OLD EQ 1 OR RND_SLCT_NEW EQ 1 THEN RND_SLCT_COMB = 1;
    
    KEEP INSZ RND_SLCT_OLD RND_SLCT_NEW RND_SLCT_COMB;
RUN;

/*Test of totaal aantal random geselecteerden gelijk is aan 100000*/
PROC FREQ DATA=OldNew;
    TITLE "Frequentie oude en nieuwe INSZ nummers naar random selectie";
    TABLES RND_SLCT_OLD RND_SLCT_NEW RND_SLCT_COMB;
RUN;

DATA Sampled_INSZ;
    SET OldNew (WHERE=(RND_SLCT_COMB=1));
    KEEP INSZ;
RUN;

proc sort data = Sampled_INSZ; by insz; run;

/* Opzoeken van de referentiepersoon. 
   Niet alle steekproefpersonen hebben een referentiepersoon */
data gezin1;
	merge Sampled_INSZ (in=ina)
		  D_insz08.nis_084 (keep = insz insz_ref);
	by insz;
	if ina=1;
	if insz_ref not in ('' 'xxxxxxxxxxxxxxxxxxxxx');
run;

/* Opzoeken van alle gezinsleden, met inbegrip van de steekproefpersonen */
proc sql;
	create table gezin2 as
	select insz, insz_ref
	from D_insz08.nis_084
	where insz_ref in (select distinct insz_ref from gezin1);
quit;

/* Toeveogen van de steekproefpersonen die geen gezinleden hebben */
data HH_SAMPLE;
	merge Sampled_INSZ (in=ina)
		  gezin2;
	by insz;
run;

proc sort data = HH_SAMPLE; by insz; run;

/**/

proc sort data = OldNew; by insz; run;

data mimosis.mim2008_Sample;
	merge HH_SAMPLE (in=ina)
		  OldNew;
	by insz;
	if ina=1;
	KEEP INSZ INSZ_REF RND_SLCT_OLD RND_SLCT_NEW RND_SLCT_COMB;
run;







